"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.validateModuleSettings = void 0;
const VALIDATE_SETTINGS_ERROR = {
    wrongFormat: "Неверный формат настроек конфигурации.",
    testsError: `Неверно указаны настройки тестов. Пример правильной настройки tests: { features: ["tests/**/*"], steps: ["steps/**/*"], exitOnEnd: false }.`,
    appNotFound: `В настройках не хватает опции "app". Пример настройки app: { bearerToken: "токен_авторизации", url: "ссылка_на_инстанс_mdt " }`,
    users: `Пожалуйста укажите пользователей под которыми можно будет запустить тестирование.`,
    instanceUrlNotFound: `Пожалуйста укажите ссылку на инстанс mdt. Пример настройки app: { url: "ссылка_на_инстанс_mdt" }`
};
function validateModuleSettings(settings) {
    if (typeof settings !== "object" || Array.isArray(settings) || settings === null)
        throw new Error(VALIDATE_SETTINGS_ERROR.wrongFormat);
    if (!settings.tests)
        throw new Error(VALIDATE_SETTINGS_ERROR.testsError);
    if (!settings.tests.steps || !settings.tests.features)
        throw new Error(VALIDATE_SETTINGS_ERROR.testsError);
    if (!settings.app)
        throw new Error(VALIDATE_SETTINGS_ERROR.appNotFound);
    if (!settings.app.users || Object.keys(settings.app.users).length < 1)
        throw new Error(VALIDATE_SETTINGS_ERROR.users);
    if (!settings.app.url)
        throw new Error(VALIDATE_SETTINGS_ERROR.instanceUrlNotFound);
}
exports.validateModuleSettings = validateModuleSettings;
