"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const cucumber_1 = require("@cucumber/cucumber");
const test_1 = require("@playwright/test");
const setup_1 = require("./setup");
const featureManager_1 = require("../src/utils/featureManager");
const waitForAppLoad_1 = require("../src/utils/waitForAppLoad");
const pageAfterRetries_1 = require("./pageAfterRetries");
const DialogManager_1 = require("../src/utils/DialogManager");
const screenshotManager_1 = require("../src/utils/screenshotManager");
const path = require("path");
const fs = require("fs");
(0, cucumber_1.setDefaultTimeout)(setup_1.config.timeout);
function goToApp() {
    var _a;
    return __awaiter(this, void 0, void 0, function* () {
        yield ((_a = global.cucumberPage) === null || _a === void 0 ? void 0 : _a.close());
        const page = yield (0, pageAfterRetries_1.pageAfterRetries)(global.context, setup_1.config.url, setup_1.config.maxRetries);
        if (!page)
            throw new Error("Не удалось подключиться к MDT. Проверьте url");
        yield (0, waitForAppLoad_1.waitForAppLoad)(page);
        global.cucumberPage = page;
    });
}
(0, cucumber_1.BeforeAll)({ timeout: setup_1.config.largeTimeout }, function () {
    return __awaiter(this, void 0, void 0, function* () {
        screenshotManager_1.ScreenshotManager.cleanFailuresImages();
        global.browser = yield test_1.chromium.launch({
            slowMo: setup_1.config.slowMo,
            channel: "chrome",
            devtools: setup_1.config.devTools,
            headless: true
        });
        global.context = yield global.browser.newContext({
            acceptDownloads: true,
            timezoneId: setup_1.config.timezone
        });
    });
});
(0, cucumber_1.Before)({ timeout: setup_1.config.largeTimeout }, function (scenario) {
    return __awaiter(this, void 0, void 0, function* () {
        const isNewFeature = featureManager_1.default.isNewFeature(scenario);
        if (isNewFeature) {
            featureManager_1.default.context.reset();
            featureManager_1.default.setCurrent(scenario);
            yield goToApp();
            DialogManager_1.DialogManager.init(global.cucumberPage);
        }
        else if (featureManager_1.default.isFailed(scenario)) {
            return featureManager_1.default.getSkippedState();
        }
        yield this.initPage(global.cucumberPage, featureManager_1.default.context);
    });
});
(0, cucumber_1.BeforeStep)({
    timeout: setup_1.config.largeTimeout
}, function () {
    return __awaiter(this, void 0, void 0, function* () {
        yield this.waitForLoading();
    });
});
(0, cucumber_1.AfterStep)({
    timeout: setup_1.config.largeTimeout
}, function (scenario) {
    return __awaiter(this, void 0, void 0, function* () {
        if (featureManager_1.default.isStepFailed(scenario)) {
            featureManager_1.default.addFailed(scenario);
            yield screenshotManager_1.ScreenshotManager.saveFailScreenshot(this.cucumberPage);
            if (setup_1.config.reloadOnError)
                yield this.reload();
        }
        yield this.waitForLoading();
    });
});
