"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.pageAfterRetries = void 0;
const setup_1 = require("./setup");
const userLogin_1 = require("../src/utils/userLogin");
function pageAfterRetries(context, url, maxRetries) {
    return __awaiter(this, void 0, void 0, function* () {
        if (!maxRetries)
            return;
        const page = yield context.newPage();
        workaroundForGoogleFontRequests(page);
        const [_, response] = yield Promise.all([
            page.goto(url),
            page.waitForEvent("response", (response) => response.request().resourceType() === "document"),
            setup_1.config.defaultUser ? yield (0, userLogin_1.loginByUser)(page, setup_1.config.defaultUser) : Promise.resolve()
        ]);
        const status = response.status();
        if ([502, 503].includes(status)) {
            yield page.close();
            return pageAfterRetries(context, url, maxRetries - 1);
        }
        return page;
    });
}
exports.pageAfterRetries = pageAfterRetries;
function workaroundForGoogleFontRequests(page) {
    page.route(`**/*`, (route) => {
        const url = route.request().url();
        if (url.includes("fonts.gstatic.com")) {
            const headers = route.request().headers();
            delete headers["Authorization"];
            route.continue({ headers });
        }
        else {
            route.continue();
        }
    });
}
