import { DataTable } from "@cucumber/cucumber";
/**
 * ```js
 * When("на форме сотрудника заполняем следующие поля:", async function (this, positionData: DataTable) {
 *  await MDT.list.openFormByNumber(this, 1);
 *  await MDT.form.expectOpen("Сотрудник")
 *  await MDT.form.setManyFieldsValue(this, positionData);
 * });
 * ```
 */
export declare const MDT: {
    form: {
        /**
         * Проверка открытия формы, аналогично шагу:
         *
         * То открывается форма {string}.
         */
        expectOpen: (page: any, title?: string) => Promise<void>;
        /**
         * Заполняет поле на форме, аналогично шагу
         *
         * Когда заполняем поле {string} значением {string}.
         *
         */
        setFieldValue: (page: any, fieldName: string, value: string) => Promise<void>;
        /**
         * Заполняет сразу несколько полей, аналогично шагу:
         *
         * Когда заполняем поля формы следующими значениями:
         *
         * | имя_поля   | значение_1 |
         * | имя_поля_2 | значение_2 |
         *
         * ```js
         * When("добавляем сотруднику должность:", async function (this, positionData: DataTable) {
         *  await MDT.form.setManyFieldsValue(this, positionData);
         * });
         * ```
         */
        setManyFieldsValue: (page: any, table: DataTable) => Promise<boolean>;
        /**
         * Проверка открытия формы, аналогично шагу:
         *
         * То на форме есть список {string}.
         */
        hasList: (page: any, options?: {
            title?: string;
        }) => Promise<void>;
        /**
         * Проверка открытия формы, аналогично шагу:
         *
         * То форма {string} закрывается.
         */
        expectClose: (page: any, title?: string) => Promise<void>;
        /**
         * Проверка открытия формы, аналогично шагу:
         *
         * Когда нажимаем кнопку {string} на форме.
         */
        clickButton: (page: any, buttonName: string) => Promise<void>;
    };
    list: {
        /**
         * Открывает форму записи, аналогично шагу:
         *
         * Когда нажимаем кнопку редактирования записи №{int}.
         */
        openFormByNumber: (page: any, rowNumber: number) => Promise<void>;
        /**
         * Нажимает кнопку в списке, аналогично шагу:
         *
         * Когда нажимаем кнопку {string} в списке.
         */
        clickButton: (page: any, buttonName: string) => Promise<void>;
        /**
         * Проверяет что список содержит записи, учитывает порядок записей, НЕ учитывает порядок колонок. Аналогично шагу:
         *
         * То список будет содержать следующие записи:
         */
        expectList: (page: any, table: DataTable) => Promise<void>;
        /**
         * Проверяет что список содержит записи, НЕ учитывает порядок записей, НЕ учитывает порядок колонок. Аналогично шагу:
         *
         * То список содержит следующие записи в любом порядке:
         */
        softCompareList: (page: any, table: DataTable) => Promise<void>;
    };
    modal: {
        /**
         * Проверка что модальное окно открылось, аналогично шагу:
         *
         * То открывается модальное окно {string}.
         */
        expectOpen: (page: any, title?: string) => Promise<void>;
        /**
         * Проверка что модальное окно закроется, аналогично шагу:
         *
         * Когда модальное окно {string} закрывается.
         */
        expectClose: (page: any, title?: string) => Promise<void>;
        /**
         * нажатие на кнопку в модальном окне, аналогично шагу:
         *
         * Когда нажимаем кнопку {string} в модальном окне.
         */
        clickButton: (page: any, title?: string) => Promise<void>;
    };
    /**
     * ожидание загрузки страницы, когда появляется loading и блокируется интерфейс
     */
    waitForLoading(page: any): any;
};
