"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MDT = void 0;
const form_steps_1 = require("../pageObject/form/form.steps");
const list_steps_1 = require("../pageObject/list/list.steps");
const modal_steps_1 = require("../pageObject/modal/modal.steps");
const expectContainRecords_steps_1 = require("../pageObject/list/steps/compare/expectContainRecords.steps");
const softListCompare_steps_1 = require("../pageObject/list/steps/compare/softListCompare.steps");
/**
 * ```js
 * When("на форме сотрудника заполняем следующие поля:", async function (this, positionData: DataTable) {
 *  await MDT.list.openFormByNumber(this, 1);
 *  await MDT.form.expectOpen("Сотрудник")
 *  await MDT.form.setManyFieldsValue(this, positionData);
 * });
 * ```
 */
exports.MDT = new (class {
    constructor() {
        this.form = {
            /**
             * Проверка открытия формы, аналогично шагу:
             *
             * То открывается форма {string}.
             */
            expectOpen: (page, title) => {
                return (0, form_steps_1.expectOpenForm)(page, title);
            },
            /**
             * Заполняет поле на форме, аналогично шагу
             *
             * Когда заполняем поле {string} значением {string}.
             *
             */
            setFieldValue: (page, fieldName, value) => {
                return (0, form_steps_1.setFieldValueStep)(page, fieldName, value);
            },
            /**
             * Заполняет сразу несколько полей, аналогично шагу:
             *
             * Когда заполняем поля формы следующими значениями:
             *
             * | имя_поля   | значение_1 |
             * | имя_поля_2 | значение_2 |
             *
             * ```js
             * When("добавляем сотруднику должность:", async function (this, positionData: DataTable) {
             *  await MDT.form.setManyFieldsValue(this, positionData);
             * });
             * ```
             */
            setManyFieldsValue: (page, table) => {
                return (0, form_steps_1.setManyFieldsValue)(page, table);
            },
            /**
             * Проверка открытия формы, аналогично шагу:
             *
             * То на форме есть список {string}.
             */
            hasList: (page, options) => {
                return (0, form_steps_1.formHasList)(page, options === null || options === void 0 ? void 0 : options.title);
            },
            /**
             * Проверка открытия формы, аналогично шагу:
             *
             * То форма {string} закрывается.
             */
            expectClose: (page, title) => {
                return (0, form_steps_1.waitForFormClosed)(page, title);
            },
            /**
             * Проверка открытия формы, аналогично шагу:
             *
             * Когда нажимаем кнопку {string} на форме.
             */
            clickButton: (page, buttonName) => {
                return (0, form_steps_1.clickButtonFromForm)(page, buttonName);
            }
        };
        this.list = {
            /**
             * Открывает форму записи, аналогично шагу:
             *
             * Когда нажимаем кнопку редактирования записи №{int}.
             */
            openFormByNumber: (page, rowNumber) => {
                return (0, list_steps_1.openForm)(page, rowNumber);
            },
            /**
             * Нажимает кнопку в списке, аналогично шагу:
             *
             * Когда нажимаем кнопку {string} в списке.
             */
            clickButton: (page, buttonName) => {
                return (0, list_steps_1.clickButtonFromListStep)(page, buttonName);
            },
            /**
             * Проверяет что список содержит записи, учитывает порядок записей, НЕ учитывает порядок колонок. Аналогично шагу:
             *
             * То список будет содержать следующие записи:
             */
            expectList: (page, table) => {
                return (0, expectContainRecords_steps_1.listContainRecordsStep)(page, table);
            },
            /**
             * Проверяет что список содержит записи, НЕ учитывает порядок записей, НЕ учитывает порядок колонок. Аналогично шагу:
             *
             * То список содержит следующие записи в любом порядке:
             */
            softCompareList: (page, table) => {
                return (0, softListCompare_steps_1.softListCompareStep)(page, table);
            }
        };
        this.modal = {
            /**
             * Проверка что модальное окно открылось, аналогично шагу:
             *
             * То открывается модальное окно {string}.
             */
            expectOpen: (page, title) => {
                return (0, modal_steps_1.expectOpenModal)(page, title);
            },
            /**
             * Проверка что модальное окно закроется, аналогично шагу:
             *
             * Когда модальное окно {string} закрывается.
             */
            expectClose: (page, title) => {
                return (0, modal_steps_1.expectCloseModal)(page, title);
            },
            /**
             * нажатие на кнопку в модальном окне, аналогично шагу:
             *
             * Когда нажимаем кнопку {string} в модальном окне.
             */
            clickButton: (page, title) => {
                return (0, modal_steps_1.clickButtonFromModal)(page, title);
            }
        };
    }
    /**
     * ожидание загрузки страницы, когда появляется loading и блокируется интерфейс
     */
    waitForLoading(page) {
        return page.waitForLoading();
    }
})();
