"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getReadyDropdown = exports.dropdownPickItem = void 0;
const cucumber_1 = require("@cucumber/cucumber");
const test_1 = require("@playwright/test");
const setup_1 = require("../../../setup/setup");
const asyncArray_1 = require("../../utils/asyncArray");
const tableManager_1 = require("../../utils/tableManager");
(0, cucumber_1.When)("нажимаем на пункт {string} в выпадающем меню.", function (itemTitle) {
    return __awaiter(this, void 0, void 0, function* () {
        yield dropdownPickItem(this, itemTitle);
    });
});
(0, cucumber_1.Then)("появляется выпадающее меню.", function () {
    return __awaiter(this, void 0, void 0, function* () {
        const dropdown = yield getReadyDropdown(this.dropdown);
        yield dropdown.el.waitFor();
        yield (0, test_1.expect)(dropdown.el).toBeVisible();
    });
});
(0, cucumber_1.Then)("выпадающее меню закрывается.", function () {
    return __awaiter(this, void 0, void 0, function* () {
        (0, test_1.expect)(yield this.dropdown.isExist()).toBeFalsy();
    });
});
(0, cucumber_1.Then)("выпадающее меню не появляется.", function () {
    return __awaiter(this, void 0, void 0, function* () {
        (0, test_1.expect)(yield this.dropdown.isExist()).toBeFalsy();
    });
});
(0, cucumber_1.Then)("в выпадающем меню есть пункт {string}.", function (itemTitle) {
    return __awaiter(this, void 0, void 0, function* () {
        const dropdown = yield getReadyDropdown(this.dropdown);
        const item = dropdown.itemByTitle(itemTitle);
        yield item.waitFor();
        yield (0, test_1.expect)(item).toBeVisible();
    });
});
function expectItemsCount(count) {
    return __awaiter(this, void 0, void 0, function* () {
        const dropdown = yield getReadyDropdown(this.dropdown);
        (0, test_1.expect)(yield dropdown.item.count()).toBe(count);
    });
}
(0, cucumber_1.Then)(/в выпадающем меню (-?\d+) пункт[ов|а]*\./, expectItemsCount);
(0, cucumber_1.Then)("в выпадающем меню есть пункты:", { timeout: setup_1.config.largeTimeout }, function (itemTitlesRow) {
    return __awaiter(this, void 0, void 0, function* () {
        const dropdown = yield getReadyDropdown(this.dropdown);
        const items = (0, tableManager_1.getRowData)(itemTitlesRow);
        yield (0, asyncArray_1.asyncForEach)(items, (itemTitle) => __awaiter(this, void 0, void 0, function* () {
            const item = dropdown.itemByTitle(itemTitle);
            yield (0, test_1.expect)(item).toBeVisible();
        }));
    });
});
function dropdownPickItem(page, itemTitle) {
    return __awaiter(this, void 0, void 0, function* () {
        const dropdown = yield getReadyDropdown(page.dropdown);
        const item = dropdown.itemByTitle(itemTitle);
        yield item.waitFor();
        yield item.click({ trial: true });
        yield item.evaluateHandle((el) => {
            el.click();
        });
        yield dropdown.el.waitFor({ state: "hidden" });
    });
}
exports.dropdownPickItem = dropdownPickItem;
function getReadyDropdown(dropdown) {
    return __awaiter(this, void 0, void 0, function* () {
        yield dropdown.el.waitFor();
        yield dropdown.item.first().waitFor();
        return dropdown;
    });
}
exports.getReadyDropdown = getReadyDropdown;
