"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getBooleanFromData = exports.getDataFromBoolean = exports.getBooleanData = exports.isBoolean = exports.booleanData = exports.booleanSelector = exports.booleanSelectors = exports.setCheckboxValue = exports.getBooleanControl = exports.getCheckbox = exports.Boolean = void 0;
const getSelector_1 = require("../../../../../utils/getSelector");
class Boolean {
    constructor(parentEl) {
        this.type = "checkbox";
        this.parentEl = parentEl;
        this.el = parentEl.locator(exports.booleanSelector);
    }
    isExistAsync() {
        return __awaiter(this, void 0, void 0, function* () {
            return isBoolean(this.parentEl);
        });
    }
    displayValueAsync() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield getBooleanData(this.parentEl);
        });
    }
    get input() {
        return getCheckbox(this.parentEl);
    }
    isReadonly() {
        return __awaiter(this, void 0, void 0, function* () {
            const oldValue = yield getBooleanData(this.parentEl);
            yield this.el.click();
            const newValue = yield getBooleanData(this.parentEl);
            const input = yield this.input.isHidden();
            if (oldValue != newValue) {
                for (let i = 0; i < 3; i++) {
                    let displayValue = yield this.displayValueAsync();
                    if (oldValue != displayValue) {
                        yield this.el.click();
                    }
                }
            }
            return input && oldValue == newValue;
        });
    }
}
exports.Boolean = Boolean;
function getCheckbox(parentEl) {
    return parentEl.locator(exports.booleanSelectors.checkbox);
}
exports.getCheckbox = getCheckbox;
function getBooleanControl(parentEl) {
    return new Boolean(parentEl);
}
exports.getBooleanControl = getBooleanControl;
function setCheckboxValue(page, checkbox, value) {
    return __awaiter(this, void 0, void 0, function* () {
        for (let i = 0; i < 3; i++) {
            let displayValue = yield checkbox.displayValueAsync();
            if (value != displayValue) {
                yield checkbox.input.click();
            }
            else
                return;
        }
        throw new Error(`Не удалось установить значение ${value} для чекбокса.`);
    });
}
exports.setCheckboxValue = setCheckboxValue;
exports.booleanSelectors = {
    checkbox: (0, getSelector_1.getSelector)({ testid: "checkbox" }),
    trueStateIcon: `.icon-check-square`,
    falseStateIcon: `.icon-square`,
    indeterminateStateIcon: `.icon-minus-square`
};
exports.booleanSelector = [
    (0, getSelector_1.getSelector)({
        testid: "boolean"
    }),
    (0, getSelector_1.getSelector)({
        testid: "checkbox"
    })
].join(", ");
exports.booleanData = {
    indeterminate: "[-]",
    truthy: "[x]",
    false: "[ ]"
};
function isBoolean(parentEl) {
    return __awaiter(this, void 0, void 0, function* () {
        const boolean = parentEl.locator(exports.booleanSelector);
        const isBoolean = yield boolean.isVisible();
        return isBoolean;
    });
}
exports.isBoolean = isBoolean;
function getBooleanData(parentEl) {
    return __awaiter(this, void 0, void 0, function* () {
        const booleanValue = yield getBooleanFromEl(parentEl);
        return getDataFromBoolean(booleanValue);
    });
}
exports.getBooleanData = getBooleanData;
function getDataFromBoolean(value) {
    if (value == null)
        return exports.booleanData.indeterminate;
    if (value)
        return exports.booleanData.truthy;
    if (value == false)
        return exports.booleanData.false;
    return "Error";
}
exports.getDataFromBoolean = getDataFromBoolean;
function getBooleanFromData(value) {
    if (value == exports.booleanData.indeterminate)
        return null;
    if (value == exports.booleanData.truthy)
        return true;
    if (value == exports.booleanData.false)
        return false;
    throw new Error("Не удалось преобразовать значение: " + value);
}
exports.getBooleanFromData = getBooleanFromData;
function getBooleanFromEl(el) {
    return __awaiter(this, void 0, void 0, function* () {
        if (yield getCheckbox(el).isVisible()) {
            const checkbox = getCheckbox(el);
            const isIndeterminate = yield checkbox.getAttribute("indeterminate");
            if (isIndeterminate)
                return null;
            const value = yield checkbox.isChecked();
            return value;
        }
        if (yield el.locator(exports.booleanSelectors.trueStateIcon).isVisible()) {
            return true;
        }
        if (yield el.locator(exports.booleanSelectors.falseStateIcon).isVisible()) {
            return false;
        }
        if (yield el.locator(exports.booleanSelectors.indeterminateStateIcon).isVisible()) {
            return null;
        }
        throw new Error(`Значение в элементе ${el} не булево.`);
    });
}
