"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.clearFileControlValue = exports.setFileControlValue = exports.getFileControl = exports.FileControl = void 0;
const getSelector_1 = require("../../../../../utils/getSelector");
const icon_1 = require("../../../../icon/icon");
const text_1 = require("../text/text");
const progressBar_1 = require("../../../../progressBar/progressBar");
class FileControl {
    constructor(parentEl) {
        this.type = "file";
        this.selectors = {
            selectorLink: (0, getSelector_1.getSelector)({ testid: "selector-link" }),
            file: (0, getSelector_1.getSelector)({ testid: "file" }),
            image: (0, getSelector_1.getSelector)({ filetype: "image" }),
            imageContent: (0, getSelector_1.getSelector)({ testid: "file-image-content" }),
            linkName: (0, getSelector_1.getSelector)({ testid: "selector-link-name" }),
            imageCleanIcon: (0, getSelector_1.getSelector)({ icon: "trash" }),
            defaultCleanIcon: (0, getSelector_1.getSelector)({ testid: "clear-action" }),
            uploadIcon: (0, getSelector_1.getSelector)({ icon: "arrow-up-from-bracket" })
        };
        this.el = parentEl.locator(this.selectors.file);
        this.fileWrap = this.el.locator(this.selectors.selectorLink);
        this.image = parentEl.locator(this.selectors.image);
        this.imageContent = this.image.locator(this.selectors.imageContent);
        this.progressBar = new progressBar_1.ProgressBar(this.el);
    }
    isExistAsync() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.el.isVisible();
        });
    }
    displayValueAsync() {
        return __awaiter(this, void 0, void 0, function* () {
            let text = yield this.el.textContent();
            if (yield this.hasFile())
                text = yield this.el.locator(this.selectors.linkName).textContent();
            return text;
        });
    }
    hasFile() {
        return this.fileWrap.isVisible();
    }
    getIcon() {
        return __awaiter(this, void 0, void 0, function* () {
            const icon = (0, icon_1.getIcon)(this.fileWrap);
            return yield icon.getCode();
        });
    }
    isImage() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.image.isVisible();
        });
    }
    hasImageFile() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.imageContent.isVisible();
        });
    }
    imageHeight(height) {
        return __awaiter(this, void 0, void 0, function* () {
            const style = yield this.image.getAttribute("style");
            if (!style)
                return false;
            if (style.match(`height: ${height}`))
                return true;
            else
                return false;
        });
    }
    imageWidth(width) {
        return __awaiter(this, void 0, void 0, function* () {
            const style = yield this.image.getAttribute("style");
            if (!style)
                return false;
            if (style.match(`width: ${width}`))
                return true;
            else
                return false;
        });
    }
    get imageFile() {
        return this.imageContent;
    }
    get ImageFileClear() {
        return this.imageContent.locator(this.selectors.imageCleanIcon);
    }
    get clear() {
        return this.el.locator(this.selectors.defaultCleanIcon);
    }
    get upload() {
        return this.el.locator(this.selectors.uploadIcon);
    }
    get input() {
        const control = new text_1.InputControl(this.el);
        return control.textEl;
    }
    isReadonly() {
        return __awaiter(this, void 0, void 0, function* () {
            const upload = yield this.upload.isHidden();
            const input = yield this.input.isHidden();
            const clear = yield this.clear.isHidden();
            return upload && clear && input;
        });
    }
}
exports.FileControl = FileControl;
function getFileControl(parentEl) {
    return new FileControl(parentEl);
}
exports.getFileControl = getFileControl;
function setFileControlValue(page, file, fileName) {
    return __awaiter(this, void 0, void 0, function* () {
        yield page.selectFile(fileName, () => __awaiter(this, void 0, void 0, function* () {
            yield file.upload.waitFor();
            yield file.upload.click();
        }));
        yield page.waitForLoading();
        yield file.progressBar.waitForComplete();
    });
}
exports.setFileControlValue = setFileControlValue;
function clearFileControlValue(file) {
    return __awaiter(this, void 0, void 0, function* () {
        yield file.el.focus();
        yield file.clear.click();
        yield file.fileWrap.waitFor({ state: "hidden" });
        if (yield file.hasFile())
            throw new Error("Не удалось очистить поле с файлом");
    });
}
exports.clearFileControlValue = clearFileControlValue;
