"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.clearTextControlValue = exports.ContentEditableControl = exports.getContentEditableControl = exports.TextAreaControl = exports.getTextAreaControl = exports.InputControl = exports.getInputControl = void 0;
class TextBase {
    constructor(parentEl, selector) {
        this.el = parentEl;
        this.textEl = this.el.locator(selector);
    }
    isExistAsync() {
        return __awaiter(this, void 0, void 0, function* () {
            return this.textEl.isVisible();
        });
    }
    displayValueAsync() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.textEl.inputValue();
        });
    }
    setValue(page, value) {
        return __awaiter(this, void 0, void 0, function* () {
            yield this.textEl.waitFor();
            yield this.textEl.fill(value);
        });
    }
}
function getInputControl(parentEl) {
    return new InputControl(parentEl);
}
exports.getInputControl = getInputControl;
class InputControl extends TextBase {
    constructor(parentEl) {
        super(parentEl, InputControl.selectors.el);
        this.parentEl = parentEl;
        this.type = "input";
    }
    isReadonly() {
        return __awaiter(this, void 0, void 0, function* () {
            const input = yield this.parentEl.locator(InputControl.selectors.el);
            return yield isTextControReadOnly(input);
        });
    }
    isExistAsync() {
        return __awaiter(this, void 0, void 0, function* () {
            return this.parentEl.locator(InputControl.selectors.el).isVisible();
        });
    }
}
exports.InputControl = InputControl;
InputControl.selectors = {
    el: "input"
};
function getTextAreaControl(parentEl) {
    return new TextAreaControl(parentEl);
}
exports.getTextAreaControl = getTextAreaControl;
class TextAreaControl extends TextBase {
    constructor(parentEl) {
        super(parentEl, TextAreaControl.selectors.el);
        this.parentEl = parentEl;
        this.type = "textarea";
    }
    isReadonly() {
        return __awaiter(this, void 0, void 0, function* () {
            const textarea = yield this.parentEl.locator(TextAreaControl.selectors.el);
            return yield isTextControReadOnly(textarea);
        });
    }
}
exports.TextAreaControl = TextAreaControl;
TextAreaControl.selectors = {
    el: "textarea"
};
function getContentEditableControl(parentEl) {
    return new ContentEditableControl(parentEl);
}
exports.getContentEditableControl = getContentEditableControl;
class ContentEditableControl extends TextBase {
    constructor(parentEl) {
        super(parentEl, ContentEditableControl.selectors.el);
        this.parentEl = parentEl;
        this.type = "contenteditable";
    }
    isReadonly() {
        return __awaiter(this, void 0, void 0, function* () {
            const contenteditable = yield this.parentEl.locator(ContentEditableControl.selectors.el);
            return yield isTextControReadOnly(contenteditable);
        });
    }
}
exports.ContentEditableControl = ContentEditableControl;
ContentEditableControl.selectors = {
    el: "[contenteditable]"
};
function isTextControReadOnly(control) {
    return __awaiter(this, void 0, void 0, function* () {
        const oldValue = yield control.inputValue();
        yield control.fill("newValue", { force: true });
        const newValue = yield control.inputValue();
        //Если при проверке значение изменилось, то возвращаем значение обратно
        if (oldValue != newValue) {
            control.fill(oldValue);
        }
        return oldValue == newValue;
    });
}
function clearTextControlValue(control) {
    return __awaiter(this, void 0, void 0, function* () {
        yield control.textEl.fill("");
    });
}
exports.clearTextControlValue = clearTextControlValue;
