"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getAudit = void 0;
const getSelector_1 = require("../../../utils/getSelector");
function getAudit(parentEl) {
    const selectors = {
        audit: (0, getSelector_1.getSelector)({
            testid: "audit"
        }),
        entry: (0, getSelector_1.getSelector)({
            testid: "audit-entry"
        }),
        loadMore: (0, getSelector_1.getSelector)({
            testid: "audit-load-more"
        })
    };
    const el = parentEl.locator(selectors.audit);
    const entry = el.locator(selectors.entry);
    return {
        el,
        get loadMore() {
            return el.locator(selectors.loadMore);
        },
        entriesCount() {
            return entry.count();
        },
        lastChange() {
            return auditEntry(entry.first());
        }
    };
}
exports.getAudit = getAudit;
function auditEntry(entryEl) {
    const selectors = {
        user: (0, getSelector_1.getSelector)({
            testid: "audit-user"
        }),
        date: (0, getSelector_1.getSelector)({
            testid: "audit-date"
        }),
        operation: (0, getSelector_1.getSelector)({
            testid: "audit-operation"
        }),
        table: (0, getSelector_1.getSelector)({
            testid: "audit-table"
        }),
        field: (0, getSelector_1.getSelector)({
            testid: "audit-field"
        })
    };
    const tableEl = entryEl.locator(selectors.table);
    return {
        el: entryEl,
        get user() {
            return entryEl.locator(selectors.user);
        },
        get date() {
            return entryEl.locator(selectors.date);
        },
        get operation() {
            return entryEl.locator(selectors.operation);
        },
        getFieldUpdate(field) {
            return fieldUpdate(tableEl, selectors.field, { field });
        },
        fieldUpdatesCount() {
            return tableEl.locator(selectors.field).count();
        }
    };
}
var ExpandButtonType;
(function (ExpandButtonType) {
    ExpandButtonType["Collapse"] = "collapse";
    ExpandButtonType["Expand"] = "expand";
})(ExpandButtonType || (ExpandButtonType = {}));
function fieldUpdate(parentEl, fieldSelector, options) {
    return __awaiter(this, void 0, void 0, function* () {
        const selectors = {
            field: fieldSelector,
            title: (0, getSelector_1.getSelector)({
                testid: "audit-field-title"
            }),
            oldValue: (0, getSelector_1.getSelector)({
                testid: `audit-value-old`
            }),
            newValue: (0, getSelector_1.getSelector)({
                testid: `audit-value-new`
            }),
            diff: (0, getSelector_1.getSelector)({
                testid: "audit-value-diff"
            }),
            expandButton: (0, getSelector_1.getSelector)({
                testid: "audit-expand-button"
            })
        };
        let el;
        if (options.index) {
            el = parentEl.locator(selectors.field).nth(options.index);
        }
        else {
            el = parentEl.locator(`${selectors.field}:has(${selectors.title}:has-text("${options.field}"))`);
        }
        const diffEl = el.locator(selectors.diff);
        const type = (yield diffEl.isVisible()) ? "multiline" : "base";
        const expandButton = el.locator(selectors.expandButton);
        return {
            el,
            title() {
                return __awaiter(this, void 0, void 0, function* () {
                    return el.locator(selectors.title).textContent();
                });
            },
            oldValue() {
                return __awaiter(this, void 0, void 0, function* () {
                    if (type == "multiline")
                        return diffEl.getAttribute((0, getSelector_1.getAttribute)("old"));
                    return el.locator(selectors.oldValue).textContent();
                });
            },
            newValue() {
                return __awaiter(this, void 0, void 0, function* () {
                    if (type == "multiline")
                        return diffEl.getAttribute((0, getSelector_1.getAttribute)("new"));
                    return el.locator(selectors.newValue).textContent();
                });
            },
            get expandButton() {
                return expandButton;
            },
            canExpand() {
                return __awaiter(this, void 0, void 0, function* () {
                    const type = yield expandButton.getAttribute((0, getSelector_1.getAttribute)("type"));
                    return type == ExpandButtonType.Expand;
                });
            },
            canCollapse() {
                return __awaiter(this, void 0, void 0, function* () {
                    const type = yield expandButton.getAttribute((0, getSelector_1.getAttribute)("type"));
                    return type == ExpandButtonType.Collapse;
                });
            }
        };
    });
}
