"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const mdt_1 = require("../../../api/mdt");
const form_steps_1 = require("../form.steps");
const test_1 = require("@playwright/test");
(0, mdt_1.When)("в журнале аудита нажимаем кнопку загрузить ещё.", function () {
    return __awaiter(this, void 0, void 0, function* () {
        const form = yield (0, form_steps_1.getForm)(this);
        const audit = yield form.getAudit();
        yield audit.loadMore.click();
    });
});
(0, mdt_1.When)("разворачиваем изменение поля {string} в последней записи аудита.", function (field) {
    return __awaiter(this, void 0, void 0, function* () {
        const modify = yield getLastChange(this);
        const fieldUpdate = yield modify.getFieldUpdate(field);
        yield fieldUpdate.expandButton.click();
    });
});
(0, mdt_1.Then)("записей в аудите: {int}.", function (count) {
    return __awaiter(this, void 0, void 0, function* () {
        const form = yield (0, form_steps_1.getForm)(this);
        const audit = yield form.getAudit();
        const entriesCount = yield audit.entriesCount();
        (0, test_1.expect)(entriesCount).toBe(count);
    });
});
(0, mdt_1.Then)("в аудите нет кнопки загрузить ещё.", function () {
    return __awaiter(this, void 0, void 0, function* () {
        const form = yield (0, form_steps_1.getForm)(this);
        const audit = yield form.getAudit();
        yield (0, test_1.expect)(audit.loadMore).toBeHidden();
    });
});
(0, mdt_1.Then)("в аудите последнее изменение сделано {string} пользователем {string} с типом {string}.", function (dateTime, userName, updateType) {
    return __awaiter(this, void 0, void 0, function* () {
        const form = yield (0, form_steps_1.getForm)(this);
        const audit = yield form.getAudit();
        const entry = yield audit.lastChange();
        (0, test_1.expect)(yield entry.date.textContent()).toSoftEqual(dateTime);
        (0, test_1.expect)(yield entry.user.textContent()).toBe(userName);
        (0, test_1.expect)(yield entry.operation.textContent()).toBe(updateType);
    });
});
(0, mdt_1.Then)("в последней записи аудита поле {string} изменено с {string} на {string}.", function (field, oldValue, newValue) {
    return __awaiter(this, void 0, void 0, function* () {
        const modify = yield getLastChange(this);
        const fieldUpdate = yield modify.getFieldUpdate(field);
        (0, test_1.expect)({
            field,
            oldValue: yield fieldUpdate.oldValue(),
            newValue: yield fieldUpdate.newValue()
        }).toEqual({
            field,
            oldValue,
            newValue
        });
    });
});
/**
 * Для проверки многострочного значения
 */
(0, mdt_1.Then)("в последней записи аудита поле {string} изменено на", function (field, newValue) {
    return __awaiter(this, void 0, void 0, function* () {
        const modify = yield getLastChange(this);
        const fieldUpdate = yield modify.getFieldUpdate(field);
        (0, test_1.expect)(yield fieldUpdate.newValue()).toBe(newValue);
    });
});
(0, mdt_1.Then)("в последней записи аудита изменено полей {int}.", function (count) {
    return __awaiter(this, void 0, void 0, function* () {
        const modify = yield getLastChange(this);
        (0, test_1.expect)(yield modify.fieldUpdatesCount()).toBe(count);
    });
});
(0, mdt_1.Then)("в последней записи аудита поле {string} можно развернуть.", function (field) {
    return __awaiter(this, void 0, void 0, function* () {
        const modify = yield getLastChange(this);
        const fieldUpdate = yield modify.getFieldUpdate(field);
        (0, test_1.expect)(yield fieldUpdate.canExpand()).toBe(true);
    });
});
function getLastChange(page) {
    return __awaiter(this, void 0, void 0, function* () {
        const form = yield (0, form_steps_1.getForm)(page);
        const audit = yield form.getAudit();
        return yield audit.lastChange();
    });
}
