"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getAggregation = exports.getColumnMenu = void 0;
const getSelector_1 = require("../../../utils/getSelector");
const quickFilter_1 = require("./quickFilter/quickFilter");
const valuesFilter_1 = require("./valuesFilter/valuesFilter");
function getColumnMenu(dropdown) {
    const el = dropdown.el;
    return {
        el,
        itemByTitle(itemTitle) {
            return dropdown.itemByTitle(itemTitle);
        },
        get sortAsc() {
            const el = dropdown.item.locator(`:scope:has(.icon-sort-amount-down)`);
            return {
                el,
                isActive() {
                    return __awaiter(this, void 0, void 0, function* () {
                        return yield el.locator(".active").isVisible();
                    });
                }
            };
        },
        get sortDesc() {
            const el = dropdown.item.locator(`:scope:has(.icon-sort-amount-up)`);
            return {
                el,
                isActive() {
                    return __awaiter(this, void 0, void 0, function* () {
                        return yield el.locator(".active").isVisible();
                    });
                }
            };
        },
        get aggregation() {
            return dropdown.item.locator(`:scope:has(.icon-sigma)`);
        },
        getQuickFilter() {
            return (0, quickFilter_1.getQuickFilter)(dropdown.item);
        },
        get valuesFilter() {
            return (0, valuesFilter_1.getValuesFilter)(dropdown.item);
        },
        isExist() {
            return __awaiter(this, void 0, void 0, function* () {
                const getQuickFilter = (testId) => el.locator((0, getSelector_1.getSelector)({ testid: testId })).isVisible();
                const quickFilter = yield getQuickFilter("quick-filter");
                const quickDateFilter = yield getQuickFilter("date");
                const isQuickFilterExist = quickFilter || quickDateFilter;
                const isElExist = yield el.isVisible();
                const isValuesFilterExist = yield this.valuesFilter.input.isExistAsync();
                return isElExist && isQuickFilterExist && isValuesFilterExist;
            });
        }
    };
}
exports.getColumnMenu = getColumnMenu;
function getAggregation(dropdown) {
    const el = dropdown.el;
    const itemSelector = (0, getSelector_1.getSelector)({
        testid: "aggregation-cm-item"
    });
    return {
        el,
        itemByTitle(title) {
            const titleSelector = (0, getSelector_1.getSelector)({
                testid: "aggregation-cm-item-title"
            });
            const itemEl = dropdown.item.locator(`${itemSelector}:has(${titleSelector}:text-is("${title}"))`);
            return {
                el: itemEl,
                value() {
                    return itemEl
                        .locator((0, getSelector_1.getSelector)({
                        testid: "aggregation-cm-item-value"
                    }))
                        .textContent();
                }
            };
        },
        itemsLength() {
            return dropdown.actionsLength();
        }
    };
}
exports.getAggregation = getAggregation;
