"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getValuesFilter = void 0;
const getSelector_1 = require("../../../../utils/getSelector");
const checkbox_1 = require("../../../form/Field/fieldControls/checkbox/checkbox");
const text_1 = require("../../../form/Field/fieldControls/text/text");
const VALUES_FILTER_TIMEOUT = 1200;
function getValuesFilter(parentEl) {
    const valuesFilterItem = parentEl.locator((0, getSelector_1.getSelector)({ testid: "values-filter" }));
    const values = parentEl.locator((0, getSelector_1.getSelector)({ testid: "values-filter-checkboxes" }));
    return {
        input: (0, text_1.getInputControl)(valuesFilterItem.locator((0, getSelector_1.getSelector)({ testid: "values-filter-input" }))),
        waitForLoading() {
            return __awaiter(this, void 0, void 0, function* () {
                const loading = values.locator((0, getSelector_1.getSelector)({ testid: "more-loading" }));
                if (yield loading.isVisible())
                    yield loading.waitFor({
                        state: "hidden"
                    });
            });
        },
        waitForChange() {
            return __awaiter(this, void 0, void 0, function* () {
                yield new Promise((resolve) => setTimeout(resolve, VALUES_FILTER_TIMEOUT));
            });
        },
        values: getColumnMenuValues(values)
    };
}
exports.getValuesFilter = getValuesFilter;
function getColumnMenuValues(parentEl) {
    const values = parentEl;
    const allChecked = values.locator((0, getSelector_1.getSelector)({ testid: "filter-checkbox", allChecked: "true" }));
    const item = values.locator((0, getSelector_1.getSelector)({ testid: "filter-checkbox" }));
    return {
        el: values,
        get selectAllItem() {
            const valueItem = (0, checkbox_1.getCheckbox)(allChecked);
            return getValueItem(valueItem);
        },
        scrollToLast() {
            return __awaiter(this, void 0, void 0, function* () {
                item.last().scrollIntoViewIfNeeded();
            });
        },
        item(index) {
            return getValueItem(item.nth(index));
        },
        get(itemTitle) {
            return __awaiter(this, void 0, void 0, function* () {
                const valueItem = item.locator(`:has-text("${itemTitle}")`);
                const count = yield valueItem.count();
                for (let i = 0; i < count; i++) {
                    const valueItemLocator = valueItem.nth(i);
                    return getValueItem(valueItemLocator);
                }
            });
        },
        isAllSelected() {
            return __awaiter(this, void 0, void 0, function* () {
                const count = yield item.count();
                for (let i = 0; i < count; i++) {
                    const valueItemLocator = item.nth(i);
                    const valueItem = getValueItem(valueItemLocator);
                    const value = yield valueItem.value();
                    if ((0, checkbox_1.getBooleanFromData)(value))
                        return false;
                }
                return true;
            });
        }
    };
}
function getValueItem(itemEl) {
    const el = itemEl;
    return {
        el,
        title: el.locator("label"),
        checkbox: (0, checkbox_1.getCheckbox)(el),
        value() {
            return __awaiter(this, void 0, void 0, function* () {
                return (0, checkbox_1.getBooleanData)(el);
            });
        }
    };
}
