"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const cucumber_1 = require("@cucumber/cucumber");
const list_steps_1 = require("../../list.steps");
const test_1 = require("@playwright/test");
const tableManager_1 = require("../../../../utils/tableManager");
const asyncArray_1 = require("../../../../utils/asyncArray");
const numberAndIndex_1 = require("../../../../utils/numberAndIndex");
const rowCompare_steps_1 = require("../../steps/rowCompare.steps");
(0, cucumber_1.Given)("в списке записи сгруппированы по полю {string}.", function (field) {
    return __awaiter(this, void 0, void 0, function* () {
        const list = yield (0, list_steps_1.getList)(this);
        const headerRow = list.getHeaderRow();
        const cells = yield headerRow.groupingCells();
        if (cells.length > 1)
            throw new Error("Записи сгруппированы по нескольким полям");
        const groupingBy = yield cells[0].getDescription();
        (0, test_1.expect)(groupingBy).toBe(field);
    });
});
(0, cucumber_1.Given)("в списке записи сгруппированы по полям:", function (dataTable) {
    return __awaiter(this, void 0, void 0, function* () {
        const list = yield (0, list_steps_1.getList)(this);
        const headerRow = list.getHeaderRow();
        const cells = yield headerRow.groupingCells();
        const groupingFields = yield (0, asyncArray_1.asyncMap)(cells, (cell) => cell.getDescription());
        const fields = (0, tableManager_1.getRowData)(dataTable);
        (0, test_1.expect)(groupingFields).toEqual(fields);
    });
});
(0, cucumber_1.Given)("в списке есть группировочная строка {string}.", function (path) {
    return __awaiter(this, void 0, void 0, function* () {
        const list = yield (0, list_steps_1.getList)(this);
        const gr = list.getGroupingRow(path);
        yield (0, test_1.expect)(gr.el).toBeVisible();
    });
});
(0, cucumber_1.Given)("группировочная строка содержит записи:", function (dataTable) {
    return __awaiter(this, void 0, void 0, function* () {
        const list = yield (0, list_steps_1.getList)(this);
        const listData = (0, tableManager_1.getListData)(dataTable);
        const gr = list.getGroupingRow();
        yield expectExactlyGroupDataRows(gr, listData, list.getHeaderRow());
    });
});
(0, cucumber_1.Given)("у группировочной строки {string} нет метки и иконки.", function (path) {
    return __awaiter(this, void 0, void 0, function* () {
        const list = yield (0, list_steps_1.getList)(this);
        const gr = list.getGroupingRow(path);
        yield (0, test_1.expect)(gr.labelIcon.el).toBeHidden();
        yield (0, test_1.expect)(gr.labelMark).toBeHidden();
    });
});
(0, cucumber_1.Given)("у группировочной строки {string} есть метка {string} и иконка {string}.", function (path, mark, icon) {
    return __awaiter(this, void 0, void 0, function* () {
        const list = yield (0, list_steps_1.getList)(this);
        const gr = list.getGroupingRow(path);
        (0, test_1.expect)(yield gr.labelMark.textContent()).toBe(mark);
        (0, test_1.expect)(yield gr.labelIcon.getCode()).toBe(icon);
    });
});
(0, cucumber_1.Given)("у группировочной строки {string} есть иконка {string}.", function (path, icon) {
    return __awaiter(this, void 0, void 0, function* () {
        const list = yield (0, list_steps_1.getList)(this);
        const gr = list.getGroupingRow(path);
        (0, test_1.expect)(yield gr.labelIcon.getCode()).toBe(icon);
    });
});
(0, cucumber_1.When)("нажимаем на группировочную строку {string}.", function (path) {
    return __awaiter(this, void 0, void 0, function* () {
        const list = yield (0, list_steps_1.getList)(this);
        const gr = list.getGroupingRow(path);
        yield gr.el.click();
    });
});
(0, cucumber_1.Then)("группировка сворачивается.", function () {
    return __awaiter(this, void 0, void 0, function* () {
        const list = yield (0, list_steps_1.getList)(this);
        const gr = list.getGroupingRow();
        const isOpen = yield gr.isCollapsed();
        (0, test_1.expect)(isOpen).toBeTruthy();
    });
});
(0, cucumber_1.Then)("группировка разворачивается.", function () {
    return __awaiter(this, void 0, void 0, function* () {
        const list = yield (0, list_steps_1.getList)(this);
        const gr = list.getGroupingRow();
        const isOpen = yield gr.isOpen();
        (0, test_1.expect)(isOpen).toBeTruthy();
    });
});
(0, cucumber_1.When)("нажимаем кнопку редактирования записи №{int} в группировке.", function (rowNumber) {
    return __awaiter(this, void 0, void 0, function* () {
        const list = yield (0, list_steps_1.getList)(this);
        const gr = list.getGroupingRow();
        const row = gr.getChildDataRow(rowNumber, list.getHeaderRow());
        yield row.formOpener.click();
    });
});
(0, cucumber_1.When)("нажимаем кнопку редактирования группировочной строки.", function () {
    return __awaiter(this, void 0, void 0, function* () {
        const list = yield (0, list_steps_1.getList)(this);
        const gr = list.getGroupingRow();
        yield gr.formOpener.click();
    });
});
// И в списке будет группировочная строка "Дата | 31.10.2022 > Доставка > Машина | 11.11.2022 12:00:00".
(0, cucumber_1.Then)("в списке будет группировочная строка {string}.", function (path) {
    return __awaiter(this, void 0, void 0, function* () {
        const list = yield (0, list_steps_1.getList)(this);
        const gr = list.getGroupingRow(path);
        yield (0, test_1.expect)(gr.el).toBeVisible();
    });
});
(0, cucumber_1.Then)("в списке нет группировочной строки {string}.", function (path) {
    return __awaiter(this, void 0, void 0, function* () {
        const list = yield (0, list_steps_1.getList)(this);
        const gr = list.getGroupingRow(path);
        yield (0, test_1.expect)(gr.el).toBeHidden();
    });
});
(0, cucumber_1.Then)("в списке есть {int} группировки {string}.", function (count, path) {
    return __awaiter(this, void 0, void 0, function* () {
        const list = yield (0, list_steps_1.getList)(this);
        const gr = list.getGroupingRow(path);
        yield (0, test_1.expect)(gr.el).toHaveCount(count);
    });
});
(0, cucumber_1.Then)("в группировке №{int} есть записи:", function (groupNumber, dataTable) {
    return __awaiter(this, void 0, void 0, function* () {
        const list = yield (0, list_steps_1.getList)(this);
        const listData = (0, tableManager_1.getListData)(dataTable);
        const gr = list.getGroupingRow();
        gr.takeByNumber(groupNumber);
        yield expectExactlyGroupDataRows(gr, listData, list.getHeaderRow());
    });
});
(0, cucumber_1.Then)("в группировке есть записи:", function (dataTable) {
    return __awaiter(this, void 0, void 0, function* () {
        const list = yield (0, list_steps_1.getList)(this);
        const listData = (0, tableManager_1.getListData)(dataTable);
        const gr = list.getGroupingRow();
        yield expectExactlyGroupDataRows(gr, listData, list.getHeaderRow());
    });
});
(0, cucumber_1.Then)("в группировке записи содержат следующие значения:", function (dataTable) {
    return __awaiter(this, void 0, void 0, function* () {
        const list = yield (0, list_steps_1.getList)(this);
        const listData = (0, tableManager_1.getListData)(dataTable);
        const gr = list.getGroupingRow();
        yield expectRowsValues(gr, listData, list.getHeaderRow());
    });
});
(0, cucumber_1.Then)("группировочная строка содержит класс {string}.", function (className) {
    return __awaiter(this, void 0, void 0, function* () {
        const list = yield (0, list_steps_1.getList)(this);
        const gr = list.getGroupingRow();
        yield (0, test_1.expect)(gr.el).toHaveClass(new RegExp(className));
    });
});
(0, cucumber_1.Then)("группировочная строка не содержит класс {string}.", function (className) {
    return __awaiter(this, void 0, void 0, function* () {
        const list = yield (0, list_steps_1.getList)(this);
        const gr = list.getGroupingRow();
        yield (0, test_1.expect)(gr.el).not.toHaveClass(new RegExp(className));
    });
});
/**
 * Следующая запись должна быть группировкой или не существовать
 */
(0, cucumber_1.Then)("записи группировки не отображены.", function () {
    return __awaiter(this, void 0, void 0, function* () {
        const list = yield (0, list_steps_1.getList)(this);
        const gr = list.getGroupingRow();
        const childRow = gr.getChildDataRow(1, list.getHeaderRow());
        const childRowNotExist = yield childRow.el.isHidden();
        (0, test_1.expect)(childRowNotExist).toBeTruthy();
    });
});
function expectRowsValues(groupingRow, listData, headerRow) {
    return __awaiter(this, void 0, void 0, function* () {
        yield (0, asyncArray_1.asyncForEach)(listData.getRows(), (dataRow, rowIndex) => __awaiter(this, void 0, void 0, function* () {
            const listRow = groupingRow.getChildDataRow((0, numberAndIndex_1.getNumberFromIndex)(rowIndex), headerRow);
            yield (0, test_1.expect)(listRow.el).toBeVisible();
            yield (0, asyncArray_1.asyncForEach)(listData.getHeaderRow(), (columnTitle, valueIndex) => __awaiter(this, void 0, void 0, function* () {
                const cell = yield listRow.getCellAsync(columnTitle);
                const cellValue = yield cell.value();
                (0, test_1.expect)(cellValue).toSoftEqual(dataRow[valueIndex]);
            }));
        }));
    });
}
function expectExactlyGroupDataRows(groupingRow, listData, headerRow) {
    return __awaiter(this, void 0, void 0, function* () {
        yield (0, asyncArray_1.asyncForEach)(listData.getRows(), (dataRow, index) => __awaiter(this, void 0, void 0, function* () {
            const listRow = groupingRow.getChildDataRow(index + 1, headerRow);
            yield (0, test_1.expect)(listRow.el).toBeVisible();
            yield (0, rowCompare_steps_1.rowCompare)(listRow, dataRow, {
                hasSelect: false
            });
        }));
    });
}
