"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.List = exports.LIST_SELECTOR = void 0;
const setup_1 = require("../../../setup/setup");
const numberAndIndex_1 = require("../../utils/numberAndIndex");
const progressBar_1 = require("../progressBar/progressBar");
const headerRow_1 = require("./headerRow/headerRow");
const listToolbar_1 = require("./listToolbar/listToolbar");
const row_1 = require("./row/row");
const groupingRow_1 = require("./extenders/grouping/groupingRow");
const featureManager_1 = require("../../utils/featureManager");
const hierarchyRow_1 = require("./extenders/hierarchy/hierarchyRow");
const getSelector_1 = require("../../utils/getSelector");
const aggregationRow_1 = require("./aggregationRow/aggregationRow");
const asyncArray_1 = require("../../utils/asyncArray");
const indexData_1 = require("../../utils/indexData");
const customMatchers_1 = require("../../utils/customMatchers");
const skeleton_1 = require("../progressBar/skeleton/skeleton");
exports.LIST_SELECTOR = (0, getSelector_1.getSelector)({ testid: "grid-outer" });
class List {
    constructor(parentEl) {
        this.el = parentEl.locator(exports.LIST_SELECTOR);
    }
    get tbody() {
        return this.el.locator(".grid tbody");
    }
    get progressBar() {
        return (0, progressBar_1.getProgressBar)(this.el.locator(".grid-progress-wrap"));
    }
    get tr() {
        return this.tbody.locator(`tr`);
    }
    useFirst() {
        this.el = this.el.first();
    }
    get footer() {
        return this.el.locator((0, getSelector_1.getSelector)({
            testid: "grid-footer"
        }));
    }
    get toolbar() {
        return (0, listToolbar_1.getListToolbar)(this.el.locator(".grid-toolbar"));
    }
    getRow(rowNumber) {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.hasAggregation == void 0) {
                this.hasAggregation = yield (0, aggregationRow_1.isAggregationRowExist)(this.tbody);
            }
            if (this.hasAggregation)
                rowNumber += 1;
            const rowIndex = (0, numberAndIndex_1.getIndexFromNumber)(rowNumber);
            const rowEl = this.tr.nth(rowIndex);
            return (0, row_1.getRow)(rowEl, this.getHeaderRow());
        });
    }
    getColumnsIndexes(columns) {
        return __awaiter(this, void 0, void 0, function* () {
            const listColumns = yield (0, asyncArray_1.asyncMap)(yield this.getHeaderRow().getAllCells(), (cell) => cell.value());
            // Собираем объект { [поле]: индекс поля в списке }
            return (0, indexData_1.getIndexes)(columns, listColumns, (key) => {
                throw new Error(`Поля "${key}" нет в списке.`);
            });
        });
    }
    findSimilar(record, columnIndexes) {
        return __awaiter(this, void 0, void 0, function* () {
            const headerRow = this.getHeaderRow();
            for (let i = 0; yield this.tr.nth(i).isVisible(); i++) {
                const row = (0, row_1.getRow)(this.tr.nth(i), headerRow);
                if (yield this.areRowSimilar(row, record, columnIndexes)) {
                    return row;
                }
            }
            return;
        });
    }
    areRowSimilar(row, record, columnIndexes) {
        return __awaiter(this, void 0, void 0, function* () {
            for (let key in record) {
                const cell = yield row.getCellByIndex(columnIndexes[key]);
                const value = yield cell.value();
                if (!(0, customMatchers_1.areSoftEqual)(record[key], value))
                    return false;
            }
            return true;
        });
    }
    getAggregationRow() {
        return (0, row_1.getRow)(this.tr.nth(0), this.getHeaderRow());
    }
    getGroupingRow(groupLabelsHierarchy) {
        let gr = void 0;
        if (groupLabelsHierarchy) {
            gr = (0, groupingRow_1.getGroupingRow)(this.tbody, groupLabelsHierarchy);
            featureManager_1.default.context.setValue("groupingRow", gr);
        }
        else
            gr = featureManager_1.default.context.getValue("groupingRow");
        return gr;
    }
    getHierarchyRow(rowNumber) {
        return __awaiter(this, void 0, void 0, function* () {
            return (0, hierarchyRow_1.getHierarchyRow)(yield this.getRow(rowNumber), {
                getNextRow: (nextRowNumber) => this.getRow(rowNumber + nextRowNumber),
                tbody: this.tbody
            });
        });
    }
    displayRowsCount() {
        return this.tr.count();
    }
    isReady() {
        return __awaiter(this, void 0, void 0, function* () {
            yield this.el.waitFor();
            yield this.getSkeleton().waitForCompleteIfExist();
            yield this.progressBar.waitForComplete();
            yield this.el.locator(".grid-wrap").waitFor();
            yield this.tbody.waitFor({
                timeout: setup_1.config.largeTimeout
            });
            return yield this.progressBar.isComplete();
        });
    }
    getSkeleton() {
        return new skeleton_1.Skeleton(this.el);
    }
    getHeaderRow() {
        return (0, headerRow_1.getHeaderRow)(this.el.locator(".grid thead"));
    }
    formOpener(rowNumber) {
        return __awaiter(this, void 0, void 0, function* () {
            const listRow = yield this.getRow(rowNumber);
            return listRow.formOpener;
        });
    }
    selectRowCell(rowNumber) {
        return __awaiter(this, void 0, void 0, function* () {
            const listRow = yield this.getRow(rowNumber);
            const selectCell = yield listRow.selectCell();
            return selectCell;
        });
    }
    selectAllRowsAsync() {
        return __awaiter(this, void 0, void 0, function* () {
            const selectCell = yield this.getHeaderRow().selectCell();
            yield selectCell.el.click();
            yield this.isReady();
        });
    }
    isEmpty() {
        return __awaiter(this, void 0, void 0, function* () {
            const hasEmptyRow = yield this.tbody.locator(".empty-row").isVisible();
            const hasEmptyText = (yield this.tbody.textContent()) == "(нет записей)";
            return hasEmptyRow && hasEmptyText;
        });
    }
}
exports.List = List;
