"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.setCellValue = exports.getRowCell = exports.getRow = void 0;
const asyncArray_1 = require("../../../utils/asyncArray");
const dateMatcher_1 = require("../../../utils/dateMatcher");
const isNullOrEmpty_1 = require("../../../utils/isNullOrEmpty");
const numberAndIndex_1 = require("../../../utils/numberAndIndex");
const getSelector_1 = require("../../../utils/getSelector");
const controls_1 = require("../../form/Field/fieldControls/controls");
function getRow(row, headerRow) {
    const el = row;
    const formOpener = (0, getSelector_1.getSelector)({
        testid: "form-opener"
    });
    return {
        el,
        getRowNumber() {
            return __awaiter(this, void 0, void 0, function* () {
                const elementIndex = yield this.el.evaluate((el) => {
                    return Array.from(el.parentElement.children).indexOf(el);
                });
                return elementIndex + 1;
            });
        },
        getCellAsync(columnTitle) {
            return __awaiter(this, void 0, void 0, function* () {
                const cellNumber = yield this.getCellNumberByTitle(columnTitle);
                const cell = this.getCellByIndex((0, numberAndIndex_1.getIndexFromNumber)(cellNumber));
                return cell;
            });
        },
        getCellNumberByTitle(columnTitle) {
            return __awaiter(this, void 0, void 0, function* () {
                const headerCells = yield headerRow.getAllCells();
                const idx = yield (0, asyncArray_1.asyncFindIndex)(headerCells, (cell) => __awaiter(this, void 0, void 0, function* () { return (yield cell.value()) == columnTitle; }));
                return (0, numberAndIndex_1.getNumberFromIndex)(idx);
            });
        },
        getCellByIndex(cellIndex) {
            return getRowCell(this.el.locator(`td`).nth(cellIndex));
        },
        formOpener: el.locator(`td ${formOpener}`),
        formOpenerCell: getRowCell(el.locator(`td:has(${formOpener})`)),
        selectCell() {
            return __awaiter(this, void 0, void 0, function* () {
                const cells = yield this.getAllCells();
                const selectCellIndex = yield (0, asyncArray_1.asyncFindIndex)(cells, (cell) => __awaiter(this, void 0, void 0, function* () {
                    const isSelect = yield cell.isSelect();
                    return isSelect;
                }));
                return this.getCellByIndex(selectCellIndex);
            });
        },
        cellsCount() {
            return __awaiter(this, void 0, void 0, function* () {
                const count = yield this.el.locator("td").count();
                return count;
            });
        },
        getAllCells() {
            return __awaiter(this, void 0, void 0, function* () {
                const cells = [];
                const cellsCount = yield this.cellsCount();
                for (let i = 0; i < cellsCount; i++) {
                    const rowCell = this.getCellByIndex(i);
                    cells.push(rowCell);
                }
                return cells;
            });
        },
        getFieldsCells() {
            return __awaiter(this, void 0, void 0, function* () {
                const cells = [];
                const headerCells = yield headerRow.getAllCells();
                yield (0, asyncArray_1.asyncForEach)(headerCells, (cell, i) => __awaiter(this, void 0, void 0, function* () {
                    if (yield cell.isSelect())
                        return;
                    if (yield cell.isFormOpener())
                        return;
                    if ((0, isNullOrEmpty_1.isNullOrEmpty)(yield cell.value()))
                        return;
                    const rowCell = this.getCellByIndex(i);
                    cells.push(rowCell);
                }));
                return cells;
            });
        },
        cellsValue(options) {
            return __awaiter(this, void 0, void 0, function* () {
                const result = [];
                if (options === null || options === void 0 ? void 0 : options.hasSelect) {
                    const selectCell = yield this.selectCell();
                    const cellValue = yield selectCell.value();
                    result.push(cellValue);
                }
                const start = yield headerRow.firstFieldCellIndex();
                const cellsCount = yield this.cellsCount();
                for (let i = start; i < cellsCount; i++) {
                    const cell = this.getCellByIndex(i);
                    const cellValue = yield cell.value();
                    result.push(cellValue);
                }
                return result;
            });
        },
        isDisabled() {
            var _a;
            return __awaiter(this, void 0, void 0, function* () {
                const classList = yield this.el.getAttribute("class");
                if (!classList)
                    return false;
                return ((_a = classList.match(/deactivated/)) === null || _a === void 0 ? void 0 : _a.length) == 1;
            });
        },
        getAction(actionTitle) {
            return this.el.locator(`a:has-text("${actionTitle}")`);
        },
        canDragDrop() {
            return this.el
                .locator((0, getSelector_1.getSelector)({
                testid: "dragdrop-handle"
            }))
                .isVisible();
        },
        canDragDropInto() {
            return this.el.getAttribute((0, getSelector_1.getAttribute)("row-dragdrop", "into")).then((v) => !!v);
        }
    };
}
exports.getRow = getRow;
function getRowCell(cell) {
    const el = cell;
    return {
        el,
        isSelect() {
            var _a;
            return __awaiter(this, void 0, void 0, function* () {
                const classList = yield this.el.getAttribute("class");
                if (!classList)
                    return false;
                return ((_a = classList.match(/select-cell/)) === null || _a === void 0 ? void 0 : _a.length) == 1;
            });
        },
        isReadonly() {
            return __awaiter(this, void 0, void 0, function* () {
                yield el.click();
                const cellContent = yield el.innerHTML();
                yield el.dblclick();
                yield el.press("F2");
                const isContentNotChanged = cellContent == (yield el.innerHTML());
                return isContentNotChanged;
            });
        },
        getClasses() {
            return __awaiter(this, void 0, void 0, function* () {
                const classList = yield this.el.evaluate((el) => [...el.classList]);
                return classList;
            });
        },
        value() {
            return __awaiter(this, void 0, void 0, function* () {
                const control = yield (0, controls_1.getControl)(this.el);
                if (control)
                    return yield control.displayValueAsync();
                if (yield cell.locator(".selector-link").isVisible()) {
                    const cellValue = yield cell.locator(".selector-link").textContent();
                    return cellValue;
                }
                if (yield cell.locator(".value-wrap, .word-wrap").isVisible()) {
                    const cellValue = yield cell.locator(".value-wrap, .word-wrap").textContent();
                    return cellValue;
                }
                const cellValue = yield cell.textContent();
                return cellValue.trim();
            });
        },
        edit() {
            return __awaiter(this, void 0, void 0, function* () {
                yield el.click();
                yield el.press("F2");
                yield el.hover();
            });
        },
        image(number) {
            const index = number ? (0, numberAndIndex_1.getIndexFromNumber)(number) : 0;
            return el.locator((0, getSelector_1.getSelector)({ testid: "file-image-content" })).nth(index);
        },
        clearValue() {
            return __awaiter(this, void 0, void 0, function* () {
                yield this.edit();
                const control = yield (0, controls_1.getControl)(this.el);
                if (!control)
                    throw "Не удалось определить тип компонента в ячейке, чтобы ее очистить";
                yield (0, controls_1.clearControlValue)(control);
            });
        },
        get tagMark() {
            return el.locator((0, getSelector_1.getSelector)({
                testid: "cell-tag-mark"
            }));
        }
    };
}
exports.getRowCell = getRowCell;
function setCellValue(page, cell, value) {
    return __awaiter(this, void 0, void 0, function* () {
        yield cell.edit();
        const control = yield (0, controls_1.getControl)(cell.el);
        if (control) {
            yield (0, controls_1.setControlValue)(page, control, value);
            return;
        }
        if (yield cell.el.locator(".value-wrap, .word-wrap").isVisible()) {
            yield cell.el.type((0, dateMatcher_1.parseIfAlias)(value), { delay: 100 });
            return;
        }
    });
}
exports.setCellValue = setCellValue;
