"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const cucumber_1 = require("@cucumber/cucumber");
const test_1 = require("@playwright/test");
const setup_1 = require("../../../../../setup/setup");
const asyncArray_1 = require("../../../../utils/asyncArray");
const tableManager_1 = require("../../../../utils/tableManager");
const list_steps_1 = require("../../list.steps");
const notFoundRecords_1 = require("./notFoundRecords");
/**
 * Проверяется полное совпадение списка, включая порядок колонок, порядок записей и количество записей
 *
   Пусть в списке есть следующие записи:
   |     | Наименования_поля | Булево_поле | Поле_с_датой   |
   | [ ] | Значение_1        | [ ]         | 29.02.2024     |
   | [ ] | Значение_2        | [x]         | {текущая дата} |
   | [ ] | Значение_3        | [-]         |                |
 */
(0, cucumber_1.Then)("список выглядит следующим образом:", { timeout: setup_1.config.largeTimeout }, function (dataTable) {
    return __awaiter(this, void 0, void 0, function* () {
        const list = yield (0, list_steps_1.getList)(this);
        const listData = (0, tableManager_1.getListData)(dataTable);
        yield expectExactlyMatchList(list, listData);
    });
});
function expectExactlyMatchList(list, listData) {
    return __awaiter(this, void 0, void 0, function* () {
        yield expectExactlyHeaderRow(list.getHeaderRow(), listData.getHeaderRow());
        yield expectExacltyMatchRows(list, listData);
    });
}
function expectExactlyHeaderRow(headerRow, listDataHeaderRow) {
    return __awaiter(this, void 0, void 0, function* () {
        yield (0, asyncArray_1.asyncForEach)(listDataHeaderRow, (value, index) => __awaiter(this, void 0, void 0, function* () {
            const cellValue = yield headerRow.getCellByIndex(index).value();
            (0, test_1.expect)(cellValue).toBe(value);
        }));
    });
}
function expectExacltyMatchRows(list, listData) {
    return __awaiter(this, void 0, void 0, function* () {
        const listRowsCount = yield list.displayRowsCount();
        const records = listData.getRecords();
        if (listRowsCount != records.length)
            throw "Количество записей не совпадает";
        const headerRow = listData.getHeaderRow();
        const notFoundRecords = yield (0, notFoundRecords_1.getNotFoundRecords)(records, list, (row) => {
            return (0, asyncArray_1.asyncMap)(headerRow, (column, i) => {
                return row.getCellByIndex(i).value();
            });
        });
        (0, notFoundRecords_1.showNotFoundRecord)(notFoundRecords);
    });
}
