"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.listContainRecordsStep = void 0;
const cucumber_1 = require("@cucumber/cucumber");
const setup_1 = require("../../../../../setup/setup");
const asyncArray_1 = require("../../../../utils/asyncArray");
const tableManager_1 = require("../../../../utils/tableManager");
const list_steps_1 = require("../../list.steps");
const notFoundRecords_1 = require("./notFoundRecords");
/**
 * Учитывает порядок записей
 * НЕ учитывает порядок колонок
 *
   Пусть список содержит следующие записи:
   | Наименования_поля | Булево_поле | Поле_с_датой   |
   | Значение_1        | [ ]         | 29.02.2024     |
   | Значение_2        | [x]         | {текущая дата} |
   | Значение_3        | [-]         |                |
 */
(0, cucumber_1.Given)("список содержит следующие записи:", { timeout: setup_1.config.largeTimeout }, function (dataTable) {
    return __awaiter(this, void 0, void 0, function* () {
        yield listContainRecordsStep(this, dataTable);
    });
});
/**
 * Учитывает порядок записей
 * НЕ учитывает порядок колонок
 *
   Пусть список содержит следующие записи:
   | Наименования_поля | Булево_поле | Поле_с_датой   |
   | Значение_1        | [ ]         | 29.02.2024     |
   | Значение_2        | [x]         | {текущая дата} |
   | Значение_3        | [-]         |                |
 */
(0, cucumber_1.Then)("список будет содержать следующие записи:", { timeout: setup_1.config.largeTimeout }, function (dataTable) {
    return __awaiter(this, void 0, void 0, function* () {
        yield listContainRecordsStep(this, dataTable);
    });
});
function listContainRecordsStep(page, dataTable) {
    return __awaiter(this, void 0, void 0, function* () {
        const list = yield (0, list_steps_1.getList)(page);
        const listData = (0, tableManager_1.getListData)(dataTable);
        yield checkListContainsRecords(list, listData);
    });
}
exports.listContainRecordsStep = listContainRecordsStep;
function checkListContainsRecords(list, listData) {
    return __awaiter(this, void 0, void 0, function* () {
        const headerRow = listData.getHeaderRow();
        const columnIndexes = yield list.getColumnsIndexes(headerRow);
        const notFoundRecords = yield (0, notFoundRecords_1.getNotFoundRecords)(listData.getRecords(), list, (row) => {
            return (0, asyncArray_1.asyncMap)(headerRow, (column) => {
                return row.getCellByIndex(columnIndexes[column]).value();
            });
        });
        (0, notFoundRecords_1.showNotFoundRecord)(notFoundRecords);
    });
}
