"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.showNotFoundRecord = exports.getNotFoundRecords = void 0;
const asyncArray_1 = require("../../../../utils/asyncArray");
const customMatchers_1 = require("../../../../utils/customMatchers");
const numberAndIndex_1 = require("../../../../utils/numberAndIndex");
function getNotFoundRecords(records, list, getRowData) {
    return __awaiter(this, void 0, void 0, function* () {
        const notFound = [];
        yield (0, asyncArray_1.asyncForEach)(records, (record, recordIndex) => __awaiter(this, void 0, void 0, function* () {
            const row = yield list.getRow((0, numberAndIndex_1.getNumberFromIndex)(recordIndex));
            if (yield row.el.isHidden()) {
                notFound.push({
                    n: recordIndex + 1,
                    row: Object.values(record)
                });
                return;
            }
            const rowData = yield getRowData(row);
            const details = [];
            Object.entries(record).forEach(([key, expected], i) => {
                const received = rowData[i];
                if ((0, customMatchers_1.areSoftEqual)(expected, received))
                    return;
                details.push({
                    fieldCode: key,
                    expected,
                    received
                });
            });
            if (details.length) {
                notFound.push({
                    n: recordIndex + 1,
                    row: Object.values(record),
                    details
                });
            }
        }));
        return notFound;
    });
}
exports.getNotFoundRecords = getNotFoundRecords;
function showNotFoundRecord(data) {
    if (data.length)
        throw buildErrorMessage(data);
}
exports.showNotFoundRecord = showNotFoundRecord;
function buildErrorMessage(data) {
    let result = `Не найдены следующие записи:`;
    data.forEach(({ n, row, details }) => {
        const recordString = row.map((v) => `${v} |`).join(" ");
        result += `\nЗапись №${n}: | ${recordString}`;
        if (details === null || details === void 0 ? void 0 : details.length) {
            details.forEach(({ fieldCode, expected, received }) => {
                result += `\n\t В поле "${fieldCode}" ожидалось "${expected || ""}" получено "${received || ""}"`;
            });
        }
    });
    return result;
}
