"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.softListCompareStep = void 0;
const cucumber_1 = require("@cucumber/cucumber");
const asyncArray_1 = require("../../../../utils/asyncArray");
const tableManager_1 = require("../../../../utils/tableManager");
const list_steps_1 = require("../../list.steps");
const notFoundRecords_1 = require("./notFoundRecords");
/**
 * Проверяет что список содержит записи
 * НЕ учитывает порядок записей
 * НЕ учитывает порядок колонок
 *
   То список содержит следующие записи в любом порядке:
   | Наименования_поля | Булево_поле | Поле_с_датой   |
   | Значение_2        | [x]         | {текущая дата} |
   | Значение_3        | [-]         |                |
   | Значение_1        | [ ]         | 29.02.2024     |
 */
(0, cucumber_1.Then)("список содержит следующие записи в любом порядке:", { timeout: 30000 }, function (dataTable) {
    return __awaiter(this, void 0, void 0, function* () {
        yield softListCompareStep(this, dataTable);
    });
});
function softListCompareStep(page, dataTable) {
    return __awaiter(this, void 0, void 0, function* () {
        const list = yield (0, list_steps_1.getList)(page);
        const listData = (0, tableManager_1.getListData)(dataTable);
        const records = listData.getRecords();
        const columnIndexes = yield list.getColumnsIndexes(listData.getHeaderRow());
        const notFound = [];
        yield (0, asyncArray_1.asyncForEach)(records, (record, recordIndex) => __awaiter(this, void 0, void 0, function* () {
            const row = yield list.findSimilar(record, columnIndexes);
            if (row)
                return;
            notFound.push({
                n: recordIndex + 1,
                row: Object.values(record)
            });
            return;
        }));
        (0, notFoundRecords_1.showNotFoundRecord)(notFound);
    });
}
exports.softListCompareStep = softListCompareStep;
