"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.rowCompare = exports.expectListRowData = void 0;
const cucumber_1 = require("@cucumber/cucumber");
const setup_1 = require("../../../../setup/setup");
const tableManager_1 = require("../../../utils/tableManager");
const list_steps_1 = require("../list.steps");
const headerCompare_steps_1 = require("./headerCompare.steps");
const test_1 = require("@playwright/test");
/**
   То в списке запись №1 будет:
   | Код | Number     | Money         | Дата     | Datetime    |
   |     | AVG: 2 000 | SUM: 3 665,00 |          | DISTINCT: 1 |
 */
(0, cucumber_1.Then)("в списке запись №{int} будет:", { timeout: setup_1.config.largeTimeout }, function (rowNumber, dataTable) {
    return __awaiter(this, void 0, void 0, function* () {
        const list = yield (0, list_steps_1.getList)(this);
        const listData = (0, tableManager_1.getListData)(dataTable);
        yield expectListRowData(list, listData.getRecords()[0], rowNumber);
    });
});
/**
   То в списке строка аггрегации содержит следующие данные:
   | Код | Number     | Money         | Дата     | Datetime    |
   |     | AVG: 2 000 | SUM: 3 665,00 |          | DISTINCT: 1 |
 */
(0, cucumber_1.Then)("в списке строка аггрегации содержит следующие данные:", function (dataTable) {
    return __awaiter(this, void 0, void 0, function* () {
        const list = yield (0, list_steps_1.getList)(this);
        const listData = (0, tableManager_1.getListData)(dataTable);
        const aggregationRecord = listData.getRecords()[0];
        const aggregationRow = list.getAggregationRow();
        const listHeaderRow = list.getHeaderRow();
        yield (0, headerCompare_steps_1.strictHeaderRowCompare)(listHeaderRow, Object.keys(aggregationRecord));
        yield rowCompare(aggregationRow, Object.values(aggregationRecord));
    });
});
function expectListRowData(list, row, rowNumber) {
    return __awaiter(this, void 0, void 0, function* () {
        const listHeaderRow = list.getHeaderRow();
        const listRow = yield list.getRow(rowNumber);
        yield (0, headerCompare_steps_1.strictHeaderRowCompare)(listHeaderRow, Object.keys(row));
        yield rowCompare(listRow, Object.values(row));
    });
}
exports.expectListRowData = expectListRowData;
function rowCompare(listRow, listDataRow, options) {
    return __awaiter(this, void 0, void 0, function* () {
        const cellsValue = yield listRow.cellsValue(options);
        (0, test_1.expect)(cellsValue).toSoftArrayEqual(listDataRow);
    });
}
exports.rowCompare = rowCompare;
