"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getModal = void 0;
const field_1 = require("../form/Field/field");
const toolbar_1 = require("../toolbar/toolbar");
const getSelector_1 = require("../../utils/getSelector");
const icon_1 = require("../icon/icon");
const selectors = (0, getSelector_1.getSelectors)({
    header: "modal-header"
});
function getModal(parentEl) {
    const element = parentEl.locator(".modal .modal-content");
    let isLast = false;
    const el = () => (isLast ? element.last() : element);
    return {
        get el() {
            return el();
        },
        titleSelector: `${selectors.header} .modal-title span`,
        contentSelector: ".modal-body",
        get header() {
            return {
                title: el().locator(this.titleSelector).first(),
                subtitle: el().locator(`${selectors.header} .modal-title small`).first()
            };
        },
        get toolbarEl() {
            return el().locator(`.modal-footer .btn-toolbar, ${selectors.header} .manage-btns`);
        },
        get toolbar() {
            return (0, toolbar_1.getToolbar)(this.toolbarEl);
        },
        get content() {
            return el().locator(this.contentSelector);
        },
        getField(fieldName) {
            return (0, field_1.getField)(this.content, fieldName);
        },
        getButton(title, byCode) {
            return __awaiter(this, void 0, void 0, function* () {
                const toolbarButton = byCode ? this.toolbar.item(title) : this.toolbar.itemByTitle(title);
                if (yield toolbarButton.isVisible())
                    return toolbarButton;
                const toolBarFromContent = (0, toolbar_1.getToolbar)(this.content);
                const contentButton = byCode ? toolBarFromContent.item(title) : toolBarFromContent.itemByTitle(title);
                if (yield contentButton.isVisible())
                    return contentButton;
                return toolbarButton;
            });
        },
        close() {
            return __awaiter(this, void 0, void 0, function* () {
                const closeIcon = (0, icon_1.getIcon)(el().locator(selectors.header), "times");
                yield closeIcon.el.click();
            });
        },
        useActive() {
            isLast = true;
        }
    };
}
exports.getModal = getModal;
