"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.expectCloseModal = exports.expectOpenModal = exports.clickButtonFromModal = void 0;
const cucumber_1 = require("@cucumber/cucumber");
const test_1 = require("@playwright/test");
const setup_1 = require("../../../setup/setup");
const tableManager_1 = require("../../utils/tableManager");
const form_steps_1 = require("../form/form.steps");
const strictListCompare_steps_1 = require("../list/steps/compare/strictListCompare.steps");
(0, cucumber_1.Given)("открыто модальное окно {string}.", function (title) {
    return __awaiter(this, void 0, void 0, function* () {
        const modal = yield this.getModal({
            title,
            waitFor: true
        });
        yield (0, test_1.expect)(modal.el).toBeVisible();
    });
});
(0, cucumber_1.When)("заполняем поля в модальном окне следующими значениями:", { timeout: setup_1.config.largeTimeout * 2 }, function (data) {
    return __awaiter(this, void 0, void 0, function* () {
        if (data.raw().length < 1)
            return false;
        const modal = yield this.getModal();
        for (const [fieldName, fieldValue] of data.raw()) {
            const field = modal.getField(fieldName);
            yield (0, form_steps_1.setValueByField)(this, field, fieldValue);
            yield this.waitForLoading();
            (0, test_1.expect)(yield field.displayValueAsync(), `Не удалось установить значение в поле ${fieldName}`).toBe(fieldValue);
        }
    });
});
(0, cucumber_1.When)("нажимаем кнопку {string} в модальном окне.", function (buttonTitle) {
    return __awaiter(this, void 0, void 0, function* () {
        yield clickButtonFromModal(this, buttonTitle);
    });
});
function clickButtonFromModal(page, buttonTitle) {
    return __awaiter(this, void 0, void 0, function* () {
        const modal = yield page.getModal();
        const button = yield modal.getButton(buttonTitle);
        yield (0, test_1.expect)(button).toBeVisible();
        yield button.click();
    });
}
exports.clickButtonFromModal = clickButtonFromModal;
(0, cucumber_1.When)("заполняем поле {string} значением {string} в модальном окне.", { timeout: setup_1.config.largeTimeout }, function (fieldName, value) {
    return __awaiter(this, void 0, void 0, function* () {
        const modal = yield this.getModal();
        const field = modal.getField(fieldName);
        yield (0, form_steps_1.setValueByField)(this, field, value);
    });
});
(0, cucumber_1.Then)("открывается модальное окно {string}.", function (title) {
    return __awaiter(this, void 0, void 0, function* () {
        yield expectOpenModal(this, title);
    });
});
(0, cucumber_1.Then)("открывается модальное окно.", function () {
    return __awaiter(this, void 0, void 0, function* () {
        yield expectOpenModal(this);
    });
});
function expectOpenModal(page, title) {
    return __awaiter(this, void 0, void 0, function* () {
        yield page.waitFor("open", {
            title,
            container: "modal"
        });
    });
}
exports.expectOpenModal = expectOpenModal;
(0, cucumber_1.Then)("в модальном окне есть сообщение {string}.", function (text) {
    return __awaiter(this, void 0, void 0, function* () {
        const modal = yield this.getModal();
        yield (0, test_1.expect)(modal.content).toContainText(text);
    });
});
(0, cucumber_1.Then)("в модальном окне есть кнопка {string}.", function (buttonTitle) {
    return __awaiter(this, void 0, void 0, function* () {
        const modal = yield this.getModal();
        const button = yield modal.getButton(buttonTitle);
        yield (0, test_1.expect)(button).toBeVisible();
    });
});
(0, cucumber_1.Then)("модальное окно {string} закрывается.", function (title) {
    return __awaiter(this, void 0, void 0, function* () {
        yield expectCloseModal(this, title);
    });
});
function expectCloseModal(page, title) {
    return __awaiter(this, void 0, void 0, function* () {
        yield page.waitFor("close", {
            title,
            container: "modal"
        });
    });
}
exports.expectCloseModal = expectCloseModal;
(0, cucumber_1.Then)("в модальном окне есть поле {string}.", function (fieldName) {
    return __awaiter(this, void 0, void 0, function* () {
        const modal = yield this.getModal();
        const field = modal.getField(fieldName);
        yield (0, test_1.expect)(field.el).toBeVisible();
    });
});
(0, cucumber_1.Then)("кнопка {string} в модальном окне активна.", function (buttonTitle) {
    return __awaiter(this, void 0, void 0, function* () {
        const modal = yield this.getModal();
        const button = yield modal.getButton(buttonTitle);
        yield (0, test_1.expect)(button).toBeVisible();
        yield (0, test_1.expect)(button).not.toHaveClass(/disabled/);
    });
});
(0, cucumber_1.Then)("кнопка {string} в модальном окне не активна.", function (buttonTitle) {
    return __awaiter(this, void 0, void 0, function* () {
        const modal = yield this.getModal();
        const button = yield modal.getButton(buttonTitle);
        yield (0, test_1.expect)(button).toBeVisible();
        yield (0, test_1.expect)(button).toHaveClass(/disabled/);
    });
});
(0, cucumber_1.Then)("в модальном окне есть список.", function () {
    return __awaiter(this, void 0, void 0, function* () {
        const list = yield this.getList({
            container: "modal"
        });
        yield list.isReady();
    });
});
(0, cucumber_1.Then)("в модальном окне есть список {string}.", function (listTitle) {
    return __awaiter(this, void 0, void 0, function* () {
        const list = yield this.getList({
            container: "modal",
            title: listTitle
        });
        yield list.isReady();
    });
});
(0, cucumber_1.Then)("в модальном окне есть список:", function (dataTable) {
    return __awaiter(this, void 0, void 0, function* () {
        const list = yield this.getList({
            container: "modal"
        });
        yield list.isReady();
        yield (0, strictListCompare_steps_1.strictListEquality)(list, (0, tableManager_1.getListData)(dataTable));
    });
});
(0, cucumber_1.Then)("в модальном окне есть список {string}:", function (listTitle, dataTable) {
    return __awaiter(this, void 0, void 0, function* () {
        const list = yield this.getList({
            container: "modal",
            title: listTitle
        });
        yield list.isReady();
        yield (0, strictListCompare_steps_1.strictListEquality)(list, (0, tableManager_1.getListData)(dataTable));
    });
});
(0, cucumber_1.Then)("в поле {string} есть значение {string} в модальном окне.", function (fieldName, value) {
    return __awaiter(this, void 0, void 0, function* () {
        const form = yield this.getModal();
        const field = form.getField(fieldName);
        yield (0, form_steps_1.expectFieldValue)(field, value);
    });
});
