"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.NextNodeSearcher = void 0;
const NodeStateAccessor_1 = require("./NodeStateAccessor");
const findPath_1 = require("./findPath/findPath");
class NextNodeSearcher {
    constructor(page) {
        this.page = page;
        this.nodeStateAccessor = new NodeStateAccessor_1.NodesStateAccessor(this.page);
    }
    getNext(current = {}) {
        return __awaiter(this, void 0, void 0, function* () {
            if (current.topNav) {
                const next = yield this.getNextLeftNav(current.leftNav);
                if (next) {
                    return Object.assign(Object.assign({}, current), { leftNav: next });
                }
            }
            if (yield this.page.header.apps.isVisible()) {
                if (current.app) {
                    const next = yield this.getNextTopNav(current.topNav);
                    if (next) {
                        return Object.assign(Object.assign({}, current), { topNav: next, leftNav: null });
                    }
                }
                const next = yield this.getNextApp(current.app);
                if (next) {
                    return {
                        app: next,
                        topNav: null,
                        leftNav: null
                    };
                }
                return;
            }
            else {
                const next = yield this.getNextTopNav(current.topNav);
                if (next) {
                    return Object.assign(Object.assign({}, current), { topNav: next, leftNav: null });
                }
            }
        });
    }
    getNextApp(app) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.findNext(app, yield this.nodeStateAccessor.getApps());
        });
    }
    getNextTopNav(topNav) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.findNext(topNav, yield this.nodeStateAccessor.getTopNavs());
        });
    }
    getNextLeftNav(leftNav) {
        var _a;
        return __awaiter(this, void 0, void 0, function* () {
            const leftNavs = yield this.nodeStateAccessor.getLeftNavs();
            if (!leftNavs)
                return null;
            if (!leftNav) {
                const title = (_a = leftNavs[0]) === null || _a === void 0 ? void 0 : _a.title;
                return title ? [title] : null;
            }
            const p = (0, findPath_1.findPath)(leftNav, leftNavs);
            return p;
        });
    }
    findNext(current, nodes) {
        return __awaiter(this, void 0, void 0, function* () {
            if (!current) {
                return nodes[0];
            }
            const currentIndex = nodes.findIndex((a) => a == current);
            return nodes[currentIndex + 1];
        });
    }
}
exports.NextNodeSearcher = NextNodeSearcher;
