"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ResultManager = void 0;
const MAXIMUM_ERRORS = 10;
class ResultManager {
    constructor(messageShower) {
        this.messageShower = messageShower;
        this.errors = [];
        this.failedForce = false;
    }
    addError(info) {
        this.errors.push(info);
    }
    showResult() {
        if (!this.errors.length) {
            this.messageShower.show(this.messageShower.success(), this.messageShower.level.result);
            return;
        }
        const message = this.buildErrorMessage();
        throw message;
    }
    errorsCount() {
        return this.errors.length;
    }
    isFailed() {
        return this.errorsCount() >= MAXIMUM_ERRORS || this.failedForce;
    }
    failForce(reason) {
        this.addError(reason);
        this.failedForce = true;
    }
    buildErrorMessage() {
        let result = this.messageShower.errorsFound();
        this.errors.forEach((error, index) => {
            result += `\n${index + 1}) ${error.definition}`;
            result += `\n${error.message}`;
            result += `\n`;
        });
        return result;
    }
}
exports.ResultManager = ResultManager;
