"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.HierarchicalListItem = exports.HierarchicalList = void 0;
const getSelector_1 = require("../../../utils/getSelector");
const selectors = (0, getSelector_1.getSelectors)({
    list: "hierarchical-list",
    item: "hierarchical-list-item",
    itemContent: "hierarchical-list-item-content",
    itemToggler: "toggle-icon",
    divider: "nav-divider",
    dividerTitle: "nav-divider-title"
});
class HierarchicalList {
    constructor(parentEl) {
        this.parentEl = parentEl;
        this.el = this.parentEl.locator(`> ${selectors.list}`);
    }
    item(title) {
        const selector = `> ${selectors.item}:has(${selectors.itemContent} :text-is("${title}"))`;
        return new HierarchicalListItem(this.el.locator(selector).first());
    }
    divider(title) {
        const el = this.el.locator(`> ${selectors.divider}:has(a > span:text-is("${title}"))`);
        return {
            header: el.locator(`> ${selectors.dividerTitle}`),
            list: new HierarchicalList(el)
        };
    }
    items() {
        return __awaiter(this, void 0, void 0, function* () {
            const all = yield this.el.locator(`> ${selectors.item}`).all();
            return all.map((l) => new HierarchicalListItem(l));
        });
    }
}
exports.HierarchicalList = HierarchicalList;
class HierarchicalListItem {
    constructor(el) {
        this.el = el;
        this.content = this.el.locator(`> ${selectors.itemContent}`);
        this.list = new HierarchicalList(this.el);
        this.toggler = this.content.locator(`> ${selectors.itemToggler}`);
    }
    isParent() {
        return this.content.locator(selectors.itemToggler).isVisible();
    }
    isOpen() {
        return this.list.el.isVisible();
    }
    isActive() {
        return __awaiter(this, void 0, void 0, function* () {
            const classList = yield this.el.evaluate((el) => el.classList);
            return classList.contains("active");
        });
    }
}
exports.HierarchicalListItem = HierarchicalListItem;
