"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.asyncEvery = exports.asyncReduce = exports.asyncReduceRight = exports.asyncSome = exports.asyncFilter = exports.asyncMap = exports.asyncFindIndex = exports.asyncForEach = void 0;
function asyncForEach(elements, cb) {
    return __awaiter(this, void 0, void 0, function* () {
        for (const [index, element] of elements.entries()) {
            yield cb(element, index, elements);
        }
    });
}
exports.asyncForEach = asyncForEach;
function asyncFindIndex(elements, cb) {
    return __awaiter(this, void 0, void 0, function* () {
        for (const [index, element] of elements.entries()) {
            if (yield cb(element, index, elements)) {
                return index;
            }
        }
        return -1;
    });
}
exports.asyncFindIndex = asyncFindIndex;
function asyncMap(elements, cb) {
    return __awaiter(this, void 0, void 0, function* () {
        const mapped = [];
        for (const [index, element] of elements.entries()) {
            const result = yield cb(element, index, elements);
            mapped.push(result);
        }
        return mapped;
    });
}
exports.asyncMap = asyncMap;
function asyncFilter(elements, cb) {
    return __awaiter(this, void 0, void 0, function* () {
        const filteredResults = [];
        for (const [index, element] of elements.entries()) {
            if (yield cb(element, index, elements)) {
                filteredResults.push(element);
            }
        }
        return filteredResults;
    });
}
exports.asyncFilter = asyncFilter;
function asyncSome(elements, cb) {
    return __awaiter(this, void 0, void 0, function* () {
        for (const [index, element] of elements.entries()) {
            if (yield cb(element, index, elements)) {
                return true;
            }
        }
        return false;
    });
}
exports.asyncSome = asyncSome;
function asyncReduceRight(elements, cb, initialValue) {
    return __awaiter(this, void 0, void 0, function* () {
        if (!elements.length && initialValue === undefined) {
            throw new Error("Reduce of empty array with no initial value");
        }
        let reducedValue;
        let index = elements.length - 1;
        if (initialValue === undefined) {
            reducedValue = elements[index];
            index--;
        }
        else {
            reducedValue = initialValue;
        }
        for (; index >= 0; index--) {
            reducedValue = yield cb(reducedValue, elements[index], index, elements);
        }
        return reducedValue;
    });
}
exports.asyncReduceRight = asyncReduceRight;
function asyncReduce(elements, cb, initialValue) {
    return __awaiter(this, void 0, void 0, function* () {
        if (!elements.length && initialValue === undefined) {
            throw new Error("Reduce of empty array with no initial value");
        }
        let reducedValue;
        let index = 0;
        if (initialValue === undefined) {
            reducedValue = elements[0];
            index++;
        }
        else {
            reducedValue = initialValue;
        }
        for (; index < elements.length; index++) {
            //@ts-ignore
            reducedValue = yield cb(reducedValue, elements[index], index, elements);
        }
        return reducedValue;
    });
}
exports.asyncReduce = asyncReduce;
function asyncEvery(elements, cb) {
    return __awaiter(this, void 0, void 0, function* () {
        for (const [index, element] of elements.entries()) {
            if (!(yield cb(element, index, elements))) {
                return false;
            }
        }
        return true;
    });
}
exports.asyncEvery = asyncEvery;
function aFind(elements, cb) {
    return __awaiter(this, void 0, void 0, function* () {
        for (const [index, element] of elements.entries()) {
            if (yield cb(element, index, elements)) {
                return element;
            }
        }
        return undefined;
    });
}
