"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.containerTypeToText = exports.ContentManager = exports.getContentManager = void 0;
const content_1 = require("../pageObject/content/content");
const modal_1 = require("../pageObject/modal/modal");
const side_1 = require("../pageObject/side/side");
function getContentManager(page) {
    return new ContentManager(page);
}
exports.getContentManager = getContentManager;
class ContentManager {
    constructor(page) {
        this.containers = {
            modal: (0, modal_1.getModal)(page.zoneBottom),
            side: (0, side_1.getSide)(page.wrapper),
            content: (0, content_1.getContent)(page.body.locator(".section > .content"))
        };
    }
    getActive() {
        return __awaiter(this, void 0, void 0, function* () {
            let active = void 0;
            for (const type of this.searchQueue()) {
                const container = this.containers[type];
                if (type == "modal")
                    container.useActive();
                if (yield container.el.isVisible()) {
                    active = {
                        type,
                        container
                    };
                    break;
                }
            }
            if (!active) {
                throw new Error("Модальное окно, боковая панель или область с контентом не найдены.");
            }
            return active;
        });
    }
    getContainer(type) {
        return this.containers[type];
    }
    getContainerEl(type, options = {}) {
        const container = this.getContainer(type);
        return this.getSpecific(container, options);
    }
    waitForHidden(type, options = {}) {
        return __awaiter(this, void 0, void 0, function* () {
            const container = this.getContainer(type);
            yield this.getSpecific(container, options).waitFor({ state: "detached" });
            if (type == "side") {
                container.inAnyState();
                yield this.getSpecific(container, options).waitFor({ state: "detached" });
            }
        });
    }
    getSpecific(container, options = {}) {
        let el = container.el;
        if (options.title)
            el = container.el.locator(`:scope:has(${container.titleSelector}:has-text("${options.title}"))`);
        if (options.hasSelector)
            el = el.locator(`:scope:has(${container.contentSelector} > ${options.hasSelector})`);
        return el;
    }
    searchQueue() {
        return ["modal", "side", "content"];
    }
}
exports.ContentManager = ContentManager;
function containerTypeToText(type) {
    const map = {
        content: "в области содержимого",
        modal: "в модальном окно",
        side: "в боковой панель"
    };
    return map[type];
}
exports.containerTypeToText = containerTypeToText;
