"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.areSoftEqual = void 0;
const test_1 = require("@playwright/test");
const dateFormat_1 = require("./dateFormat");
const dateMatcher_1 = require("./dateMatcher");
function simplify(val) {
    var _a;
    if (typeof val == "string") {
        if (((_a = dateFormat_1._dateRegex.exec(val)) === null || _a === void 0 ? void 0 : _a.length) == 8)
            return val;
        val = val.replace(",", ".").replace(" ", "");
        val = val.replace("{\n}", "\n");
    }
    if (val == "")
        return null;
    if (!isNaN(parseFloat(val)))
        return parseFloat(val);
    return val;
}
function parseIfDateEmptyMask(val) {
    if (val == "__.__.____ __:__:__" || val == "__.__.____")
        return "";
    return val;
}
function areSoftEqual(val1, val2) {
    val1 = parseIfDateEmptyMask(val1);
    val2 = parseIfDateEmptyMask(val2);
    if ((0, dateMatcher_1.isAlias)(val1) || (0, dateMatcher_1.isAlias)(val2)) {
        return (0, dateMatcher_1.equalByDateAlias)(val1, val2);
    }
    return simplify(val1) == simplify(val2);
}
exports.areSoftEqual = areSoftEqual;
test_1.expect.extend({
    toSoftEqual(received, expected) {
        return {
            message: () => `Received "${received}" to be soft equal to "${(0, dateMatcher_1.parseIfAlias)(expected)}"`,
            pass: areSoftEqual(received, expected)
        };
    },
    toSoftArrayEqual(received, expected) {
        const diff = [];
        return {
            pass: received.length === expected.length &&
                received.every((element, index) => {
                    if (areSoftEqual(element, expected[index]))
                        return true;
                    diff.push([element, (0, dateMatcher_1.parseIfAlias)(expected[index])]);
                    return false;
                }),
            message: () => {
                let msg = `Received "${JSON.stringify(received)}" to be soft equal to "${JSON.stringify(expected)}"`;
                if (diff.length) {
                    msg += `\ndiff:\n`;
                    msg += diff.map(([r, e], i) => `#${i + 1} received ${r} to be soft equal to ${e}`);
                }
                return msg;
            }
        };
    }
});
