"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.equalByDateAlias = exports.parseIfAlias = exports.isAlias = void 0;
const dateFormat_1 = require("./dateFormat");
function isAlias(val) {
    return isDateAlias(val) || isDateTimeAlias(val);
}
exports.isAlias = isAlias;
function isDateAlias(val) {
    var _a;
    const dateAliasReg = /^({текущая дата}|{текущая дата \+ [1-9]{1,2} дней})$/;
    return typeof val == "string" && !!((_a = val.match(dateAliasReg)) === null || _a === void 0 ? void 0 : _a[0]);
}
function isDateTimeAlias(val) {
    var _a;
    const dateAliasReg = /^({текущая дата и время}|{текущая дата \+ [1-9]{1,2} дней и время})$/;
    return typeof val == "string" && !!((_a = val.match(dateAliasReg)) === null || _a === void 0 ? void 0 : _a[0]);
}
function parseIfAlias(val) {
    if (isDateAlias(val))
        return (0, dateFormat_1.dateFormat)(getDateFromAlias(val), "date");
    if (isDateTimeAlias(val))
        return (0, dateFormat_1.dateFormat)(getDateFromAlias(val), "datetime");
    return val;
}
exports.parseIfAlias = parseIfAlias;
function getDateEqualityType(val, val2) {
    let isDateTime = isDateTimeAlias(val) || isDateTimeAlias(val2);
    if (isDateTime)
        return "datetime";
    let isDate = isDateAlias(val) || isDateAlias(val2);
    if (isDate)
        return "date";
}
function getDateFromAlias(val) {
    var _a;
    const date = new Date();
    const daysCount = (_a = val.match(/[1-9]{1,2}/)) === null || _a === void 0 ? void 0 : _a[0];
    if (daysCount)
        date.setDate(date.getDate() + parseFloat(daysCount));
    return date;
}
function equalByDateAlias(val, val2) {
    const type = getDateEqualityType(val, val2);
    const date1 = parseToDate(val);
    const date2 = parseToDate(val2);
    if (type == "datetime") {
        const diffSeconds = Math.abs((0, dateFormat_1.parseToMSeconds)(date1) - (0, dateFormat_1.parseToMSeconds)(date2)) / 1000;
        const fiveMinutes = 301;
        return diffSeconds <= fiveMinutes;
    }
    if (type == "date") {
        const yearsAreEqual = date1.getFullYear() == date2.getFullYear();
        const monthsAreEqual = date1.getMonth() == date2.getMonth();
        const daysAreEqual = date1.getDate() == date2.getDate();
        return yearsAreEqual && monthsAreEqual && daysAreEqual;
    }
}
exports.equalByDateAlias = equalByDateAlias;
function parseToDate(val) {
    if (isAlias(val))
        return getDateFromAlias(val);
    return new Date((0, dateFormat_1.parseToMSeconds)(val));
}
