"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const featureContext_1 = require("./featureContext");
const path = require("path");
const FeatureManager = new (class {
    constructor() {
        this.currentFeature = void 0;
        this.failedFeatures = [];
        this.context = (0, featureContext_1.getFeatureContext)();
        this.getScenarioPath = (scenario) => { var _a; return ((_a = scenario.gherkinDocument) === null || _a === void 0 ? void 0 : _a.uri) || ""; };
    }
    isStepFailed(scenario) {
        var _a;
        return ((_a = scenario === null || scenario === void 0 ? void 0 : scenario.result) === null || _a === void 0 ? void 0 : _a.status) == "FAILED";
    }
    isFailed(scenario) {
        if (this.failedFeatures.includes(this.getScenarioPath(scenario)))
            return true;
        return false;
    }
    isCompletedOrFailed(scenario) {
        return this.isFailed(scenario);
    }
    isNewFeature(scenario) {
        return this.currentFeature != this.getScenarioPath(scenario);
    }
    isFirstFeature() {
        return !this.currentFeature;
    }
    setCurrent(scenario) {
        this.currentFeature = this.getScenarioPath(scenario);
    }
    addFailed(scenario) {
        const path = this.getScenarioPath(scenario);
        if (!this.failedFeatures.includes(path))
            this.failedFeatures.push(path);
    }
    getFailedCount() {
        return this.failedFeatures.length;
    }
    getSkippedState() {
        return "skipped";
    }
    getFileName() {
        return path.parse(this.currentFeature).name;
    }
})();
exports.default = FeatureManager;
