"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getField = void 0;
const getSelector_1 = require("../../../utils/getSelector");
const controls_1 = require("./fieldControls/controls");
const icon_1 = require("../../icon/icon");
function getField(parentEl, fieldName) {
    const selectors = Object.assign(Object.assign({}, (0, getSelector_1.getSelectors)({
        field: "field",
        panel: "panel",
        label: "field-label",
        lockable: "lockable",
        tagMark: "field-tag-mark"
    })), { placeholder: `[placeholder="${fieldName}"]` });
    const findByLabel = `${selectors.field}:has(${selectors.label} :text-is("${fieldName}"), ${selectors.placeholder}):not(:has(${selectors.panel}))`;
    const findByNameAttribute = `${selectors.field}${(0, getSelector_1.getSelector)({ fieldName })}`;
    const el = parentEl.locator(findByLabel).or(parentEl.locator(findByNameAttribute)).locator("visible=true").first();
    const lockedWrap = el.locator(`${selectors.lockable}[inert]:not([inert="false"])`);
    const waitForUnlocked = () => lockedWrap.waitFor({ state: "hidden" });
    return {
        el,
        isLocked() {
            return lockedWrap.isVisible();
        },
        // TODO: кешировать контрол в объекте, чтобы поиск не прогонялся несколько раз.
        getControl() {
            return __awaiter(this, void 0, void 0, function* () {
                yield waitForUnlocked();
                if (yield this.el.isHidden())
                    throw new Error(`Поле "${fieldName}" не найдено.`);
                const control = yield (0, controls_1.getControl)(el);
                if (control)
                    return control;
                throw new Error(`Неизвестный компонент в поле ${fieldName}.`);
            });
        },
        get error() {
            return (0, icon_1.getIcon)(el.locator(selectors.label), "exclamation-circle").el;
        },
        isExist() {
            return __awaiter(this, void 0, void 0, function* () {
                if (yield this.el.isVisible())
                    return true;
                throw new Error(`Поле "${fieldName}" не найдено.`);
            });
        },
        isReadonly() {
            return __awaiter(this, void 0, void 0, function* () {
                const control = yield this.getControl();
                return yield control.isReadonly();
            });
        },
        displayValueAsync() {
            return __awaiter(this, void 0, void 0, function* () {
                const control = yield this.getControl();
                return yield control.displayValueAsync();
            });
        },
        getWidth() {
            return __awaiter(this, void 0, void 0, function* () {
                const width = yield el.evaluate((el, args) => {
                    var _a;
                    return (_a = el.closest(args.colSelector)) === null || _a === void 0 ? void 0 : _a.getAttribute(args.widthAttribute);
                }, {
                    colSelector: (0, getSelector_1.getSelector)({ testid: "col" }),
                    widthAttribute: (0, getSelector_1.getAttribute)("width")
                });
                return parseInt(width);
            });
        },
        get tagMark() {
            return el.locator(selectors.label).locator(selectors.tagMark);
        }
    };
}
exports.getField = getField;
