"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.clearControlValue = exports.setControlValue = exports.getControl = void 0;
const checkbox_1 = require("./checkbox/checkbox");
const date_1 = require("./date/date");
const file_1 = require("./file/file");
const multiPicker_1 = require("./multiPicker/multiPicker");
const picker_1 = require("./picker/picker");
const select_1 = require("./select/select");
const text_1 = require("./text/text");
const radioPicker_1 = require("./radioPicker/radioPicker");
function getControl(parentEl, type) {
    return __awaiter(this, void 0, void 0, function* () {
        const controls = [
            multiPicker_1.getMultiPicker,
            picker_1.getPicker,
            date_1.getDatePicker,
            file_1.getFileControl,
            select_1.getSelect,
            checkbox_1.getBooleanControl,
            radioPicker_1.getRadioPicker,
            text_1.getInputControl,
            text_1.getTextAreaControl,
            text_1.getContentEditableControl
        ];
        for (const getControlFn of controls) {
            const control = getControlFn(parentEl);
            if (type && type != control.type)
                continue;
            if (yield control.isExistAsync())
                return control;
        }
    });
}
exports.getControl = getControl;
function setControlValue(page, control, value) {
    return __awaiter(this, void 0, void 0, function* () {
        switch (control.type) {
            case "multiPicker":
                return yield control.setValue(page, value);
            case "picker":
                return yield (0, picker_1.setPickerValue)(page, control, value);
            case "datePicker":
                return yield (0, date_1.setDatePickerValue)(page, control, value);
            case "file":
                return yield (0, file_1.setFileControlValue)(page, control, value);
            case "select":
                return yield (0, select_1.setSelectControlValue)(page, control, value);
            case "checkbox":
                return yield (0, checkbox_1.setCheckboxValue)(page, control, value);
            case "input":
                return yield control.setValue(page, value);
            case "textarea":
                return yield control.setValue(page, value);
            case "contenteditable":
                return yield control.setValue(page, value);
            default:
                break;
        }
        throw new Error(`Невозможно автоматически проставить значение ${value}`);
    });
}
exports.setControlValue = setControlValue;
function clearControlValue(control) {
    return __awaiter(this, void 0, void 0, function* () {
        switch (control.type) {
            case "multiPicker":
                return yield (0, multiPicker_1.clearMultiPickerValue)(control);
            case "picker":
                return yield (0, picker_1.clearPickerValue)(control);
            case "datePicker":
                return yield (0, date_1.clearDatePickerValue)(control);
            case "file":
                return yield (0, file_1.clearFileControlValue)(control);
            case "input":
                return yield (0, text_1.clearTextControlValue)(control);
            case "textarea":
                return yield (0, text_1.clearTextControlValue)(control);
            case "contenteditable":
                return yield (0, text_1.clearTextControlValue)(control);
            default:
                break;
        }
        throw new Error(`Невозможно автоматически очистить значение для контрола ${control.type}`);
    });
}
exports.clearControlValue = clearControlValue;
