"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.clearMultiPickerValue = exports.MultiPicker = exports.getMultiPicker = void 0;
const getSelector_1 = require("../../../../../utils/getSelector");
const text_1 = require("../text/text");
const dropdown_steps_1 = require("../../../../dropdown/dropdown.steps");
const SPLITTER = "/";
function getMultiPicker(parentEl) {
    return new MultiPicker(parentEl);
}
exports.getMultiPicker = getMultiPicker;
class MultiPicker {
    constructor(parentEl) {
        this.type = "multiPicker";
        this.el = parentEl.locator(MultiPicker.selectors.el);
    }
    isReadonly() {
        return __awaiter(this, void 0, void 0, function* () {
            const inputValue = yield this.input.isHidden();
            const action = yield this.action.isHidden();
            const clear = yield this.clear.isHidden();
            return inputValue && action && clear;
        });
    }
    get firstItem() {
        return getMultiPickerItem(this.el, { first: true });
    }
    get input() {
        const inputCtrl = new text_1.InputControl(this.el);
        return inputCtrl.textEl;
    }
    get clear() {
        return this.el.locator(MultiPicker.selectors.clear);
    }
    get action() {
        return this.el.locator(".action");
    }
    isExistAsync() {
        return __awaiter(this, void 0, void 0, function* () {
            return this.el.isVisible();
        });
    }
    displayValueAsync() {
        return __awaiter(this, void 0, void 0, function* () {
            let result = yield this.el.textContent();
            if (yield this.input.isVisible()) {
                result += yield this.input.inputValue();
            }
            return result;
        });
    }
    hasPickedValue() {
        return this.firstItem.el.isVisible();
    }
    item(title) {
        return getMultiPickerItem(this.el, { title });
    }
    itemsCount() {
        return getMultiPickerItem(this.el).el.count();
    }
    setValue(page, value) {
        return __awaiter(this, void 0, void 0, function* () {
            this.el.waitFor();
            const items = value.split(SPLITTER);
            if (yield this.hasPickedValue()) {
                yield clearMultiPickerValue(this);
            }
            yield page.waitForLoading();
            for (const value of items) {
                yield this.input.waitFor();
                yield this.input.fill(value);
                yield (0, dropdown_steps_1.dropdownPickItem)(page, value);
                yield page.waitForLoading();
                yield this.item(value).el.first().waitFor();
            }
        });
    }
}
exports.MultiPicker = MultiPicker;
MultiPicker.selectors = (0, getSelector_1.getSelectors)({
    el: "multi-picker",
    clear: "clear-action"
});
function getMultiPickerItem(parentEl, options) {
    let el = parentEl.locator(".picked-item");
    if (options === null || options === void 0 ? void 0 : options.title)
        el = el.locator(`:has-text("${options === null || options === void 0 ? void 0 : options.title}")`);
    if (options === null || options === void 0 ? void 0 : options.first)
        el.first();
    return {
        el,
        value: el.locator(".picked-item-value"),
        remove: el.locator(".picked-item-clear")
    };
}
function clearMultiPickerValue(picker) {
    return __awaiter(this, void 0, void 0, function* () {
        const itemsCount = yield picker.itemsCount();
        for (let i = 0; i < itemsCount; i++) {
            yield picker.el.waitFor();
            yield picker.el.hover();
            yield picker.firstItem.remove.waitFor();
            yield picker.firstItem.remove.click();
        }
        yield picker.firstItem.el.waitFor({ state: "hidden" });
        if (yield picker.hasPickedValue())
            throw new Error("Невозможно очистить значение в мультипикере");
    });
}
exports.clearMultiPickerValue = clearMultiPickerValue;
