"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.clearPickerValue = exports.setPickerValue = exports.getPicker = exports.Picker = void 0;
const getSelector_1 = require("../../../../../utils/getSelector");
const dropdown_steps_1 = require("../../../../dropdown/dropdown.steps");
const text_1 = require("../text/text");
class Picker {
    constructor(parentEl) {
        this.type = "picker";
        this.el = parentEl.locator(Picker.selectors.el);
    }
    isReadonly() {
        return __awaiter(this, void 0, void 0, function* () {
            const inputValue = yield this.input.isHidden();
            const action = yield this.action.isHidden();
            const clear = yield this.clear.isHidden();
            return inputValue && action && clear;
        });
    }
    isExistAsync() {
        return __awaiter(this, void 0, void 0, function* () {
            return this.el.isVisible();
        });
    }
    displayValueAsync() {
        return __awaiter(this, void 0, void 0, function* () {
            if (yield this.hasPickedItem())
                return yield this.pickedItem.textContent();
            return yield this.input.inputValue();
        });
    }
    hasPickedItem() {
        return __awaiter(this, void 0, void 0, function* () {
            return (yield this.pickedItem.isVisible()) && (yield this.input.isHidden());
        });
    }
    get pickedItem() {
        return this.el.locator(`.selector-link`);
    }
    get input() {
        const inputCtrl = new text_1.InputControl(this.el);
        return inputCtrl.textEl;
    }
    get clear() {
        return this.el.locator(Picker.selectors.clear);
    }
    get action() {
        return this.el.locator(Picker.selectors.action);
    }
}
exports.Picker = Picker;
Picker.selectors = (0, getSelector_1.getSelectors)({
    el: "picker",
    clear: "clear-action",
    action: "common-control-action"
});
function getPicker(parentEl) {
    return new Picker(parentEl);
}
exports.getPicker = getPicker;
function setPickerValue(page, picker, value) {
    return __awaiter(this, void 0, void 0, function* () {
        yield picker.el.waitFor();
        if (yield picker.hasPickedItem()) {
            yield picker.el.hover();
            if (yield picker.clear.isVisible()) {
                yield picker.clear.click();
                yield page.waitForLoading();
            }
            else
                throw new Error("Невозможно очистить значение в пикере");
        }
        yield picker.input.clear();
        yield page.dropdown.el.waitFor();
        if (yield page.dropdown.el.isHidden()) {
            yield picker.input.click();
        }
        const dropdown = yield (0, dropdown_steps_1.getReadyDropdown)(page.dropdown);
        const item = dropdown.itemByTitle(value);
        if (yield item.isHidden()) {
            yield picker.input.fill(value);
            yield page.waitForLoading();
        }
        yield item.click();
        yield dropdown.el.waitFor({ state: "hidden" });
        yield picker.pickedItem.waitFor();
    });
}
exports.setPickerValue = setPickerValue;
function clearPickerValue(picker) {
    return __awaiter(this, void 0, void 0, function* () {
        if (yield picker.hasPickedItem()) {
            yield picker.el.hover();
            if (yield picker.clear.isVisible())
                yield picker.clear.click();
        }
        if (yield picker.hasPickedItem())
            throw new Error("Не удалось очистить значение в пикере");
    });
}
exports.clearPickerValue = clearPickerValue;
