"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getTab = void 0;
const list_1 = require("../../list/list");
const progressBar_1 = require("../../progressBar/progressBar");
const getSelector_1 = require("../../../utils/getSelector");
const tabsSelector = {
    wrapper: (0, getSelector_1.getSelector)({
        testid: "tabs-wrapper"
    }),
    label: (0, getSelector_1.getSelector)({
        testid: "tab-label"
    }),
    content: (0, getSelector_1.getSelector)({
        testid: "tab-content"
    })
};
function getTab(parentEl, tabName) {
    const tabs = parentEl.locator(tabsSelector.wrapper);
    const linkSelector = `${tabsSelector.label}:has-text("${tabName}")`;
    const currentTab = tabs.locator(`:scope:has(${linkSelector})`);
    const contentEl = currentTab.locator(tabsSelector.content);
    return {
        get link() {
            return currentTab.locator(linkSelector);
        },
        waitForOpen() {
            return __awaiter(this, void 0, void 0, function* () {
                const progressBar = (0, progressBar_1.getProgressBar)(contentEl);
                if (yield progressBar.isLoading())
                    yield progressBar.waitForComplete();
            });
        },
        get content() {
            return currentTab.locator(tabsSelector.content);
        },
        getList() {
            return new list_1.List(contentEl);
        }
    };
}
exports.getTab = getTab;
