"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Form = void 0;
const progressBar_1 = require("../progressBar/progressBar");
const field_1 = require("./Field/field");
const formToolbar_1 = require("./formToolbar/formToolbar");
const infoBlock_1 = require("./infoBlock/infoBlock");
const tabs_1 = require("./Tabs/tabs");
const workflow_1 = require("./workflow/workflow");
const audit_1 = require("./audit/audit");
const tag_1 = require("../tag/tag");
const skeleton_1 = require("../progressBar/skeleton/skeleton");
class Form {
    constructor(parentEl, options) {
        this.parentEl = parentEl;
        this.options = options;
        this.el = this.parentEl;
        this.progressBar = (0, progressBar_1.getProgressBar)(this.parentEl.locator(".form-progress-wrap"));
        this.skeleton = new skeleton_1.Skeleton(this.parentEl);
        this.toolbar = (0, formToolbar_1.getFormToolbar)(this.parentEl.locator(".form-actions .btn-toolbar"));
    }
    isLoading() {
        return __awaiter(this, void 0, void 0, function* () {
            let result = (yield this.skeleton.isExist()) || (yield this.progressBar.isLoading());
            return result;
        });
    }
    waitForComplete() {
        return __awaiter(this, void 0, void 0, function* () {
            yield this.skeleton.waitForCompleteIfExist();
            yield this.progressBar.waitForComplete();
        });
    }
    waitComponentsLoading() {
        return __awaiter(this, void 0, void 0, function* () {
            while (yield this.isLoading()) {
                yield this.waitForComplete();
            }
        });
    }
    getField(fieldName) {
        return (0, field_1.getField)(this.el, fieldName);
    }
    getTab(tabTitle) {
        return (0, tabs_1.getTab)(this.el, tabTitle);
    }
    get workflow() {
        return (0, workflow_1.getWorkflow)(this.el);
    }
    getAudit() {
        return __awaiter(this, void 0, void 0, function* () {
            const audit = (0, audit_1.getAudit)(this.el);
            if (yield audit.el.isHidden())
                throw new Error("Аудит не найдён");
            return audit;
        });
    }
    getTagMenu(options) {
        return __awaiter(this, void 0, void 0, function* () {
            const tagMenu = new tag_1.TagMenu(this.el);
            if ((options === null || options === void 0 ? void 0 : options.waitFor) !== false)
                yield tagMenu.el.waitFor();
            return tagMenu;
        });
    }
    waitForReady() {
        return __awaiter(this, void 0, void 0, function* () {
            yield this.el.waitFor();
            yield this.waitForComplete();
            yield this.waitComponentsLoading();
            const result = yield this.progressBar.isComplete();
            return result;
        });
    }
    wasClosedOrNotExist() {
        return __awaiter(this, void 0, void 0, function* () {
            yield this.el.waitFor({ state: "hidden" });
            const wasClosed = yield this.el.isHidden();
            return wasClosed;
        });
    }
    get infoBlock() {
        return (0, infoBlock_1.getInfoBlock)(this.parentEl);
    }
    get designerWrapper() {
        return this.options.designerWrapper;
    }
}
exports.Form = Form;
