"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getForm = exports.waitForFormClosed = exports.clearFieldValue = exports.setValueByField = exports.expectFieldValue = exports.formHasList = exports.expectOpenForm = exports.clickButtonFromForm = exports.setFieldValueStep = exports.setManyFieldsValue = void 0;
const cucumber_1 = require("@cucumber/cucumber");
const test_1 = require("@playwright/test");
const setup_1 = require("../../../setup/setup");
const asyncArray_1 = require("../../utils/asyncArray");
const dateMatcher_1 = require("../../utils/date/dateMatcher/dateMatcher");
const isNullOrEmpty_1 = require("../../utils/isNullOrEmpty");
const tableManager_1 = require("../../utils/tableManager");
const dropdown_steps_1 = require("../dropdown/dropdown.steps");
const list_steps_1 = require("../list/list.steps");
const checkbox_1 = require("./Field/fieldControls/checkbox/checkbox");
const controls_1 = require("./Field/fieldControls/controls");
const file_1 = require("./Field/fieldControls/file/file");
const imageList_1 = require("./Field/fieldControls/file/imageList");
const numberAndIndex_1 = require("../../utils/numberAndIndex");
const filesList_1 = require("./Field/fieldControls/file/filesList");
const picker_1 = require("./Field/fieldControls/picker/picker");
const radioPicker_1 = require("./Field/fieldControls/radioPicker/radioPicker");
const compareByRowsOrder_1 = require("../list/steps/compare/compareByRowsOrder");
/*
    Когда заполняем поля формы следующими значениями:
      | Модуль        | mdt     |
      | Название      | Новый объект |
      | Имя схемы     | e2e          |
      | Системное имя | NewObject    |
*/
(0, cucumber_1.When)("заполняем поля формы следующими значениями:", { timeout: setup_1.config.largeTimeout * 2 }, function (data) {
    return __awaiter(this, void 0, void 0, function* () {
        yield setManyFieldsValue(this, data);
    });
});
function setManyFieldsValue(page, data) {
    return __awaiter(this, void 0, void 0, function* () {
        if (data.raw().length < 1)
            return false;
        const form = yield getForm(page);
        for (const [fieldName, fieldValue] of data.raw()) {
            const field = form.getField(fieldName);
            yield setValueByField(page, field, fieldValue);
            yield form.waitForReady();
            yield page.waitForLoading();
            (0, test_1.expect)(yield field.displayValueAsync(), `Не удалось установить значение в поле ${fieldName}`).toSoftEqual(fieldValue);
        }
    });
}
exports.setManyFieldsValue = setManyFieldsValue;
(0, cucumber_1.When)("нажимаем кнопку {string} в расширенном меню формы.", function (buttonTitle) {
    return __awaiter(this, void 0, void 0, function* () {
        const form = yield getForm(this);
        yield form.toolbar.more.waitFor();
        yield form.toolbar.more.evaluateHandle((el) => {
            el.click();
        });
        yield (0, dropdown_steps_1.dropdownPickItem)(this, buttonTitle);
    });
});
(0, cucumber_1.Then)("в расширенном меню формы нет кнопки {string}.", function (buttonTitle) {
    return __awaiter(this, void 0, void 0, function* () {
        const form = yield getForm(this);
        form.toolbar.more.waitFor();
        yield form.toolbar.more.click();
        const dropdown = yield (0, dropdown_steps_1.getReadyDropdown)(this.dropdown);
        const item = dropdown.itemByTitle(buttonTitle);
        yield item.waitFor({ state: "hidden" });
        yield (0, test_1.expect)(item).toBeHidden();
    });
});
(0, cucumber_1.When)("проставляем флаг в поле {string}.", function (fieldName) {
    return __awaiter(this, void 0, void 0, function* () {
        const form = yield getForm(this);
        const field = form.getField(fieldName);
        const fieldControl = yield field.getControl();
        if (fieldControl.type != "checkbox")
            throw new Error(`В поле ${fieldName} ожидался checkbox, но найден ${fieldControl.type}.`);
        yield setValueByField(this, field, checkbox_1.booleanData.truthy);
    });
});
(0, cucumber_1.When)("убираем флаг в поле {string}.", function (fieldName) {
    return __awaiter(this, void 0, void 0, function* () {
        const form = yield getForm(this);
        const field = form.getField(fieldName);
        const fieldControl = yield field.getControl();
        if (fieldControl.type != "checkbox")
            throw new Error(`В поле ${fieldName} ожидался checkbox, но найден ${fieldControl.type}.`);
        yield setValueByField(this, field, checkbox_1.booleanData.false);
    });
});
(0, cucumber_1.When)("заполняем поле {string} значением {string}.", { timeout: setup_1.config.largeTimeout }, function (fieldName, value) {
    return __awaiter(this, void 0, void 0, function* () {
        yield setFieldValueStep(this, fieldName, value);
    });
});
function setFieldValueStep(page, fieldName, value) {
    return __awaiter(this, void 0, void 0, function* () {
        const form = yield getForm(page);
        const field = form.getField(fieldName);
        yield setValueByField(page, field, value);
    });
}
exports.setFieldValueStep = setFieldValueStep;
/**
 * Для многострочного значения
 */
(0, cucumber_1.When)("заполняем поле {string} значением", { timeout: setup_1.config.largeTimeout }, function (fieldName, value) {
    return __awaiter(this, void 0, void 0, function* () {
        const form = yield getForm(this);
        const field = form.getField(fieldName);
        yield setValueByField(this, field, value);
    });
});
(0, cucumber_1.When)("очищаем значение поля {string}.", { timeout: setup_1.config.largeTimeout }, function (fieldName) {
    return __awaiter(this, void 0, void 0, function* () {
        const form = yield getForm(this);
        const field = form.getField(fieldName);
        yield clearFieldValue(field);
    });
});
(0, cucumber_1.When)("нажимаем кнопку {string} на форме.", function (buttonTile) {
    return __awaiter(this, void 0, void 0, function* () {
        yield clickButtonFromForm(this, buttonTile);
    });
});
function clickButtonFromForm(page, buttonTitle) {
    return __awaiter(this, void 0, void 0, function* () {
        const form = yield getForm(page);
        const button = getItem(form, buttonTitle);
        yield button.click({
            trial: true
        });
        yield button.evaluateHandle((el) => {
            el.click();
        });
    });
}
exports.clickButtonFromForm = clickButtonFromForm;
(0, cucumber_1.When)("на форме меняем язык на {string}.", function (language) {
    return __awaiter(this, void 0, void 0, function* () {
        const form = yield getForm(this);
        const button = getItem(form, "data-ext", true);
        yield button.click();
        yield (0, dropdown_steps_1.dropdownPickItem)(this, language);
    });
});
(0, cucumber_1.When)("в поле {string} загружаем файл {string}.", { timeout: setup_1.config.largeTimeout }, function (fieldName, fileName) {
    return __awaiter(this, void 0, void 0, function* () {
        const form = yield getForm(this);
        const field = form.getField(fieldName);
        yield field.el.waitFor();
        const fieldControl = yield field.getControl();
        if (fieldControl.type != "file")
            throw new Error(`Поле "${fieldName}" не содержит компонент позволяющий загрузить файл. `);
        yield (0, file_1.setFileControlValue)(this, fieldControl, fileName);
    });
});
(0, cucumber_1.When)("загружаем файл {string} в поле {string} со списком изображений.", function (fileName, fieldName) {
    return __awaiter(this, void 0, void 0, function* () {
        const form = yield getForm(this);
        const field = form.getField(fieldName);
        const imageList = (0, imageList_1.getImageList)(field.el);
        yield this.selectFile(fileName, () => imageList.addImage.click());
    });
});
(0, cucumber_1.When)("загружаем файл {string} в поле {string} со списком изображений по кнопке Загрузить.", function (fileName, fieldName) {
    return __awaiter(this, void 0, void 0, function* () {
        const form = yield getForm(this);
        const field = form.getField(fieldName);
        const imageList = (0, imageList_1.getImageList)(field.el);
        yield this.selectFile(fileName, () => imageList.uploadBtn.click());
    });
});
(0, cucumber_1.When)("нажимаем на поле {string}.", function (fieldName) {
    return __awaiter(this, void 0, void 0, function* () {
        const form = yield getForm(this);
        const field = form.getField(fieldName);
        const fieldControl = yield field.getControl();
        if (fieldControl.type == "picker") {
            yield fieldControl.input.waitFor();
            yield fieldControl.input.focus();
            yield fieldControl.input.click({ delay: 100 });
        }
        else
            yield fieldControl.el.click();
    });
});
(0, cucumber_1.When)("нажимаем на изображение в поле {string}.", function (fieldName) {
    return __awaiter(this, void 0, void 0, function* () {
        const form = yield getForm(this);
        const field = form.getField(fieldName);
        const control = yield field.getControl();
        if (control.type == "file") {
            yield control.imageFile.click();
        }
    });
});
(0, cucumber_1.When)("удаляем изображение из поля {string}.", function (fieldName) {
    return __awaiter(this, void 0, void 0, function* () {
        const form = yield getForm(this);
        const field = form.getField(fieldName);
        const control = yield field.getControl();
        if (control.type == "file") {
            yield control.ImageFileClear.click();
        }
    });
});
(0, cucumber_1.When)("нажимаем кнопку Скачать всё в поле {string} со списком изображений.", function (fieldName) {
    return __awaiter(this, void 0, void 0, function* () {
        const form = yield getForm(this);
        const field = form.getField(fieldName);
        const imageList = (0, imageList_1.getImageList)(field.el);
        yield imageList.cleanBtn.click();
    });
});
(0, cucumber_1.When)("удаляем изображение №{int} из поля {string}.", function (imageNumber, fieldName) {
    return __awaiter(this, void 0, void 0, function* () {
        const form = yield getForm(this);
        const field = form.getField(fieldName);
        const imageList = (0, imageList_1.getImageList)(field.el);
        yield imageList.trashIcon.nth((0, numberAndIndex_1.getIndexFromNumber)(imageNumber)).click();
    });
});
(0, cucumber_1.When)("загружаем файл {string} в поле {string} со списком файлов.", function (fileName, fieldName) {
    return __awaiter(this, void 0, void 0, function* () {
        const form = yield getForm(this);
        const field = form.getField(fieldName);
        const fileList = (0, filesList_1.getFilesList)(field.el);
        yield this.selectFile(fileName, () => fileList.upload.click());
    });
});
(0, cucumber_1.When)("удаляем файл №{int} в поле {string} со списком файлов.", function (fileNumber, fieldName) {
    return __awaiter(this, void 0, void 0, function* () {
        const form = yield getForm(this);
        const field = form.getField(fieldName);
        const fileList = (0, filesList_1.getFilesList)(field.el);
        yield fileList.file(fileNumber).clear.click();
    });
});
(0, cucumber_1.When)("наводимся на ошибку валидации в поле {string}.", function (fieldName) {
    return __awaiter(this, void 0, void 0, function* () {
        const form = yield getForm(this);
        const field = form.getField(fieldName);
        const error = yield field.error;
        yield error.hover();
    });
});
/*
* Проверяет множественный файловых контрол
*
    То в поле "Файл" есть файлы:
      | filesList.jpg | filesList1.png |
*/
(0, cucumber_1.Then)("в поле {string} есть файлы:", function (fieldName, filesRow) {
    return __awaiter(this, void 0, void 0, function* () {
        const form = yield getForm(this);
        const field = form.getField(fieldName);
        const fileList = (0, filesList_1.getFilesList)(field.el);
        const files = (0, tableManager_1.getRowData)(filesRow);
        yield (0, asyncArray_1.asyncForEach)(files, (fileTitle) => __awaiter(this, void 0, void 0, function* () {
            (0, test_1.expect)(yield fileList.hasFile(fileTitle)).toBe(true);
        }));
    });
});
(0, cucumber_1.Then)("в поле {string} со списком файлов есть файл {string}.", function (fieldName, fileTitle) {
    return __awaiter(this, void 0, void 0, function* () {
        const form = yield getForm(this);
        const field = form.getField(fieldName);
        const fileList = (0, filesList_1.getFilesList)(field.el);
        (0, test_1.expect)(yield fileList.hasFile(fileTitle)).toBe(true);
    });
});
/*
    То на форме есть следующие поля со значениями:
      | Модуль        | mdt		     |
      | Название      | Новый объект |
      | Имя схемы     | e2e          |
      | Системное имя | NewObject    |
*/
(0, cucumber_1.Then)("на форме есть следующие поля со значениями:", { timeout: setup_1.config.largeTimeout }, function (dataTable) {
    return __awaiter(this, void 0, void 0, function* () {
        const form = yield getForm(this);
        yield expectedFormRecordAsync(form, (0, tableManager_1.getRecord)(dataTable));
    });
});
/*
    То на форме есть следующие поля со значениями:
      | Модуль        | mdt		     |
      | Название      | Новый объект |
      | Имя схемы     | e2e          |
      | Системное имя | NewObject    |
*/
(0, cucumber_1.Then)("на форме поля заполнены следующими значениями:", { timeout: setup_1.config.largeTimeout }, function (dataTable) {
    return __awaiter(this, void 0, void 0, function* () {
        const form = yield getForm(this);
        yield expectedFormRecordAsync(form, (0, tableManager_1.getRecord)(dataTable));
    });
});
(0, cucumber_1.Then)("на форме есть кнопка {string}.", function (buttonTitle) {
    return __awaiter(this, void 0, void 0, function* () {
        const form = yield getForm(this);
        const button = getItem(form, buttonTitle);
        yield button.waitFor();
        yield (0, test_1.expect)(button).toBeVisible();
    });
});
(0, cucumber_1.Then)("на форме нет кнопки {string}.", function (buttonTitle) {
    return __awaiter(this, void 0, void 0, function* () {
        const form = yield getForm(this);
        const button = getItem(form, buttonTitle);
        yield (0, test_1.expect)(button).toBeHidden();
    });
});
/*
    То на форме будут кнопки:
    | Сохранить | Настроить задачи | JSON | Отменить |
*/
(0, cucumber_1.Then)("на форме будут кнопки:", { timeout: setup_1.config.largeTimeout }, function (buttonNamesRow) {
    return __awaiter(this, void 0, void 0, function* () {
        const buttons = (0, tableManager_1.getRowData)(buttonNamesRow);
        const form = yield getForm(this);
        yield (0, asyncArray_1.asyncForEach)(buttons, (buttonName) => __awaiter(this, void 0, void 0, function* () {
            yield (0, test_1.expect)(getItem(form, buttonName)).toBeVisible();
        }));
    });
});
(0, cucumber_1.Then)("на форме есть поле {string}.", function (fieldName) {
    return __awaiter(this, void 0, void 0, function* () {
        const form = yield getForm(this);
        const field = form.getField(fieldName);
        yield field.el.waitFor();
    });
});
(0, cucumber_1.Then)("на форме нет поля {string}.", function (fieldName) {
    return __awaiter(this, void 0, void 0, function* () {
        const form = yield getForm(this);
        const field = form.getField(fieldName);
        yield field.el.waitFor({ state: "hidden" });
    });
});
/*
    И на форме есть поля:
    | Путь к полю | Название | Ширина | Позиция | Описание |
*/
(0, cucumber_1.Then)("на форме есть поля:", { timeout: setup_1.config.largeTimeout }, function (fieldsTitleRow) {
    return __awaiter(this, void 0, void 0, function* () {
        const fields = (0, tableManager_1.getRowData)(fieldsTitleRow);
        const form = yield getForm(this);
        yield (0, asyncArray_1.asyncForEach)(fields, (fieldName) => __awaiter(this, void 0, void 0, function* () {
            const formField = form.getField(fieldName);
            yield (0, test_1.expect)(formField.el).toBeVisible();
        }));
    });
});
(0, cucumber_1.Then)("поле {string} - поле загрузки изображений.", function (fieldName) {
    return __awaiter(this, void 0, void 0, function* () {
        const form = yield getForm(this);
        const field = form.getField(fieldName);
        const control = yield field.getControl();
        if (control.type == "file") {
            (0, test_1.expect)(yield control.isImage()).toBeTruthy();
        }
    });
});
(0, cucumber_1.Then)("изображение в поле {string} имеет высоту {string} и ширину {string}.", function (fieldName, height, width) {
    return __awaiter(this, void 0, void 0, function* () {
        const form = yield getForm(this);
        const field = form.getField(fieldName);
        const control = yield field.getControl();
        if (control.type == "file") {
            (0, test_1.expect)(control.imageHeight(height)).toBeTruthy();
            (0, test_1.expect)(control.imageWidth(width)).toBeTruthy();
        }
    });
});
(0, cucumber_1.Then)("в поле {string} есть изображение.", function (fieldName) {
    return __awaiter(this, void 0, void 0, function* () {
        const form = yield getForm(this);
        const field = form.getField(fieldName);
        const control = yield field.getControl();
        if (control.type == "file") {
            (0, test_1.expect)(control.hasImageFile()).toBeTruthy();
        }
    });
});
(0, cucumber_1.Then)("открывается форма {string}.", function (title) {
    return __awaiter(this, void 0, void 0, function* () {
        yield expectOpenForm(this, title);
    });
});
(0, cucumber_1.Then)("открывается форма.", function () {
    return __awaiter(this, void 0, void 0, function* () {
        yield expectOpenForm(this);
    });
});
function expectOpenForm(page, title) {
    return __awaiter(this, void 0, void 0, function* () {
        yield getForm(page, {
            title,
            inSideOrModal: true
        });
    });
}
exports.expectOpenForm = expectOpenForm;
(0, cucumber_1.Then)("форма {string} остаётся открытой.", function (title) {
    return __awaiter(this, void 0, void 0, function* () {
        yield getForm(this, {
            title,
            inSideOrModal: true
        });
    });
});
(0, cucumber_1.Then)("форма {string} закрывается.", function (title) {
    return __awaiter(this, void 0, void 0, function* () {
        yield waitForFormClosed(this, title);
    });
});
(0, cucumber_1.Then)("форма закрывается.", function () {
    return __awaiter(this, void 0, void 0, function* () {
        yield waitForFormClosed(this);
    });
});
(0, cucumber_1.Then)("в поле {string} есть значение {string}.", function (fieldName, value) {
    return __awaiter(this, void 0, void 0, function* () {
        const form = yield getForm(this);
        const field = form.getField(fieldName);
        yield expectFieldValue(field, value);
    });
});
(0, cucumber_1.Then)(/^в поле \"([^\1]*)\" со списком изображений (\d+) файл[ов|а]*\./, function (fieldName, filesCount) {
    return __awaiter(this, void 0, void 0, function* () {
        const form = yield getForm(this);
        const field = form.getField(fieldName);
        const imageList = (0, imageList_1.getImageList)(field.el);
        (0, test_1.expect)(yield imageList.imagesCount()).toBe(filesCount);
    });
});
(0, cucumber_1.Then)("в поле {string} есть файл.", function (fieldName) {
    return __awaiter(this, void 0, void 0, function* () {
        const form = yield getForm(this);
        const field = form.getField(fieldName);
        const imageList = (0, imageList_1.getImageList)(field.el);
        (0, test_1.expect)(yield imageList.hasImageFile()).toBeTruthy();
    });
});
(0, cucumber_1.Then)("в поле {string} у файла есть иконка {string}.", function (fieldName, iconName) {
    return __awaiter(this, void 0, void 0, function* () {
        const form = yield getForm(this);
        const field = form.getField(fieldName);
        const control = yield field.getControl();
        if (control.type == "file") {
            if (yield control.hasFile()) {
                (0, test_1.expect)(yield control.getIcon()).toBe(iconName);
                return;
            }
        }
        throw new Error("иконка не найдена");
    });
});
(0, cucumber_1.Then)("поле {string} будет не заполнено.", function (fieldName) {
    return __awaiter(this, void 0, void 0, function* () {
        const form = yield getForm(this);
        const field = form.getField(fieldName);
        const fieldValue = yield field.displayValueAsync();
        (0, test_1.expect)((0, isNullOrEmpty_1.isNullOrEmpty)(fieldValue)).toBeTruthy();
    });
});
(0, cucumber_1.Then)("поле {string} недоступно для редактирования.", function (fieldName) {
    return __awaiter(this, void 0, void 0, function* () {
        const form = yield getForm(this);
        const field = form.getField(fieldName);
        (0, test_1.expect)(yield field.isReadonly()).toBeTruthy();
    });
});
(0, cucumber_1.Then)("поле {string} доступно для редактирования.", function (fieldName) {
    return __awaiter(this, void 0, void 0, function* () {
        const form = yield getForm(this);
        const field = form.getField(fieldName);
        (0, test_1.expect)(yield field.isReadonly()).toBeFalsy();
    });
});
(0, cucumber_1.Then)("на форме есть список {string}.", function (title) {
    return __awaiter(this, void 0, void 0, function* () {
        yield formHasList(this, title);
    });
});
(0, cucumber_1.Then)("на форме есть список.", function () {
    return __awaiter(this, void 0, void 0, function* () {
        yield formHasList(this);
    });
});
function formHasList(page, title) {
    return __awaiter(this, void 0, void 0, function* () {
        const list = yield (0, list_steps_1.getList)(page, title);
        yield (0, test_1.expect)(list.el).toBeVisible();
    });
}
exports.formHasList = formHasList;
/**
 * Список из нескольких записей,
 * Можно указать колонку выбора записей
 *
   Пусть в списке есть следующие записи:
   |     | Наименования_поля | Булево_поле | Поле_с_датой   |
   | [ ] | Значение_1        | [ ]         | 29.02.2024     |
   | [ ] | Значение_2        | [x]         | {текущая дата} |
   | [ ] | Значение_3        | [-]         |                |
 */
(0, cucumber_1.Then)("на форме есть список {string}:", { timeout: -1 }, function (listTitle, dataTable) {
    return __awaiter(this, void 0, void 0, function* () {
        const list = yield (0, list_steps_1.getList)(this, listTitle);
        yield list.isReady();
        yield (0, test_1.expect)(list.el).toBeVisible();
        yield (0, compareByRowsOrder_1.compareByRowsOrder)(list, (0, tableManager_1.getListData)(dataTable));
    });
});
(0, cucumber_1.Then)("в поле {string} появляется ошибка.", function (fieldName) {
    return __awaiter(this, void 0, void 0, function* () {
        const form = yield getForm(this);
        const field = form.getField(fieldName);
        yield field.error.waitFor();
        yield (0, test_1.expect)(field.error).toBeVisible();
    });
});
(0, cucumber_1.Then)("в поле {string} нет ошибки.", function (fieldName) {
    return __awaiter(this, void 0, void 0, function* () {
        const form = yield getForm(this);
        const field = form.getField(fieldName);
        yield field.error.waitFor({ state: "hidden" });
        yield (0, test_1.expect)(field.error).toBeHidden();
    });
});
(0, cucumber_1.Then)("на форме есть ошибка валидации {string}.", function (textContent) {
    return __awaiter(this, void 0, void 0, function* () {
        const form = yield getForm(this);
        yield form.infoBlock.el.waitFor();
        yield (0, test_1.expect)(form.infoBlock.title).toHaveText(/Ошибки валидации/);
        yield (0, test_1.expect)(form.infoBlock.data).toHaveText(textContent);
    });
});
(0, cucumber_1.Then)("на форме нет ошибки валидации {string}.", function (textContent) {
    return __awaiter(this, void 0, void 0, function* () {
        const form = yield getForm(this);
        if (form.infoBlock.title.isHidden())
            return;
        if (form.infoBlock.data.isHidden())
            return;
        (0, test_1.expect)(yield form.infoBlock.data.textContent()).not.toMatch(textContent);
    });
});
(0, cucumber_1.Then)("на форме нет ошибок валидации.", function () {
    return __awaiter(this, void 0, void 0, function* () {
        const form = yield getForm(this);
        yield form.infoBlock.el.waitFor({
            state: "hidden"
        });
        yield (0, test_1.expect)(form.infoBlock.title).not.toHaveText(/Ошибки валидации/);
    });
});
(0, cucumber_1.Then)("поле {string} имеет ширину {int}.", function (fieldName, width) {
    return __awaiter(this, void 0, void 0, function* () {
        const form = yield getForm(this);
        const field = form.getField(fieldName);
        (0, test_1.expect)(width).toBe(yield field.getWidth());
    });
});
(0, cucumber_1.Then)("поле {string} содержит компонент {string}.", function (fieldName, controlCode) {
    return __awaiter(this, void 0, void 0, function* () {
        const form = yield getForm(this);
        const field = form.getField(fieldName);
        const control = yield field.getControl();
        (0, test_1.expect)(controlCode).toBe(control.type);
    });
});
/*
    То недоступны для редактирования следующие поля:
    | Код | Наименование |
*/
(0, cucumber_1.Then)("недоступны для редактирования следующие поля:", function (dataTable) {
    return __awaiter(this, void 0, void 0, function* () {
        const form = yield getForm(this);
        const row = (0, tableManager_1.getRowData)(dataTable);
        let result = true;
        yield (0, asyncArray_1.asyncForEach)(row, (fieldName) => __awaiter(this, void 0, void 0, function* () {
            const field = form.getField(fieldName);
            result && (result = yield field.isReadonly());
        }));
        (0, test_1.expect)(result).toBeTruthy();
    });
});
/*
    То недоступны для редактирования следующие поля:
    | Код | Наименование |
*/
(0, cucumber_1.Then)("доступны для редактирования следующие поля:", function (dataTable) {
    return __awaiter(this, void 0, void 0, function* () {
        const form = yield getForm(this);
        const row = (0, tableManager_1.getRowData)(dataTable);
        const hasSomeOneReadonly = yield (0, asyncArray_1.asyncSome)(row, (fieldName) => form.getField(fieldName).isReadonly());
        (0, test_1.expect)(hasSomeOneReadonly).toBeFalsy();
    });
});
(0, cucumber_1.Then)("поле {string} заблокировано.", function (fieldName) {
    return __awaiter(this, void 0, void 0, function* () {
        const form = yield getForm(this);
        const field = form.getField(fieldName);
        (0, test_1.expect)(yield field.isLocked()).toBeTruthy();
    });
});
(0, cucumber_1.Then)("поле {string} не заблокировано.", function (fieldName) {
    return __awaiter(this, void 0, void 0, function* () {
        const form = yield getForm(this);
        const field = form.getField(fieldName);
        (0, test_1.expect)(yield field.isLocked()).toBeFalsy();
    });
});
(0, cucumber_1.Then)("открывается конструктор форм.", function () {
    return __awaiter(this, void 0, void 0, function* () {
        const form = yield getForm(this);
        (0, test_1.expect)(form.designerWrapper).toHaveClass(/designer/);
    });
});
(0, cucumber_1.Then)("конструктор форм закрывается.", function () {
    return __awaiter(this, void 0, void 0, function* () {
        const form = yield getForm(this);
        (0, test_1.expect)(yield form.designerWrapper).not.toHaveClass(/designer/);
    });
});
(0, cucumber_1.Then)("кнопка {string} на форме активна.", function (buttonTitle) {
    return __awaiter(this, void 0, void 0, function* () {
        const form = yield getForm(this);
        const button = getItem(form, buttonTitle);
        yield (0, test_1.expect)(button).not.toHaveClass(/disabled/);
    });
});
(0, cucumber_1.Then)("кнопка {string} на форме не доступна.", function (buttonTitle) {
    return __awaiter(this, void 0, void 0, function* () {
        const form = yield getForm(this);
        const button = getItem(form, buttonTitle);
        yield (0, test_1.expect)(button).toHaveClass(/disabled/);
    });
});
/** mapping */
(0, cucumber_1.When)("нажимаем радио кнопку {string} на форме.", function (item) {
    return __awaiter(this, void 0, void 0, function* () {
        const form = yield getForm(this);
        const radioPicker = (0, radioPicker_1.getRadioPicker)(form.el);
        (0, test_1.expect)(yield radioPicker.isExistAsync()).toBeTruthy();
        yield (0, radioPicker_1.setRadioPickerValue)(this, radioPicker, item);
    });
});
(0, cucumber_1.When)("на форме заполняем пикер значением {string}.", function (item) {
    return __awaiter(this, void 0, void 0, function* () {
        const form = yield getForm(this);
        const picker = (0, picker_1.getPicker)(form.el);
        (0, test_1.expect)(yield picker.isExistAsync()).toBeTruthy();
        yield (0, picker_1.setPickerValue)(this, picker, item);
    });
});
function expectedFormRecordAsync(form, expectedRecord) {
    return __awaiter(this, void 0, void 0, function* () {
        for (const [fieldName, fieldValue] of Object.entries(expectedRecord)) {
            const field = form.getField(fieldName);
            yield expectFieldValue(field, fieldValue);
        }
    });
}
function expectFieldValue(field, fieldValue) {
    return __awaiter(this, void 0, void 0, function* () {
        (0, test_1.expect)(yield field.displayValueAsync()).toSoftEqual(fieldValue);
    });
}
exports.expectFieldValue = expectFieldValue;
function setValueByField(page, field, value) {
    return __awaiter(this, void 0, void 0, function* () {
        const control = yield field.getControl();
        yield (0, controls_1.setControlValue)(page, control, (0, dateMatcher_1.parseIfAlias)(value));
    });
}
exports.setValueByField = setValueByField;
function clearFieldValue(field) {
    return __awaiter(this, void 0, void 0, function* () {
        const control = yield field.getControl();
        yield (0, controls_1.clearControlValue)(control);
    });
}
exports.clearFieldValue = clearFieldValue;
function waitForFormClosed(page, title) {
    return __awaiter(this, void 0, void 0, function* () {
        yield page.waitFor("close", {
            container: "modal",
            title
        });
        yield page.waitFor("close", {
            container: "side",
            title
        });
    });
}
exports.waitForFormClosed = waitForFormClosed;
function getForm(page, options) {
    return __awaiter(this, void 0, void 0, function* () {
        const form = yield page.getForm(options);
        (0, test_1.expect)(yield form.waitForReady()).toBeTruthy();
        return form;
    });
}
exports.getForm = getForm;
function getItem(form, item, byCode) {
    const toolbar = form.toolbar;
    const itemFromToolbar = getItemFromToolbar(toolbar, item, byCode);
    return itemFromToolbar.or(form.workflow.getAction(item));
}
function getItemFromToolbar(toolbar, item, byCode) {
    if (byCode)
        return toolbar.item(item);
    if (item == "Закрыть")
        return toolbar.item("close");
    if (item == "Ещё" || item == "Еще")
        return toolbar.more;
    if (item == "Сохранить и обновить" || item == "Сохранить и продолжить редактирование")
        return toolbar.item("save-refresh");
    return toolbar.itemByTitle(item);
}
