"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const cucumber_1 = require("@cucumber/cucumber");
const test_1 = require("@playwright/test");
const asyncArray_1 = require("../../../utils/asyncArray");
const dateMatcher_1 = require("../../../utils/date/dateMatcher/dateMatcher");
const getSelector_1 = require("../../../utils/getSelector");
const tableManager_1 = require("../../../utils/tableManager");
const dropdown_steps_1 = require("../../dropdown/dropdown.steps");
const checkbox_1 = require("../../form/Field/fieldControls/checkbox/checkbox");
const list_steps_1 = require("../list.steps");
const columnMenu_1 = require("./columnMenu");
const setup_1 = require("../../../../setup/setup");
(0, cucumber_1.When)("в колоночном меню нажимаем на значение {string}.", function (valueItemTitle) {
    return __awaiter(this, void 0, void 0, function* () {
        const columnMenu = yield getColumnMenuAsync(this);
        const valueItem = yield getValueItem(columnMenu, valueItemTitle);
        yield valueItem.title.click();
        yield columnMenu.valuesFilter.waitForChange();
    });
});
(0, cucumber_1.When)("проматываем колоночное меню до конца.", function () {
    return __awaiter(this, void 0, void 0, function* () {
        const columnMenu = yield getColumnMenuAsync(this);
        yield columnMenu.valuesFilter.values.scrollToLast();
    });
});
(0, cucumber_1.When)("в колоночном меню убираем значение {string}.", function (value) {
    return __awaiter(this, void 0, void 0, function* () {
        const columnMenu = yield getColumnMenuAsync(this);
        const valueItem = yield getValueItem(columnMenu, value);
        if ((yield valueItem.value()) != checkbox_1.booleanData.false) {
            yield valueItem.checkbox.click();
        }
        (0, test_1.expect)(yield valueItem.value()).toBe(checkbox_1.booleanData.false);
    });
});
(0, cucumber_1.When)("в колоночном меню выбираем значение {string}.", function (value) {
    return __awaiter(this, void 0, void 0, function* () {
        const columnMenu = yield getColumnMenuAsync(this);
        const valueItem = yield getValueItem(columnMenu, value);
        if ((yield valueItem.value()) != checkbox_1.booleanData.truthy) {
            yield valueItem.checkbox.click();
        }
        (0, test_1.expect)(yield valueItem.value()).toBe(checkbox_1.booleanData.truthy);
        yield columnMenu.valuesFilter.waitForChange();
        yield columnMenu.valuesFilter.waitForLoading();
    });
});
(0, cucumber_1.When)(`в колоночном меню выбираем пункт {string}.`, function (itemTitle) {
    return __awaiter(this, void 0, void 0, function* () {
        const columnMenu = yield getColumnMenuAsync(this);
        const item = columnMenu.itemByTitle(itemTitle);
        yield item.click();
    });
});
(0, cucumber_1.When)("в колоночном меню вводим быстрый фильтр {string}.", function (filterValue) {
    return __awaiter(this, void 0, void 0, function* () {
        const columnMenu = yield getColumnMenuAsync(this);
        const quickFilter = yield columnMenu.getQuickFilter();
        yield quickFilter.control.textEl.fill((0, dateMatcher_1.parseIfAlias)(filterValue));
        yield quickFilter.waitForChange();
    });
});
(0, cucumber_1.When)("в колоночном меню вводим фильтр по значению {string}.", function (filterValue) {
    return __awaiter(this, void 0, void 0, function* () {
        const columnMenu = yield getColumnMenuAsync(this);
        const valuesFilter = columnMenu.valuesFilter;
        yield valuesFilter.input.textEl.fill((0, dateMatcher_1.parseIfAlias)(filterValue));
        yield valuesFilter.waitForChange();
        yield columnMenu.valuesFilter.waitForLoading();
    });
});
(0, cucumber_1.When)("нажимаем на иконку сортировки в заголовке колонки {string}.", function (columnTitle) {
    return __awaiter(this, void 0, void 0, function* () {
        const list = yield (0, list_steps_1.getList)(this);
        const headerRow = list.getHeaderRow();
        const headerCell = headerRow.getCell(columnTitle);
        const icon = headerCell.actions.clearSorting;
        yield icon.click();
    });
});
(0, cucumber_1.When)("нажимаем на иконку фильтра в заголовке колонки {string}.", function (columnTitle) {
    return __awaiter(this, void 0, void 0, function* () {
        const list = yield (0, list_steps_1.getList)(this);
        const headerRow = list.getHeaderRow();
        const headerCell = headerRow.getCell(columnTitle);
        const icon = headerCell.actions.clearFilter;
        yield icon.click();
    });
});
(0, cucumber_1.When)("в колоночном меню у быстрого фильтра нажимаем на знак очищения значения", function () {
    return __awaiter(this, void 0, void 0, function* () {
        const columnMenu = yield getColumnMenuAsync(this);
        const quickFilter = yield columnMenu.getQuickFilter();
        yield quickFilter.control.textEl.clear();
        yield quickFilter.waitForChange();
    });
});
(0, cucumber_1.When)("в колоночном меню нажимаем на дейтпикер.", function () {
    return __awaiter(this, void 0, void 0, function* () {
        const columnMenu = yield getColumnMenuAsync(this);
        const quickFilter = yield columnMenu.getQuickFilter();
        yield quickFilter.showCalendar();
    });
});
(0, cucumber_1.When)("в календаре выбираем число {string} нынешнего месяца и года.", function (date) {
    return __awaiter(this, void 0, void 0, function* () {
        yield chooseCalendarDate(this, date);
    });
});
(0, cucumber_1.Then)("выпадающее меню агрегации состоит из элементов:", { timeout: setup_1.config.largeTimeout }, function (AggregationRow) {
    return __awaiter(this, void 0, void 0, function* () {
        const dropdown = yield (0, dropdown_steps_1.getReadyDropdown)(this.dropdown);
        const aggregation = (0, columnMenu_1.getAggregation)(dropdown);
        const aggregationRecord = (0, tableManager_1.getRecord)(AggregationRow);
        const propsCount = Object.keys(aggregationRecord).length;
        (0, test_1.expect)(yield aggregation.itemsLength()).toBe(propsCount);
        yield (0, asyncArray_1.asyncForEach)(Object.keys(aggregationRecord), (itemTitle) => __awaiter(this, void 0, void 0, function* () {
            const item = aggregation.itemByTitle(itemTitle);
            yield (0, test_1.expect)(item.el).toBeVisible();
            const itemValue = yield item.value();
            (0, test_1.expect)(itemValue).toBe(aggregationRecord[itemTitle]);
        }));
    });
});
(0, cucumber_1.Then)("открывается календарь.", function () {
    return __awaiter(this, void 0, void 0, function* () {
        const calendar = yield getCalendarDropdown(this);
        yield calendar.isVisible();
    });
});
(0, cucumber_1.Then)("появляется колоночное меню.", function () {
    return __awaiter(this, void 0, void 0, function* () {
        yield getColumnMenuAsync(this);
    });
});
(0, cucumber_1.Then)("колоночное меню закрывается.", function () {
    return __awaiter(this, void 0, void 0, function* () {
        const columnMenu = (0, columnMenu_1.getColumnMenu)(this.dropdown);
        yield columnMenu.el.waitFor({ state: "hidden" });
        (0, test_1.expect)(yield columnMenu.isExist()).toBeFalsy();
    });
});
(0, cucumber_1.Then)("в колоночном меню есть значения:", function (tableData) {
    return __awaiter(this, void 0, void 0, function* () {
        const columnMenu = yield getColumnMenuAsync(this);
        const rows = (0, tableManager_1.getRowsData)(tableData);
        yield (0, asyncArray_1.asyncForEach)(rows, (row) => __awaiter(this, void 0, void 0, function* () {
            if (row.length != 2)
                throw new Error("Таблица сопоставления значений для колоночного меню должна содержать 2 столбца.");
            const valueItem = yield getValueItem(columnMenu, row[1]);
            (0, test_1.expect)(yield valueItem.value()).toSoftEqual(row[0]);
        }));
    });
});
(0, cucumber_1.Then)("значения колоночного меню расположены в следующем порядке:", function (tableData) {
    return __awaiter(this, void 0, void 0, function* () {
        const columnMenu = yield getColumnMenuAsync(this);
        const rows = (0, tableManager_1.getRowsData)(tableData);
        yield (0, asyncArray_1.asyncForEach)(rows, (row, index) => __awaiter(this, void 0, void 0, function* () {
            if (row.length != 2)
                throw new Error("Таблица сопоставления значений для колоночного меню должна содержать 2 столбца.");
            const valueItem = columnMenu.valuesFilter.values.item(index);
            (0, test_1.expect)(yield valueItem.value()).toSoftEqual(row[0]);
            (0, test_1.expect)(yield valueItem.title.textContent()).toSoftEqual(row[1]);
        }));
    });
});
(0, cucumber_1.Then)("в колоночном меню у быстрого фильтра есть значение {string}", function (filterValue) {
    return __awaiter(this, void 0, void 0, function* () {
        const columnMenu = yield getColumnMenuAsync(this);
        const quickFilter = yield columnMenu.getQuickFilter();
        yield quickFilter.control.textEl.textContent();
    });
});
(0, cucumber_1.Then)("в колоночном меню все значения не выбраны.", function () {
    return __awaiter(this, void 0, void 0, function* () {
        const columnMenu = yield getColumnMenuAsync(this);
        yield columnMenu.valuesFilter.waitForLoading();
        const isAllSelected = yield columnMenu.valuesFilter.values.isAllSelected();
        (0, test_1.expect)(isAllSelected).toBeTruthy();
    });
});
(0, cucumber_1.Then)("в колоночном меню есть пункт {string}.", function (itemTitle) {
    return __awaiter(this, void 0, void 0, function* () {
        const columnMenu = yield getColumnMenuAsync(this);
        const item = columnMenu.itemByTitle(itemTitle);
        yield (0, test_1.expect)(item).toBeVisible();
    });
});
function getColumnMenuAsync(page) {
    return __awaiter(this, void 0, void 0, function* () {
        const dd = yield (0, dropdown_steps_1.getReadyDropdown)(page.dropdown);
        const columnMenu = (0, columnMenu_1.getColumnMenu)(dd);
        yield columnMenu.el.waitFor();
        (0, test_1.expect)(yield columnMenu.isExist()).toBeTruthy();
        return columnMenu;
    });
}
function getValueItem(columnMenu, valueItemTitle) {
    return __awaiter(this, void 0, void 0, function* () {
        yield columnMenu.valuesFilter.waitForLoading();
        return yield columnMenu.valuesFilter.values.get((0, dateMatcher_1.parseIfAlias)(valueItemTitle));
    });
}
function getCalendarDropdown(page) {
    return __awaiter(this, void 0, void 0, function* () {
        const dropdown = yield (0, dropdown_steps_1.getReadyDropdown)(page.dropdown);
        return dropdown.el.locator((0, getSelector_1.getSelector)({ testid: "datepicker" }));
    });
}
function chooseCalendarDate(page, date) {
    return __awaiter(this, void 0, void 0, function* () {
        const dropdown = yield getCalendarDropdown(page);
        const days = dropdown.locator((0, getSelector_1.getSelector)({ testid: "calendar-day" }));
        const day = days.locator(`:has-text("${date}")`);
        yield day.click();
    });
}
