"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getGroupingRow = void 0;
const getSelector_1 = require("../../../../utils/getSelector");
const numberAndIndex_1 = require("../../../../utils/numberAndIndex");
const pathList_1 = require("../../../../utils/pathList");
const hierarchyRow_1 = require("../hierarchy/hierarchyRow");
const groupingChildRow_1 = require("./groupingChildRow");
const icon_1 = require("../../../icon/icon");
function getGroupingRow(tbody, groupLabelsHierarchy) {
    const baseSelector = mapToSelector(groupLabelsHierarchy);
    let rowNumber = 0;
    const getEl = (child) => {
        let result = baseSelector;
        if (child > 0) {
            for (let i = 0; i < child; i++) {
                result += " + tr:not(.grouping-row)";
            }
            return tbody.locator(result).nth(rowNumber);
        }
        if (child > 0)
            return tbody.locator(result).nth(rowNumber);
        return tbody.locator(result).first();
    };
    const selectors = {
        labelIcon: (0, getSelector_1.getSelector)({
            testid: "grouping-label-icon"
        }),
        labelMark: (0, getSelector_1.getSelector)({
            testid: "grouping-label-mark"
        }),
        groupCell: (0, getSelector_1.getSelector)({
            testid: "group-hierarchy-cell"
        }),
        toggler: (0, getSelector_1.getSelector)({
            testid: "row-toggler"
        }),
        formOpener: (0, getSelector_1.getSelector)({
            testid: "form-opener"
        })
    };
    return {
        get el() {
            return getEl();
        },
        getChildDataRow(childNumber, headerRow) {
            return (0, groupingChildRow_1.getGroupingChildRow)(getEl(childNumber), headerRow);
        },
        takeByNumber(number) {
            rowNumber = (0, numberAndIndex_1.getIndexFromNumber)(number);
        },
        isCollapsed() {
            return __awaiter(this, void 0, void 0, function* () {
                const toggleableCell = this.getToggleableCell();
                return toggleableCell.isCollapsed();
            });
        },
        isOpen() {
            return __awaiter(this, void 0, void 0, function* () {
                const toggleableCell = this.getToggleableCell();
                return toggleableCell.isOpen();
            });
        },
        getToggleableCell() {
            return (0, hierarchyRow_1.getToggleableCell)(this.el.locator(selectors.groupCell));
        },
        get toggler() {
            return this.el.locator(selectors.toggler);
        },
        get formOpener() {
            return this.el.locator(selectors.formOpener);
        },
        get labelIcon() {
            return (0, icon_1.getIcon)(this.el.locator(selectors.labelIcon));
        },
        get labelMark() {
            return this.el.locator(selectors.labelMark);
        }
    };
}
exports.getGroupingRow = getGroupingRow;
function mapToSelector(groupLabelsHierarchy) {
    const path = new pathList_1.PathList(groupLabelsHierarchy).path;
    let elSelector = "";
    path.forEach((p, index) => {
        const { label, value } = extractLabelAndValue(p);
        let selector = (0, getSelector_1.getSelector)({
            testid: "grouping-row",
            label,
            level: index.toString()
        });
        const valueSelector = (0, getSelector_1.getSelector)({
            testid: "grouping-row-value"
        });
        selector += `:has(${valueSelector}:has-text("${value}"))`;
        if (index == 0)
            elSelector += selector;
        else
            elSelector += " ~ " + selector;
    });
    return elSelector;
}
/**
 * label | value -> Дата | 21.03.2021
 * value -> 21.03.2021
 */
function extractLabelAndValue(groupIdentifier) {
    var _a, _b, _c;
    const data = groupIdentifier.split("|");
    if (data.length == 1) {
        return {
            label: void 0,
            value: ((_a = data[0]) === null || _a === void 0 ? void 0 : _a.trim()) || void 0
        };
    }
    return {
        label: ((_b = data[0]) === null || _b === void 0 ? void 0 : _b.trim()) || void 0,
        value: ((_c = data[1]) === null || _c === void 0 ? void 0 : _c.trim()) || void 0
    };
}
