"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const cucumber_1 = require("@cucumber/cucumber");
const list_steps_1 = require("../../list.steps");
const test_1 = require("@playwright/test");
const tableManager_1 = require("../../../../utils/tableManager");
const asyncArray_1 = require("../../../../utils/asyncArray");
const numberAndIndex_1 = require("../../../../utils/numberAndIndex");
const rowCompare_steps_1 = require("../../steps/rowCompare.steps");
(0, cucumber_1.Given)("запись №{int} не имеет дочерних записей.", function (rowNumber) {
    return __awaiter(this, void 0, void 0, function* () {
        const list = yield (0, list_steps_1.getList)(this);
        const row = yield list.getHierarchyRow(rowNumber);
        const hasChildren = yield row.hasChildren();
        (0, test_1.expect)(hasChildren).toBeFalsy();
    });
});
(0, cucumber_1.Given)("запись №{int} имеет дочерние записи.", function (rowNumber) {
    return __awaiter(this, void 0, void 0, function* () {
        const list = yield (0, list_steps_1.getList)(this);
        const row = yield list.getHierarchyRow(rowNumber);
        const hasChildren = yield row.hasChildren();
        (0, test_1.expect)(hasChildren).toBeTruthy();
    });
});
(0, cucumber_1.When)("нажимаем кнопку {string} в записи №{int}.", function (actionTitle, rowNumber) {
    return __awaiter(this, void 0, void 0, function* () {
        const list = yield (0, list_steps_1.getList)(this);
        const row = yield list.getRow(rowNumber);
        yield row.getAction(actionTitle).click();
    });
});
(0, cucumber_1.When)("запись №{int} содержит кнопку {string}.", function (rowNumber, actionTitle) {
    return __awaiter(this, void 0, void 0, function* () {
        const list = yield (0, list_steps_1.getList)(this);
        const row = yield list.getRow(rowNumber);
        yield (0, test_1.expect)(row.getAction(actionTitle)).toBeVisible();
    });
});
(0, cucumber_1.When)("запись №{int} не содержит кнопку {string}.", function (rowNumber, actionTitle) {
    return __awaiter(this, void 0, void 0, function* () {
        const list = yield (0, list_steps_1.getList)(this);
        const row = yield list.getRow(rowNumber);
        yield (0, test_1.expect)(row.getAction(actionTitle)).toBeHidden();
    });
});
(0, cucumber_1.Then)("запись №{int} не содержит дочерних записей.", function (rowNumber) {
    return __awaiter(this, void 0, void 0, function* () {
        const list = yield (0, list_steps_1.getList)(this);
        const row = yield list.getHierarchyRow(rowNumber);
        const hasChildren = yield row.hasChildren();
        (0, test_1.expect)(hasChildren).toBeFalsy();
    });
});
(0, cucumber_1.Then)("запись №{int} содержит дочерние записи.", function (rowNumber) {
    return __awaiter(this, void 0, void 0, function* () {
        const list = yield (0, list_steps_1.getList)(this);
        const row = yield list.getHierarchyRow(rowNumber);
        const hasChildren = yield row.hasChildren();
        (0, test_1.expect)(hasChildren).toBeTruthy();
    });
});
(0, cucumber_1.Then)("запись №{int} содержит дочерние записи:", function (rowNumber, dataTable) {
    return __awaiter(this, void 0, void 0, function* () {
        const list = yield (0, list_steps_1.getList)(this);
        const hierarchyRow = yield list.getHierarchyRow(rowNumber);
        (0, test_1.expect)(yield hierarchyRow.hasChildren()).toBeTruthy();
        (0, test_1.expect)(yield hierarchyRow.isOpen()).toBeTruthy();
        const listData = (0, tableManager_1.getListData)(dataTable);
        const rows = listData.getRows();
        const childrenCount = yield hierarchyRow.childrenCount();
        if (childrenCount != rows.length)
            throw new Error(`Количество дочерних записей не совпадает ожидалось ${rows.length} найдено ${childrenCount}`);
        const currentLevel = yield hierarchyRow.getLevel();
        yield (0, asyncArray_1.asyncForEach)(rows, (row, index) => __awaiter(this, void 0, void 0, function* () {
            const rowNumber = (0, numberAndIndex_1.getNumberFromIndex)(index);
            const listRow = yield hierarchyRow.getChildren((0, numberAndIndex_1.getNumberFromIndex)(index));
            if (!(yield listRow.isHierarchy()))
                throw new Error(`Не удалось сопоставить запись №${rowNumber}, т.к. соответствующая запись в списке не иерархическая`);
            const nextRowLevel = yield listRow.getLevel();
            if (nextRowLevel - currentLevel != 1)
                throw new Error(`Не удалось сопоставить запись №${rowNumber}, т.к. не соответствует вложенность записей`);
            yield (0, rowCompare_steps_1.rowCompare)(listRow, row);
        }));
    });
});
(0, cucumber_1.Then)("запись №{int} содержит {int} дочерних записей.", function (rowNumber, childrenCount) {
    return __awaiter(this, void 0, void 0, function* () {
        const list = yield (0, list_steps_1.getList)(this);
        const row = yield list.getHierarchyRow(rowNumber);
        (0, test_1.expect)(yield row.childrenCount()).toBe(childrenCount);
    });
});
(0, cucumber_1.Given)("запись №{int} свёрнута.", rowCollapsedStep);
(0, cucumber_1.Then)("запись №{int} будет свёрнута.", rowCollapsedStep);
function rowCollapsedStep(rowNumber) {
    return __awaiter(this, void 0, void 0, function* () {
        const list = yield (0, list_steps_1.getList)(this);
        const row = yield list.getHierarchyRow(rowNumber);
        const isOpen = yield row.isCollapsed();
        (0, test_1.expect)(isOpen).toBeTruthy();
    });
}
(0, cucumber_1.Then)("запись №{int} развёрнута.", function (rowNumber) {
    return __awaiter(this, void 0, void 0, function* () {
        const list = yield (0, list_steps_1.getList)(this);
        const row = yield list.getHierarchyRow(rowNumber);
        const isOpen = yield row.isOpen();
        (0, test_1.expect)(isOpen).toBeTruthy();
    });
});
