"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getToggleableCell = exports.getHierarchyRow = void 0;
const getSelector_1 = require("../../../../utils/getSelector");
function getHierarchyRow(baseRow, options) {
    let toggleableCell = null;
    const selectors = {
        cellHierarchy: (0, getSelector_1.getSelector)({ testid: "hierarchy-cell" })
    };
    return Object.assign(Object.assign({}, baseRow), { getHierarchyCell() {
            return __awaiter(this, void 0, void 0, function* () {
                if (toggleableCell)
                    return toggleableCell;
                const fieldCells = yield baseRow.getFieldsCells();
                toggleableCell = getToggleableCell(fieldCells[0].el);
                return toggleableCell;
            });
        },
        hasChildren() {
            return __awaiter(this, void 0, void 0, function* () {
                const hierarchyCell = yield this.getHierarchyCell();
                return hierarchyCell.hasChildren();
            });
        },
        isOpen() {
            return __awaiter(this, void 0, void 0, function* () {
                if (yield this.hasChildren()) {
                    const hierarchyCell = yield this.getHierarchyCell();
                    return hierarchyCell.isOpen();
                }
                throw new Error("Запись не может быть раскрыта, т.к. не содержит дочерних записей");
            });
        },
        isCollapsed() {
            return __awaiter(this, void 0, void 0, function* () {
                if (yield this.hasChildren()) {
                    const hierarchyCell = yield this.getHierarchyCell();
                    return hierarchyCell.isCollapsed();
                }
                throw new Error("Запись не может быть скрыта, т.к. не содержит дочерних записей");
            });
        },
        getLevel() {
            return __awaiter(this, void 0, void 0, function* () {
                const hierarchyCell = yield this.getHierarchyCell();
                const level = yield hierarchyCell.el.getAttribute((0, getSelector_1.getAttribute)("level"));
                return parseInt(level);
            });
        },
        getChildren(rowNumber) {
            return __awaiter(this, void 0, void 0, function* () {
                const nextHierarchy = getHierarchyRow(yield options.getNextRow(rowNumber), {
                    getNextRow: (nextRowNumber) => options.getNextRow(rowNumber + nextRowNumber),
                    tbody: options.tbody
                });
                return nextHierarchy;
            });
        },
        isHierarchy() {
            return this.el.locator(selectors.cellHierarchy).isVisible();
        },
        childrenCount() {
            return __awaiter(this, void 0, void 0, function* () {
                const rowNumber = yield this.getRowNumber();
                const levelAttr = (0, getSelector_1.getAttribute)("level");
                const childLevel = (yield this.getLevel()) + 1;
                return yield options.tbody.locator(`xpath=//tr[position() > ${rowNumber}]`).evaluateAll((trElements, options) => {
                    let i;
                    for (i = 0; i < trElements.length; i++) {
                        const element = trElements[i].querySelector(options.hierarchyCellSelector);
                        if (!element)
                            break;
                        const elLevel = parseInt(element.getAttribute(options.levelAttr));
                        if (elLevel != options.childLevel)
                            break;
                    }
                    return i;
                }, {
                    hierarchyCellSelector: selectors.cellHierarchy,
                    levelAttr,
                    childLevel: childLevel
                });
            });
        } });
}
exports.getHierarchyRow = getHierarchyRow;
function getToggleableCell(cell) {
    const toggler = cell.locator((0, getSelector_1.getSelector)({
        testid: "row-toggler"
    }));
    const openStateSelector = ".icon-minus-square";
    const collapsedStateSelector = ".icon-plus-square";
    return {
        el: cell,
        hasChildren() {
            return toggler.isVisible();
        },
        isOpen() {
            return __awaiter(this, void 0, void 0, function* () {
                const isOpen = yield toggler.locator(openStateSelector).isVisible();
                const isClose = yield toggler.locator(collapsedStateSelector).isVisible();
                return isOpen && !isClose;
            });
        },
        isCollapsed() {
            return __awaiter(this, void 0, void 0, function* () {
                const isOpen = yield toggler.locator(openStateSelector).isVisible();
                const isClose = yield toggler.locator(collapsedStateSelector).isVisible();
                return isClose && !isOpen;
            });
        }
    };
}
exports.getToggleableCell = getToggleableCell;
