"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getHeaderCell = exports.getHeaderRow = void 0;
const asyncArray_1 = require("../../../utils/asyncArray");
const getSelector_1 = require("../../../utils/getSelector");
const checkbox_1 = require("../../form/Field/fieldControls/checkbox/checkbox");
function getHeaderRow(parentEl) {
    return {
        el: parentEl.locator(".grid-row-header"),
        getCell(title) {
            return getHeaderCell(this.el.locator(`th:has-text("${title}")`).first());
        },
        getCellByIndex(cellIndex) {
            return getHeaderCell(this.el.locator(`th`).nth(cellIndex));
        },
        selectCell() {
            return __awaiter(this, void 0, void 0, function* () {
                const cells = yield this.getAllCells();
                const selectCellIndex = yield (0, asyncArray_1.asyncFindIndex)(cells, function (cell) {
                    return __awaiter(this, void 0, void 0, function* () {
                        const isSelect = yield (cell === null || cell === void 0 ? void 0 : cell.isSelect());
                        return isSelect;
                    });
                });
                return this.getCellByIndex(selectCellIndex);
            });
        },
        cellsCount() {
            return __awaiter(this, void 0, void 0, function* () {
                const count = yield this.el.locator("th").count();
                return count;
            });
        },
        getAllCells() {
            return __awaiter(this, void 0, void 0, function* () {
                const cells = [];
                const cellsCount = yield this.cellsCount();
                for (let i = 0; i < cellsCount; i++) {
                    const headerCell = this.getCellByIndex(i);
                    cells.push(headerCell);
                }
                return cells;
            });
        },
        cellsValue(options) {
            return __awaiter(this, void 0, void 0, function* () {
                const result = [];
                if (options === null || options === void 0 ? void 0 : options.hasSelect) {
                    const selectCell = yield this.selectCell();
                    const cellValue = yield selectCell.value();
                    result.push(cellValue);
                }
                const start = yield this.firstFieldCellIndex();
                const cellsCount = yield this.cellsCount();
                for (let i = start; i < cellsCount; i++) {
                    const cell = this.getCellByIndex(i);
                    const cellValue = yield cell.value();
                    result.push(cellValue);
                }
                return result;
            });
        },
        firstFieldCellIndex() {
            return __awaiter(this, void 0, void 0, function* () {
                const cells = yield this.getAllCells();
                const cellIndex = yield (0, asyncArray_1.asyncFindIndex)(cells, (cell) => __awaiter(this, void 0, void 0, function* () {
                    if (yield cell.isSelect())
                        return false;
                    if (yield cell.isGrouping())
                        return false;
                    const cellValue = yield cell.value();
                    return cellValue != "" && cellValue != null;
                }));
                return cellIndex;
            });
        },
        groupingCells() {
            return __awaiter(this, void 0, void 0, function* () {
                const cells = yield this.getAllCells();
                const groupingCells = [];
                yield (0, asyncArray_1.asyncForEach)(cells, function (cell) {
                    return __awaiter(this, void 0, void 0, function* () {
                        const isGrouping = yield (cell === null || cell === void 0 ? void 0 : cell.isGrouping());
                        if (isGrouping)
                            groupingCells.push(cell);
                    });
                });
                return groupingCells;
            });
        }
    };
}
exports.getHeaderRow = getHeaderRow;
function getHeaderCell(cell) {
    return {
        el: cell,
        isSelect() {
            var _a;
            return __awaiter(this, void 0, void 0, function* () {
                const classList = yield this.el.getAttribute("class");
                if (!classList)
                    return false;
                return ((_a = classList.match(/select-cell/)) === null || _a === void 0 ? void 0 : _a.length) == 1;
            });
        },
        isGrouping() {
            var _a;
            return __awaiter(this, void 0, void 0, function* () {
                const classList = yield this.el.getAttribute("class");
                if (!classList)
                    return false;
                return ((_a = classList.match(/grouping-col/)) === null || _a === void 0 ? void 0 : _a.length) == 1;
            });
        },
        isFormOpener() {
            var _a;
            return __awaiter(this, void 0, void 0, function* () {
                const classList = yield this.el.getAttribute("class");
                if (!classList)
                    return false;
                return ((_a = classList.match(/form-opener/)) === null || _a === void 0 ? void 0 : _a.length) == 1;
            });
        },
        getBooleanValue() {
            return __awaiter(this, void 0, void 0, function* () {
                const cellValue = yield (0, checkbox_1.getBooleanValue)(this.el);
                return (0, checkbox_1.getBooleanFromData)(cellValue);
            });
        },
        value() {
            return __awaiter(this, void 0, void 0, function* () {
                if (yield (0, checkbox_1.isBoolean)(this.el)) {
                    const cellValue = yield (0, checkbox_1.getBooleanValue)(this.el);
                    return cellValue;
                }
                const cellValue = yield cell.textContent();
                return cellValue;
            });
        },
        getDescription() {
            return this.el.getAttribute((0, getSelector_1.getAttribute)("description"));
        },
        get actions() {
            return getHeaderCellActions(this.el.locator((0, getSelector_1.getSelector)({ testid: "column-actions" })));
        }
    };
}
exports.getHeaderCell = getHeaderCell;
function getHeaderCellActions(parentEl) {
    return {
        get edit() {
            return parentEl.locator(".icon-cog");
        },
        get clearFilter() {
            return parentEl.locator(`[code="clear-filter"]`);
        },
        get clearSorting() {
            return parentEl.locator(`[code="clear-sorting"]`);
        }
    };
}
