"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getList = exports.openForm = exports.clickButtonFromListStep = void 0;
const cucumber_1 = require("@cucumber/cucumber");
const test_1 = require("@playwright/test");
const setup_1 = require("../../../setup/setup");
const asyncArray_1 = require("../../utils/asyncArray");
const hotkeys_1 = require("../../utils/hotkeys");
const isNullOrEmpty_1 = require("../../utils/isNullOrEmpty");
const tableManager_1 = require("../../utils/tableManager");
const dropdown_steps_1 = require("../dropdown/dropdown.steps");
const checkbox_1 = require("../form/Field/fieldControls/checkbox/checkbox");
const row_1 = require("./row/row");
(0, cucumber_1.Given)("список не пустой.", function () {
    return __awaiter(this, void 0, void 0, function* () {
        const list = yield getList(this);
        (0, test_1.expect)(yield list.isEmpty()).toBeFalsy();
    });
});
(0, cucumber_1.Given)("в списке есть не активная кнопка {string}.", function (buttonTitle) {
    return __awaiter(this, void 0, void 0, function* () {
        const list = yield getList(this);
        yield expectListItemDisabled(list, buttonTitle);
    });
});
function extendedMenuHasAction(buttonTitle) {
    return __awaiter(this, void 0, void 0, function* () {
        const list = yield getList(this);
        yield getItemFromList(list, "Ещё").click();
        const dropdown = yield (0, dropdown_steps_1.getReadyDropdown)(this.dropdown);
        (0, test_1.expect)(yield dropdown.itemByTitle(buttonTitle).isVisible()).toBeFalsy();
    });
}
(0, cucumber_1.Given)("в расширенном меню списка нет кнопки {string}.", extendedMenuHasAction);
(0, cucumber_1.Then)("в списке в расширенном меню нет кнопки {string}.", extendedMenuHasAction);
(0, cucumber_1.Given)("в списке есть кнопки:", { timeout: setup_1.config.largeTimeout }, function (buttonNamesRow) {
    return __awaiter(this, void 0, void 0, function* () {
        const buttons = (0, tableManager_1.getRowData)(buttonNamesRow);
        const list = yield getList(this);
        yield listExpectButtons(list, buttons);
    });
});
(0, cucumber_1.When)("в списке нажимаем на заголовок колонки {string}.", function (columnTitle) {
    return __awaiter(this, void 0, void 0, function* () {
        const list = yield getList(this);
        const headerRow = list.getHeaderRow();
        const headerCell = yield headerRow.getCell(columnTitle);
        yield headerCell.el.click();
    });
});
(0, cucumber_1.When)("нажимаем кнопку {string} в расширенном меню списка.", function (buttonTitle) {
    return __awaiter(this, void 0, void 0, function* () {
        const list = yield getList(this);
        yield getItemFromList(list, "Ещё").click();
        yield (0, dropdown_steps_1.dropdownPickItem)(this, buttonTitle);
    });
});
(0, cucumber_1.When)("нажимаем кнопку {string} в списке.", { timeout: -1 }, function (buttonTitle) {
    return __awaiter(this, void 0, void 0, function* () {
        yield clickButtonFromListStep(this, buttonTitle);
    });
});
function clickButtonFromListStep(page, buttonTitle) {
    return __awaiter(this, void 0, void 0, function* () {
        const list = yield getList(page);
        const item = getItemFromList(list, buttonTitle);
        // Проверяем вручную visible, stable элемента. Т.к. обычный click также проверяет элемент на возможность обрабатывать события нажатия.
        // И в некоторых ситуациях это не нужно MDTS-3590.
        // https://playwright.dev/docs/actionability#introduction
        yield item.waitFor();
        yield item.scrollIntoViewIfNeeded();
        yield item.click({ force: true });
    });
}
exports.clickButtonFromListStep = clickButtonFromListStep;
(0, cucumber_1.When)("в списке меняем язык на {string}.", function (language) {
    return __awaiter(this, void 0, void 0, function* () {
        const list = yield getList(this);
        const item = getItemFromList(list, "data-ext", true);
        yield item.click();
        yield (0, dropdown_steps_1.dropdownPickItem)(this, language);
    });
});
(0, cucumber_1.When)("нажимаем кнопку редактирования записи №{int}.", function (rowNumber) {
    return __awaiter(this, void 0, void 0, function* () {
        yield openForm(this, rowNumber);
    });
});
function openForm(page, rowNumber) {
    return __awaiter(this, void 0, void 0, function* () {
        const list = yield getList(page);
        const formOpener = yield list.formOpener(rowNumber);
        yield formOpener.click();
    });
}
exports.openForm = openForm;
(0, cucumber_1.When)("выделяем запись №{int} в списке.", function (rowNumber) {
    return __awaiter(this, void 0, void 0, function* () {
        const list = yield getList(this);
        const selectCell = yield list.selectRowCell(rowNumber);
        yield selectCell.el.click();
    });
});
(0, cucumber_1.When)("выделяем все записи в списке.", function () {
    return __awaiter(this, void 0, void 0, function* () {
        const list = yield getList(this);
        yield list.selectAllRowsAsync();
    });
});
(0, cucumber_1.When)("вводим значение {string} в ячейку колонки {string} строки №{int}.", { timeout: setup_1.config.largeTimeout }, function (value, columnTitle, rowNumber) {
    return __awaiter(this, void 0, void 0, function* () {
        const list = yield getList(this);
        const row = yield list.getRow(rowNumber);
        const cell = yield row.getCellAsync(columnTitle);
        yield (0, row_1.setCellValue)(this, cell, value);
        yield this.cucumberPage.keyboard.press("Enter");
    });
});
(0, cucumber_1.When)("нажимаем ПКМ на ячейку в колонке {string} строки №{int}.", { timeout: setup_1.config.largeTimeout }, function (columnTitle, rowNumber) {
    return __awaiter(this, void 0, void 0, function* () {
        const list = yield getList(this);
        const row = yield list.getRow(rowNumber);
        const cell = yield row.getCellAsync(columnTitle);
        yield cell.el.click({ button: "right" });
    });
});
(0, cucumber_1.When)("делаем двойное нажатие на ячейку в колонке {string} строки №{int}.", function (columnTitle, rowNumber) {
    return __awaiter(this, void 0, void 0, function* () {
        const list = yield getList(this);
        const row = yield list.getRow(rowNumber);
        const cell = yield row.getCellAsync(columnTitle);
        yield cell.el.dblclick();
    });
});
(0, cucumber_1.When)("нажимаем на ячейку в колонке {string} строки №{int}.", function (columnTitle, rowNumber) {
    return __awaiter(this, void 0, void 0, function* () {
        const list = yield getList(this);
        const row = yield list.getRow(rowNumber);
        const cell = yield row.getCellAsync(columnTitle);
        yield cell.el.click();
    });
});
(0, cucumber_1.When)("нажимаем на кнопку редактирования колонки {string}.", function (columnTitle) {
    return __awaiter(this, void 0, void 0, function* () {
        const list = yield getList(this);
        const headerRow = list.getHeaderRow();
        const cell = yield headerRow.getCell(columnTitle);
        yield cell.actions.edit.click();
    });
});
(0, cucumber_1.When)("очищаем значение ячейки в колонке {string} строки №{int}.", function (columnTitle, rowNumber) {
    return __awaiter(this, void 0, void 0, function* () {
        const list = yield getList(this);
        const row = yield list.getRow(rowNumber);
        const cell = yield row.getCellAsync(columnTitle);
        yield cell.clearValue();
        (0, test_1.expect)((0, isNullOrEmpty_1.isNullOrEmpty)(yield cell.value())).toBeTruthy();
        yield this.cucumberPage.keyboard.press("Enter");
    });
});
(0, cucumber_1.When)("очищаем значение ячейки в колонке {string} строки №{int} без подтверждения.", function (columnTitle, rowNumber) {
    return __awaiter(this, void 0, void 0, function* () {
        const list = yield getList(this);
        const row = yield list.getRow(rowNumber);
        const cell = yield row.getCellAsync(columnTitle);
        yield cell.clearValue();
        (0, test_1.expect)((0, isNullOrEmpty_1.isNullOrEmpty)(yield cell.value())).toBeTruthy();
    });
});
(0, cucumber_1.When)("проставляем флаг в ячейке колонки {string} строки №{int}.", function (columnTitle, rowNumber) {
    return __awaiter(this, void 0, void 0, function* () {
        const list = yield getList(this);
        const row = yield list.getRow(rowNumber);
        const cell = yield row.getCellAsync(columnTitle);
        yield cell.edit();
        yield (0, checkbox_1.setCheckboxValue)(this, (0, checkbox_1.getBooleanControl)(cell.el), checkbox_1.booleanData.truthy);
        yield this.cucumberPage.keyboard.press(hotkeys_1.HOTKEY_PRIMARY);
    });
});
(0, cucumber_1.When)("убираем флаг в ячейке колонки {string} строки №{int}.", function (columnTitle, rowNumber) {
    return __awaiter(this, void 0, void 0, function* () {
        const list = yield getList(this);
        const row = yield list.getRow(rowNumber);
        const cell = yield row.getCellAsync(columnTitle);
        yield cell.edit();
        yield (0, checkbox_1.setCheckboxValue)(this, (0, checkbox_1.getBooleanControl)(cell.el), checkbox_1.booleanData.false);
        yield this.cucumberPage.keyboard.press(hotkeys_1.HOTKEY_PRIMARY);
    });
});
(0, cucumber_1.When)("наводим курсор на изображение №{int} в ячейке строки №{int} колонки {string}.", function (imageNumber, rowNumber, columnTitle) {
    return __awaiter(this, void 0, void 0, function* () {
        const list = yield getList(this);
        const row = yield list.getRow(rowNumber);
        const cell = yield row.getCellAsync(columnTitle);
        yield cell.image(imageNumber).hover();
    });
});
(0, cucumber_1.When)("нажимаем на изображение №{int} в ячейке строки №{int} колонки {string}.", function (imageNumber, rowNumber, columnTitle) {
    return __awaiter(this, void 0, void 0, function* () {
        const list = yield getList(this);
        const row = yield list.getRow(rowNumber);
        const cell = yield row.getCellAsync(columnTitle);
        yield cell.image(imageNumber).click();
    });
});
(0, cucumber_1.Then)("появляется превью изображения.", function () {
    return __awaiter(this, void 0, void 0, function* () {
        (0, test_1.expect)(this.previewImage).toBeTruthy();
    });
});
(0, cucumber_1.Then)("в расширенном меню списка есть кнопка {string}.", function (buttonTitle) {
    return __awaiter(this, void 0, void 0, function* () {
        const list = yield getList(this);
        yield getItemFromList(list, "Ещё").click();
        const dropdown = yield (0, dropdown_steps_1.getReadyDropdown)(this.dropdown);
        const item = dropdown.itemByTitle(buttonTitle);
        yield item.waitFor();
        yield (0, test_1.expect)(item).toBeVisible();
    });
});
(0, cucumber_1.Then)("кнопка {string} в расширенном меню списка не активна.", function (buttonTitle) {
    return __awaiter(this, void 0, void 0, function* () {
        const list = yield getList(this);
        yield getItemFromList(list, "Ещё").click();
        const dropdown = yield (0, dropdown_steps_1.getReadyDropdown)(this.dropdown);
        const item = dropdown.itemByTitle(buttonTitle);
        yield item.waitFor();
        yield expectItemDisabled(item);
    });
});
(0, cucumber_1.Then)("открывается конструктор списка.", function () {
    return __awaiter(this, void 0, void 0, function* () {
        const list = yield getList(this);
        yield (0, test_1.expect)(list.el).toHaveClass(/designer/);
    });
});
(0, cucumber_1.Then)("закрывается конструктор списка.", function () {
    return __awaiter(this, void 0, void 0, function* () {
        const list = yield getList(this);
        yield (0, test_1.expect)(list.el).not.toHaveClass(/designer/);
    });
});
(0, cucumber_1.Then)("список будет пуст.", function () {
    return __awaiter(this, void 0, void 0, function* () {
        const list = yield getList(this);
        const isEmpty = yield list.isEmpty();
        (0, test_1.expect)(isEmpty).toBeTruthy();
    });
});
(0, cucumber_1.Then)("в списке {string} нет записей.", function (listTitle) {
    return __awaiter(this, void 0, void 0, function* () {
        const list = yield getList(this, listTitle);
        (0, test_1.expect)(yield list.isEmpty()).toBeTruthy();
    });
});
(0, cucumber_1.Then)("в списке нет записей.", function () {
    return __awaiter(this, void 0, void 0, function* () {
        const list = yield getList(this);
        (0, test_1.expect)(yield list.isEmpty()).toBeTruthy();
    });
});
(0, cucumber_1.Then)("список обновляется.", { timeout: setup_1.config.largeTimeout }, function () {
    return __awaiter(this, void 0, void 0, function* () {
        const list = yield this.getList();
        // заплатка, ожидаем что началась загрузка в течении одной секунды. Если загрузка идёт, то дожидаемся
        yield list.progressBar.loading.waitFor({ timeout: 1000 }).catch(() => void 0);
        if (yield list.progressBar.isLoading()) {
            yield list.isReady();
        }
    });
});
(0, cucumber_1.Then)("в списке запись №{int} новая.", function (rowNumber) {
    return __awaiter(this, void 0, void 0, function* () {
        const list = yield getList(this);
        const listRow = yield list.getRow(rowNumber);
        yield (0, test_1.expect)(listRow.el).toHaveClass(/modified/);
    });
});
(0, cucumber_1.Then)("в списке запись №{int} пустая.", function (rowNumber) {
    return __awaiter(this, void 0, void 0, function* () {
        const list = yield getList(this);
        const isRowEmpty = yield isListRowEmpty(list, rowNumber);
        (0, test_1.expect)(isRowEmpty).toBeTruthy();
    });
});
(0, cucumber_1.Then)("ячейка строки №{int} колонки {string} содержит значение {string}.", function (rowNumber, columnTitle, value) {
    return __awaiter(this, void 0, void 0, function* () {
        const list = yield getList(this);
        const cellValue = yield getCellValueAsync(list, columnTitle, rowNumber);
        (0, test_1.expect)(cellValue).toContain(value);
    });
});
/**
 * Для проверки многострочного значения
 * Значение может быть не равно, но содержать под строку
 *
    То ячейка строки №1 колонки "Поле связи" содержит значение:
    """
    Город
    ID_City
    """
 */
(0, cucumber_1.Then)("ячейка строки №{int} колонки {string} содержит значение:", function (rowNumber, columnTitle, value) {
    return __awaiter(this, void 0, void 0, function* () {
        const list = yield getList(this);
        const cellValue = yield getCellValueAsync(list, columnTitle, rowNumber);
        (0, test_1.expect)(cellValue).toContain(value);
    });
});
(0, cucumber_1.Then)("значение ячейки строки №{int} колонки {string} равно {string}.", function (rowNumber, columnTitle, value) {
    return __awaiter(this, void 0, void 0, function* () {
        const list = yield getList(this);
        const cellValue = yield getCellValueAsync(list, columnTitle, rowNumber);
        (0, test_1.expect)(cellValue).toSoftEqual(value);
    });
});
/**
 * Для проверки многострочного значения
 * Значение может должно быть равно
 *
    То ячейка строки №1 колонки "Поле связи" равно:
    """
    Город
    ID_City
    """
 */
(0, cucumber_1.Then)("значение ячейки строки №{int} колонки {string} равно:", function (rowNumber, columnTitle, value) {
    return __awaiter(this, void 0, void 0, function* () {
        const list = yield getList(this);
        const cellValue = yield getCellValueAsync(list, columnTitle, rowNumber);
        (0, test_1.expect)(cellValue).toSoftEqual(value);
    });
});
(0, cucumber_1.Then)("ячейка строки №{int} колонки {string} содержит изображение.", function (rowNumber, columnTitle) {
    return __awaiter(this, void 0, void 0, function* () {
        const list = yield getList(this);
        const row = yield list.getRow(rowNumber);
        const cell = yield row.getCellAsync(columnTitle);
        (0, test_1.expect)(yield cell.image().isVisible()).toBeTruthy();
    });
});
(0, cucumber_1.Then)("кнопка {string} в списке активна.", function (buttonTitle) {
    return __awaiter(this, void 0, void 0, function* () {
        const list = yield getList(this);
        yield (0, test_1.expect)(getItemFromList(list, buttonTitle)).not.toHaveClass(/disabled/);
    });
});
(0, cucumber_1.Then)("изображение №{int} в ячейке строки №{int} колонки {string} имеет высоту {int}px и ширину {int}px.", function (imageNumber, rowNumber, columnTitle, height, width) {
    return __awaiter(this, void 0, void 0, function* () {
        const list = yield getList(this);
        const row = yield list.getRow(rowNumber);
        const cell = yield row.getCellAsync(columnTitle);
        const image = cell.image(imageNumber);
        const imageElData = yield image.boundingBox();
        (0, test_1.expect)(imageElData.height).toBe(height);
        (0, test_1.expect)(imageElData.width).toBe(width);
    });
});
(0, cucumber_1.Then)("кнопка {string} в списке не активна.", function (buttonTitle) {
    return __awaiter(this, void 0, void 0, function* () {
        const list = yield getList(this);
        yield expectListItemDisabled(list, buttonTitle);
    });
});
(0, cucumber_1.Then)("в списке есть кнопка {string}.", function (buttonTitle) {
    return __awaiter(this, void 0, void 0, function* () {
        const list = yield getList(this);
        yield (0, test_1.expect)(getItemFromList(list, buttonTitle)).toBeVisible();
    });
});
(0, cucumber_1.Then)("в списке нет кнопки {string}.", function (buttonTitle) {
    return __awaiter(this, void 0, void 0, function* () {
        const list = yield getList(this);
        yield (0, test_1.expect)(getItemFromList(list, buttonTitle)).toBeHidden();
    });
});
/**
 * Проверка кнопок в списке, порядок не учитывается
 *
    И в списке будут кнопки:
      | Добавить новый столбец | Сохранить форму списка | Задачи | Отменить |
 */
(0, cucumber_1.Then)("в списке будут кнопки:", { timeout: setup_1.config.largeTimeout }, function (buttonNamesRow) {
    return __awaiter(this, void 0, void 0, function* () {
        const buttons = (0, tableManager_1.getRowData)(buttonNamesRow);
        const list = yield getList(this);
        yield listExpectButtons(list, buttons);
    });
});
(0, cucumber_1.Then)("в заголовках столбцов есть кнопка редактирования.", { timeout: setup_1.config.largeTimeout }, function () {
    return __awaiter(this, void 0, void 0, function* () {
        const list = yield getList(this);
        const headerRow = list.getHeaderRow();
        yield (0, asyncArray_1.asyncForEach)(yield headerRow.getAllCells(), (headerCell) => __awaiter(this, void 0, void 0, function* () {
            if (yield headerCell.isSelect())
                return;
            if (yield headerCell.isFormOpener())
                return;
            yield (0, test_1.expect)(headerCell.actions.edit).toBeVisible();
        }));
    });
});
(0, cucumber_1.Then)("в списке нет колонки {string}.", function (columnTitle) {
    return __awaiter(this, void 0, void 0, function* () {
        const list = yield getList(this);
        const headerRow = list.getHeaderRow();
        yield (0, test_1.expect)(headerRow.getCell(columnTitle).el).toBeHidden();
    });
});
(0, cucumber_1.Then)("ячейка недоступна для редактирования в колонке {string} строки №{int}.", function (columnTitle, rowNumber) {
    return __awaiter(this, void 0, void 0, function* () {
        const list = yield getList(this);
        const row = yield list.getRow(rowNumber);
        const cell = yield row.getCellAsync(columnTitle);
        (0, test_1.expect)(yield cell.isReadonly()).toBeTruthy();
    });
});
(0, cucumber_1.Then)("ячейка в колонке {string} строки №{int} не активна", function (columnTitle, rowNumber) {
    return __awaiter(this, void 0, void 0, function* () {
        const list = yield getList(this);
        const row = yield list.getRow(rowNumber);
        const cell = yield row.getCellAsync(columnTitle);
        const classList = yield cell.getClasses();
        (0, test_1.expect)(classList).toContain("deactivated");
    });
});
(0, cucumber_1.Then)("ячейка в колонке {string} строки №{int} активна", function (columnTitle, rowNumber) {
    return __awaiter(this, void 0, void 0, function* () {
        const list = yield getList(this);
        const row = yield list.getRow(rowNumber);
        const cell = yield row.getCellAsync(columnTitle);
        const classList = yield cell.getClasses();
        (0, test_1.expect)(classList).not.toContain("deactivated");
    });
});
(0, cucumber_1.Then)("в списке запись №{int} не активна.", function (rowNumber) {
    return __awaiter(this, void 0, void 0, function* () {
        const list = yield getList(this);
        const row = yield list.getRow(rowNumber);
        const isRowDisabled = yield row.isDisabled();
        (0, test_1.expect)(isRowDisabled).toBeTruthy();
    });
});
(0, cucumber_1.Then)("в списке запись №{int} активна.", function (rowNumber) {
    return __awaiter(this, void 0, void 0, function* () {
        const list = yield getList(this);
        const row = yield list.getRow(rowNumber);
        const isRowDisabled = yield row.isDisabled();
        (0, test_1.expect)(!isRowDisabled).toBeTruthy();
    });
});
(0, cucumber_1.Then)("ячейка доступна для редактирования в колонке {string} строки №{int}.", function (columnTitle, rowNumber) {
    return __awaiter(this, void 0, void 0, function* () {
        const list = yield getList(this);
        const row = yield list.getRow(rowNumber);
        const cell = yield row.getCellAsync(columnTitle);
        const isReadonly = yield cell.isReadonly();
        (0, test_1.expect)(!isReadonly).toBeTruthy();
    });
});
(0, cucumber_1.Then)("ячейки строки №{int} недоступны для редактирования.", function (rowNumber) {
    return __awaiter(this, void 0, void 0, function* () {
        const list = yield getList(this);
        const row = yield list.getRow(rowNumber);
        const cells = yield row.getFieldsCells();
        const allCellAreReadonly = yield (0, asyncArray_1.asyncEvery)(cells, (cell) => __awaiter(this, void 0, void 0, function* () {
            return yield cell.isReadonly();
        }));
        (0, test_1.expect)(allCellAreReadonly).toBeTruthy();
    });
});
(0, cucumber_1.Then)("ячейки строки №{int} доступны для редактирования.", function (rowNumber) {
    return __awaiter(this, void 0, void 0, function* () {
        const list = yield getList(this);
        const row = yield list.getRow(rowNumber);
        const cells = yield row.getFieldsCells();
        const allCellAreReadonly = yield (0, asyncArray_1.asyncEvery)(cells, (cell) => __awaiter(this, void 0, void 0, function* () {
            return yield cell.isReadonly();
        }));
        (0, test_1.expect)(allCellAreReadonly).toBeFalsy();
    });
});
(0, cucumber_1.Then)(/^в списке (-?\d+) запис[ей|ь|и]*\./, function (rowsCount) {
    return __awaiter(this, void 0, void 0, function* () {
        const list = yield getList(this);
        const listRowsCount = yield list.displayRowsCount();
        (0, test_1.expect)(listRowsCount).toBe(rowsCount);
    });
});
(0, cucumber_1.When)("проматываем список до конца записей.", { timeout: setup_1.config.largeTimeout }, function () {
    return __awaiter(this, void 0, void 0, function* () {
        const list = yield getList(this);
        yield list.el.focus();
        yield list.footer.scrollIntoViewIfNeeded();
    });
});
(0, cucumber_1.Then)("количество строк в списке {int}.", function (rowsCount) {
    return __awaiter(this, void 0, void 0, function* () {
        const list = yield getList(this);
        const visibleRowsCount = yield list.toolbar.count.value();
        (0, test_1.expect)(parseInt(visibleRowsCount)).toBe(rowsCount);
    });
});
(0, cucumber_1.Then)("количество строк в списке не отображено.", function () {
    return __awaiter(this, void 0, void 0, function* () {
        const list = yield getList(this);
        const valueIsUnknown = yield list.toolbar.count.valueIsUnknown();
        (0, test_1.expect)(valueIsUnknown).toBeTruthy();
    });
});
function isListRowEmpty(list, rowNumber) {
    return __awaiter(this, void 0, void 0, function* () {
        const listColumns = yield list.getHeaderRow().cellsValue();
        let isListRowEmpty = true;
        yield (0, asyncArray_1.asyncForEach)(listColumns, (column) => __awaiter(this, void 0, void 0, function* () {
            const cellValue = yield getCellValueAsync(list, column, rowNumber);
            isListRowEmpty = isListRowEmpty && (0, isNullOrEmpty_1.isNullOrEmpty)(cellValue);
        }));
        return isListRowEmpty;
    });
}
function getCellValueAsync(list, columnTitle, rowNumber) {
    return __awaiter(this, void 0, void 0, function* () {
        const listRow = yield list.getRow(rowNumber);
        return yield getCellValueByRowAsync(listRow, columnTitle);
    });
}
function getCellValueByRowAsync(listRow, columnTitle) {
    return __awaiter(this, void 0, void 0, function* () {
        const cell = yield listRow.getCellAsync(columnTitle);
        return yield cell.value();
    });
}
function getList(page, title) {
    return __awaiter(this, void 0, void 0, function* () {
        const list = yield page.getList({
            title
        });
        yield list.isReady();
        return list;
    });
}
exports.getList = getList;
function expectListItemDisabled(list, itemTitle) {
    return __awaiter(this, void 0, void 0, function* () {
        const item = getItemFromList(list, itemTitle);
        yield expectItemDisabled(item);
    });
}
function expectItemDisabled(item) {
    return __awaiter(this, void 0, void 0, function* () {
        yield (0, test_1.expect)(item).toHaveClass(/disabled/);
    });
}
function getItemFromList(list, item, byCode) {
    const toolbar = list.toolbar;
    if (byCode)
        return toolbar.item(item);
    if (item == "Вид")
        return toolbar.listView;
    if (item == "Именованные фильтры")
        return toolbar.namedFilter;
    if (item == "Обновить")
        return toolbar.refresh;
    if (item == "Ещё" || item == "Еще")
        return toolbar.more;
    if (item == "Количество строк")
        return toolbar.countItem;
    return toolbar.itemByTitle(item);
}
function listExpectButtons(list, buttons) {
    return __awaiter(this, void 0, void 0, function* () {
        yield (0, asyncArray_1.asyncForEach)(buttons, (buttonName) => __awaiter(this, void 0, void 0, function* () {
            yield (0, test_1.expect)(getItemFromList(list, buttonName)).toBeVisible();
        }));
    });
}
