"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.notFoundDetailsMessage = exports.showNotFoundRecords = exports.waitForRow = exports.getNotFoundRecords = void 0;
const setup_1 = require("../../../../../setup/setup");
const numberAndIndex_1 = require("../../../../utils/numberAndIndex");
function getNotFoundRecords(records, list, columnIndexes) {
    return __awaiter(this, void 0, void 0, function* () {
        const notFound = new Map();
        const checkRecordPromises = [];
        for (const [recordIndex, record] of records.entries()) {
            const row = yield list.getRow((0, numberAndIndex_1.getNumberFromIndex)(recordIndex));
            const rowNumber = recordIndex + 1;
            checkRecordPromises.push(waitForRow({
                row,
                record,
                columnIndexes,
                onRowNotFound: (details) => {
                    notFound.set(rowNumber, {
                        row: Object.values(record),
                        details
                    });
                }
            }));
        }
        yield Promise.all(checkRecordPromises);
        return notFound;
    });
}
exports.getNotFoundRecords = getNotFoundRecords;
function waitForRow(options) {
    return __awaiter(this, void 0, void 0, function* () {
        const { row, record, columnIndexes, onRowNotFound } = options;
        const rejected = yield row.el.waitFor({ timeout: setup_1.config.timeout }).catch(() => {
            onRowNotFound();
            return true;
        });
        if (rejected)
            return;
        const details = new Map();
        const fieldsCheckPromises = Object.entries(record).map(([column, expected], i) => {
            return (() => __awaiter(this, void 0, void 0, function* () {
                const cell = row.getCellByIndex(columnIndexes[column]);
                const rejected = yield cell.waitForValue(expected).catch(() => true);
                if (rejected) {
                    const received = yield cell.value();
                    details.set(column, {
                        expected,
                        received
                    });
                }
            }))();
        });
        yield Promise.all(fieldsCheckPromises);
        if (details.size) {
            onRowNotFound(details);
        }
    });
}
exports.waitForRow = waitForRow;
function showNotFoundRecords(data) {
    if (data.size > 0) {
        let result = `Не найдены следующие записи:`;
        for (const [n, { row, details }] of data.entries()) {
            const recordString = row.map((v) => `${v} |`).join(" ");
            result += `\nЗапись №${n}: | ${recordString}`;
            result += notFoundDetailsMessage(details);
        }
        throw result;
    }
}
exports.showNotFoundRecords = showNotFoundRecords;
function notFoundDetailsMessage(details) {
    let result = "";
    if ((details === null || details === void 0 ? void 0 : details.size) > 0) {
        for (const [fieldCode, { expected, received }] of details.entries()) {
            result += `\n\t ${notFoundFieldMessage(fieldCode, expected, received)}`;
        }
    }
    return result;
}
exports.notFoundDetailsMessage = notFoundDetailsMessage;
function notFoundFieldMessage(fieldCode, expected, received) {
    `В поле "${fieldCode}" ожидалось "${expected || ""}" получено "${received || ""}"`;
}
