"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.softListCompareStep = void 0;
const cucumber_1 = require("@cucumber/cucumber");
const tableManager_1 = require("../../../../utils/tableManager");
const notFoundRecords_1 = require("./notFoundRecords");
const withTimeoutHelpers_1 = require("./withTimeoutHelpers");
const customWaitFor_1 = require("../../../../utils/customWaitFor");
/**
 * Проверяет что список содержит записи
 * НЕ учитывает порядок записей
 * НЕ учитывает порядок колонок
 *
   То список содержит следующие записи в любом порядке:
   | Наименования_поля | Булево_поле | Поле_с_датой   |
   | Значение_2        | [x]         | {текущая дата} |
   | Значение_3        | [-]         |                |
   | Значение_1        | [ ]         | 29.02.2024     |
 */
(0, cucumber_1.Then)("список содержит следующие записи в любом порядке:", { timeout: -1 }, function (dataTable) {
    return __awaiter(this, void 0, void 0, function* () {
        yield softListCompareStep(this, dataTable);
    });
});
function softListCompareStep(page, dataTable) {
    return __awaiter(this, void 0, void 0, function* () {
        const list = yield (0, withTimeoutHelpers_1.getListWithTimeout)(page);
        const listData = (0, tableManager_1.getListData)(dataTable);
        const records = listData.getRecords();
        const columnIndexes = yield list.getColumnsIndexes(listData.getHeaderRow());
        const notFound = new Map();
        let promises = [];
        for (const [recordIndex, record] of records.entries()) {
            promises.push((0, customWaitFor_1.customWaitFor)(() => __awaiter(this, void 0, void 0, function* () {
                return !!(yield list.findSimilar(record, columnIndexes));
            })).catch(() => {
                notFound.set(recordIndex + 1, {
                    row: Object.values(record)
                });
            }));
        }
        yield Promise.all(promises);
        (0, notFoundRecords_1.showNotFoundRecords)(notFound);
    });
}
exports.softListCompareStep = softListCompareStep;
