"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.AppHelper = void 0;
const FormOpener_1 = require("./FormOpener");
const NodeOpener_1 = require("./NodeOpener");
const NextNodeSearcher_1 = require("./NextNodeSearcher");
class AppHelper {
    constructor(page, logger) {
        this.page = page;
        this.logger = logger;
        this.formOpener = new FormOpener_1.FormOpener(this.page);
        this.nextNodeSearcher = new NextNodeSearcher_1.NextNodeSearcher(this.page);
        this.nodeOpener = new NodeOpener_1.NodeOpener(this.page);
    }
    openNode(path) {
        return __awaiter(this, void 0, void 0, function* () {
            this.logger.show(this.logger.openNode(path), this.logger.level.openNode);
            yield this.nodeOpener.open(path);
            const content = this.page.getContent();
            yield content.waitForLoading();
        });
    }
    getNextNode(currentPath) {
        return this.nextNodeSearcher.getNext(currentPath);
    }
    tryOpenForm(path) {
        return __awaiter(this, void 0, void 0, function* () {
            const list = yield this.formOpener.getList();
            if (!list)
                return;
            if (yield this.formOpener.canOpenRecord(list)) {
                this.logger.show(this.logger.openForm(path), this.logger.level.openForm);
                return yield this.formOpener.openRecord(list);
            }
            if (yield this.formOpener.canOpenNew(list)) {
                this.logger.show(this.logger.openForm(path), this.logger.level.openForm);
                return yield this.formOpener.openNew(list);
            }
        });
    }
}
exports.AppHelper = AppHelper;
