"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.NodeOpener = void 0;
const textPrepare_1 = require("../../../utils/textPrepare");
class NodeOpener {
    constructor(page) {
        this.page = page;
    }
    open(path) {
        return __awaiter(this, void 0, void 0, function* () {
            if (path.leftNav) {
                yield this.openLeftNav(path.leftNav);
                return;
            }
            if (path.topNav) {
                yield this.openTopNav(path.topNav);
                return;
            }
            if (path.app) {
                yield this.openApp(path.app);
                return;
            }
        });
    }
    openApp(title) {
        return __awaiter(this, void 0, void 0, function* () {
            yield this.page.header.apps.click();
            yield this.page.waitNavigationAfterInvoke(() => __awaiter(this, void 0, void 0, function* () {
                yield this.page.header.apps.waitFor();
                yield this.page.appsTiles.item(title).click();
            }));
            yield this.page.waitForLoading();
        });
    }
    openTopNav(title) {
        return __awaiter(this, void 0, void 0, function* () {
            yield this.page.header.navItem(title).click();
            yield this.page.waitForLoading();
        });
    }
    openLeftNav(path) {
        return __awaiter(this, void 0, void 0, function* () {
            let list = this.page.leftNav.list;
            let item;
            for (const title of path) {
                item = list.item((0, textPrepare_1.prepareText)(title));
                if ((yield item.isParent()) && !(yield item.isOpen())) {
                    yield item.toggler.click();
                }
                list = item.list;
            }
            yield item.content.click();
            yield this.page.waitForLoading();
        });
    }
}
exports.NodeOpener = NodeOpener;
