import { Browser, BrowserContext, Page as CucumberPage, Locator } from "@playwright/test";
import { List } from "./list/list";
import { World as CucumberWorld } from "@cucumber/cucumber";
import { LeftNav } from "./leftNav/leftNav";
import { Form } from "./form/form";
import { TopNav } from "./topNav/topNav";
import { ContainerType } from "../utils/contentManager";
import { ContentManager } from "../utils/contentManager";
import { Side } from "./side/side";
import { Content } from "./content/content";
import { AppTiles } from "./topNav/apps/apps";
import { Modal } from "./modal/modal";
import { FeatureContext } from "../utils/featureContext";
import { TagMenu } from "./tag/tag";
declare type NavigationInokeFunction = () => Promise<void>;
declare global {
    var m: any;
}
export interface GetFormOptions {
    title?: string;
    inSideOrModal?: boolean;
}
export interface GetListOptions {
    title?: string;
    parentEl?: Locator;
    container?: ContainerType;
}
export interface ContainerOptions {
    container: ContainerType;
    title?: string;
}
declare type scenarioStateKeys = "gallery.imageData";
export declare class Page extends CucumberWorld {
    cucumberPage: CucumberPage;
    context: BrowserContext;
    browser: Browser;
    private fileManager;
    private pageContext;
    private langManager;
    scenarioState: Map<scenarioStateKeys, any>;
    contentManager: ContentManager;
    constructor(options: any);
    waitForDownload(): Promise<import("playwright-core").Download>;
    waitForLoading(): Promise<void>;
    private waitPendingRequests;
    private waitForLoadingIndicator;
    private getActiveContainer;
    getContent(): Content;
    getSide({ title, waitFor }?: {
        title?: string;
        waitFor?: boolean;
    }): Promise<Side>;
    getModal({ title, waitFor }?: {
        title?: string;
        waitFor?: boolean;
    }): Promise<Modal>;
    get header(): TopNav;
    get appsTiles(): AppTiles;
    get leftNav(): LeftNav;
    getNotification(textContent: string): import("./notification/notification").Notification;
    getList({ title: listTitle, parentEl, container }?: GetListOptions): Promise<List>;
    getForm({ title, inSideOrModal }?: GetFormOptions): Promise<Form>;
    waitFor(type: "open" | "close", options: ContainerOptions): Promise<void>;
    get body(): Locator;
    get wrapper(): Locator;
    get zoneBottom(): Locator;
    getTooltip(): Promise<Locator>;
    get gallery(): import("./form/Field/fieldControls/gallery/gallery").Gallery;
    get dropdown(): import("./dropdown/dropdown").Dropdown;
    previewImage(): Promise<boolean>;
    waitNavigationAfterInvoke(navigationInvokeFunction: NavigationInokeFunction): Promise<[import("playwright-core").Response, void]>;
    selectFile(fileName: string, fileChooserOpen: () => Promise<void>): Promise<void>;
    initPage(page: CucumberPage, context: FeatureContext): Promise<void>;
    reload(): Promise<void>;
    changeLanguage(language: string): Promise<void>;
    get commandMenu(): {
        el: Locator;
        readonly search: Locator;
        command(name: string): Locator;
    };
    get splashPage(): Locator;
    private waitForLoad;
    private getListByTitle;
    getTagMenu(options?: {
        waitFor: boolean;
    }): Promise<TagMenu>;
    getContextMenu(options?: {
        ready: boolean;
    }): Promise<import("./contextMenu/contextMenu").ContextMenu>;
}
export {};
