"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Page = void 0;
const list_1 = require("./list/list");
const cucumber_1 = require("@cucumber/cucumber");
const leftNav_1 = require("./leftNav/leftNav");
const form_1 = require("./form/form");
const topNav_1 = require("./topNav/topNav");
const dropdown_1 = require("./dropdown/dropdown");
const fileManager_1 = require("../utils/fileManager");
const contentManager_1 = require("../utils/contentManager");
const contentManager_2 = require("../utils/contentManager");
const formToolbar_1 = require("./form/formToolbar/formToolbar");
const apps_1 = require("./topNav/apps/apps");
const formList_1 = require("./form/FormList/formList");
const setup_1 = require("../../setup/setup");
const notification_1 = require("./notification/notification");
const commandMenu_1 = require("./commandMenu/commandMenu");
const waitForAppLoad_1 = require("../utils/waitForAppLoad");
const langManager_1 = require("../utils/langManager");
const tag_1 = require("./tag/tag");
const contextMenu_1 = require("./contextMenu/contextMenu");
const gallery_1 = require("./form/Field/fieldControls/gallery/gallery");
const getSelector_1 = require("../utils/getSelector");
class Page extends cucumber_1.World {
    constructor(options) {
        super(options);
    }
    waitForDownload() {
        return this.fileManager.waitDownload();
    }
    waitForLoading() {
        return __awaiter(this, void 0, void 0, function* () {
            const timeout = setTimeout(() => {
                clearTimeout(timeout);
                throw "Слишком долгая загрузка.";
            }, setup_1.config.largeTimeout);
            yield this.cucumberPage.waitForLoadState();
            yield (0, waitForAppLoad_1.waitForAppLoad)(this.cucumberPage);
            yield this.waitForLoadingIndicator();
            yield this.waitPendingRequests();
            clearTimeout(timeout);
        });
    }
    waitPendingRequests() {
        return __awaiter(this, void 0, void 0, function* () {
            const navigationStarted = yield this.cucumberPage.evaluate(() => {
                let onNavigate;
                let interval;
                return new Promise((resolve) => {
                    onNavigate = () => {
                        clearInterval(interval);
                        resolve(true);
                    };
                    globalThis.navigation.addEventListener("navigate", onNavigate);
                    interval = setInterval(() => {
                        const pendingRequests = (m === null || m === void 0 ? void 0 : m.pendingRequests) || 0;
                        if (pendingRequests == 0)
                            resolve(false);
                    }, 50);
                }).finally(() => {
                    globalThis.navigation.removeEventListener("navigate", onNavigate);
                    clearInterval(interval);
                });
            });
            if (navigationStarted) {
                yield this.cucumberPage.waitForNavigation({
                    waitUntil: "networkidle"
                });
                yield (0, waitForAppLoad_1.waitForAppLoad)(this.cucumberPage);
            }
        });
    }
    waitForLoadingIndicator() {
        return __awaiter(this, void 0, void 0, function* () {
            yield this.body.locator("#loading-indicator.shown").waitFor({ state: "hidden" });
        });
    }
    getActiveContainer(type, options) {
        return __awaiter(this, void 0, void 0, function* () {
            if (options === null || options === void 0 ? void 0 : options.waitFor) {
                const container = this.contentManager.getContainer(type);
                if (type == "modal")
                    container.useActive();
                yield container.el.waitFor();
                if (options.title) {
                    yield container.header.title.locator(`text="${options.title}"`);
                }
            }
            let active = yield this.contentManager.getActive();
            if (active.type != type)
                throw new Error(`Expected type: ${type}, but received ${active.type}`);
            if (options === null || options === void 0 ? void 0 : options.title) {
                const activeTitle = yield active.container.header.title.textContent();
                if (activeTitle != options.title)
                    throw new Error(`Expected type ${type} with title ${options.title}, but received with title ${activeTitle}`);
            }
            return active.container;
        });
    }
    getContent() {
        return this.contentManager.getContainer("content");
    }
    getSide({ title, waitFor } = {}) {
        return this.getActiveContainer("side", { title, waitFor });
    }
    getModal({ title, waitFor } = {}) {
        return this.getActiveContainer("modal", {
            title,
            waitFor
        });
    }
    get header() {
        return new topNav_1.TopNav(this.wrapper);
    }
    get appsTiles() {
        return new apps_1.AppTiles(this.zoneBottom);
    }
    get leftNav() {
        return new leftNav_1.LeftNav(this.body);
    }
    getNotification(textContent) {
        return (0, notification_1.getNotification)(this.zoneBottom, textContent);
    }
    getList({ title: listTitle, parentEl, container } = {}) {
        return __awaiter(this, void 0, void 0, function* () {
            let list;
            if (parentEl)
                this.pageContext.setValue("listParentEl", parentEl);
            const parentElContext = this.pageContext.getValue("listParentEl");
            if (parentElContext) {
                list = new list_1.List(parentElContext);
                if (yield list.el.isVisible())
                    return list;
            }
            let active = yield this.contentManager.getActive();
            list = new list_1.List(active.container.content);
            if (listTitle) {
                list = yield this.getListByTitle(listTitle, active);
                this.pageContext.setValue("formListTitle", listTitle);
            }
            else {
                const contextTitle = this.pageContext.getValue("formListTitle");
                if (contextTitle) {
                    const listFromContext = yield this.getListByTitle(contextTitle, active);
                    if (listFromContext) {
                        list = listFromContext;
                        this.pageContext.setValue("formListTitle", contextTitle);
                    }
                    else {
                        this.pageContext.setValue("formListTitle", void 0);
                    }
                }
            }
            if (!list)
                throw new Error("Список не найден.");
            if ((yield list.el.count()) > 1) {
                throw new Error("Найдено несколько списков, непонятно с каким взаимодействовать.");
            }
            if (container && container != active.type) {
                throw new Error(`Список в ${(0, contentManager_1.containerTypeToText)(container)} не найден.`);
            }
            return list;
        });
    }
    getForm({ title, inSideOrModal } = {}) {
        return __awaiter(this, void 0, void 0, function* () {
            const inModal = this.contentManager.getContainerEl("modal", { title });
            const inSideBar = this.contentManager.getContainerEl("side", { title });
            const inContent = this.contentManager.getContainerEl("content", { title });
            let expectedContainer = inModal.or(inSideBar);
            if (!inSideOrModal)
                expectedContainer = expectedContainer.or(inContent);
            yield expectedContainer.waitFor({
                strict: !!title
            });
            let active = yield this.contentManager.getActive();
            if (title) {
                const activeTitle = yield active.container.header.title.textContent();
                if (activeTitle != title)
                    throw new Error(`Ожидалась форма "${title}", однако открыта "${activeTitle}".`);
            }
            const form = new form_1.Form(active.container.content, {
                designerWrapper: active.container.el
            });
            if (active.type == "modal") {
                form.toolbar = (0, formToolbar_1.getFormToolbar)(active.container.toolbarEl);
                return form;
            }
            return form;
        });
    }
    waitFor(type, options) {
        return __awaiter(this, void 0, void 0, function* () {
            if (type == "close") {
                return this.contentManager.waitForHidden(options.container, {
                    title: options.title
                });
            }
            return this.contentManager
                .getContainerEl(options.container, {
                title: options.title
            })
                .waitFor();
        });
    }
    get body() {
        return this.cucumberPage.locator("body");
    }
    get wrapper() {
        return this.body.locator("#wrapper");
    }
    get zoneBottom() {
        return this.body.locator(".zone-bottom");
    }
    getTooltip() {
        return __awaiter(this, void 0, void 0, function* () {
            const tooltip = this.body.locator((0, getSelector_1.getSelector)({ testid: "tooltip" }));
            return tooltip;
        });
    }
    get gallery() {
        return (0, gallery_1.getGallery)(this.zoneBottom);
    }
    get dropdown() {
        return (0, dropdown_1.getDropdown)(this.zoneBottom);
    }
    previewImage() {
        return __awaiter(this, void 0, void 0, function* () {
            return this.body.locator((0, getSelector_1.getSelector)({ testid: "gallery-full-img-preview" })).isVisible();
        });
    }
    waitNavigationAfterInvoke(navigationInvokeFunction) {
        return __awaiter(this, void 0, void 0, function* () {
            return Promise.all([this.cucumberPage.waitForNavigation(), navigationInvokeFunction()]);
        });
    }
    selectFile(fileName, fileChooserOpen) {
        return __awaiter(this, void 0, void 0, function* () {
            const [fileChooser] = yield Promise.all([this.cucumberPage.waitForEvent("filechooser"), fileChooserOpen()]);
            const filePath = (0, fileManager_1.getFilePath)(fileName);
            yield fileChooser.setFiles(filePath);
        });
    }
    initPage(page, context) {
        return __awaiter(this, void 0, void 0, function* () {
            this.cucumberPage = page;
            yield this.waitForLoad(this.cucumberPage);
            this.contentManager = (0, contentManager_2.getContentManager)(this);
            this.fileManager = fileManager_1.FileManager.init(page);
            this.pageContext = getPageContext(context);
            this.langManager = langManager_1.default;
            this.langManager.usePage(this);
            this.scenarioState = new Map();
        });
    }
    reload() {
        return __awaiter(this, void 0, void 0, function* () {
            yield this.waitNavigationAfterInvoke(() => __awaiter(this, void 0, void 0, function* () {
                yield this.cucumberPage.reload({
                    timeout: setup_1.config.largeTimeout,
                    waitUntil: "networkidle"
                });
            }));
            yield this.waitForLoad(this.cucumberPage);
        });
    }
    changeLanguage(language) {
        return __awaiter(this, void 0, void 0, function* () {
            yield this.langManager.changeLanguage(language);
            yield this.reload();
        });
    }
    get commandMenu() {
        return (0, commandMenu_1.commandMenu)(this.zoneBottom);
    }
    get splashPage() {
        return this.body.locator(".splash-page");
    }
    waitForLoad(page) {
        return __awaiter(this, void 0, void 0, function* () {
            yield page.waitForLoadState("load", { timeout: setup_1.config.largeTimeout });
            yield (0, waitForAppLoad_1.waitForAppLoad)(this.cucumberPage, { timeout: setup_1.config.largeTimeout });
        });
    }
    getListByTitle(title, active) {
        return (0, formList_1.getFormList)(active.container.content, title);
    }
    getTagMenu(options) {
        return __awaiter(this, void 0, void 0, function* () {
            const tagMenu = new tag_1.TagMenu(this.dropdown.el);
            if ((options === null || options === void 0 ? void 0 : options.waitFor) !== false)
                yield tagMenu.el.waitFor();
            return tagMenu;
        });
    }
    getContextMenu(options) {
        return __awaiter(this, void 0, void 0, function* () {
            if (!options)
                options = { ready: true };
            const contextMenu = (0, contextMenu_1.getContextMenu)(this.zoneBottom);
            if (options.ready)
                yield contextMenu.el.waitFor();
            return contextMenu;
        });
    }
}
exports.Page = Page;
function getPageContext({ getValue, setValue }) {
    return {
        getValue,
        setValue
    };
}
