"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const test_1 = require("@playwright/test");
const cucumber_1 = require("@cucumber/cucumber");
const setup_1 = require("../../setup/setup");
const dateMatcher_1 = require("../utils/date/dateMatcher/dateMatcher");
const userLogin_1 = require("../utils/userLogin");
const snapshots_1 = require("../utils/snapshots/snapshots");
const navRunner_1 = require("./navRunner/navRunner");
(0, cucumber_1.Given)("тестирование выполняется под пользователем {string}.", { timeout: setup_1.config.largeTimeout }, function (userName) {
    return __awaiter(this, void 0, void 0, function* () {
        yield (0, userLogin_1.loginByUser)(this.cucumberPage, userName);
        (0, test_1.expect)(yield this.header.user.textContent()).toBe(userName);
    });
});
(0, cucumber_1.Given)("пользователь не авторизован.", function () {
    return __awaiter(this, void 0, void 0, function* () {
        yield (0, test_1.expect)(this.splashPage).toBeVisible();
    });
});
(0, cucumber_1.Given)("данные восстановлены из снапшота.", { timeout: setup_1.config.largeTimeout }, function () {
    return __awaiter(this, void 0, void 0, function* () {
        yield (0, snapshots_1.restoreSnapshot)();
        yield this.waitForLoading();
        yield this.reload();
    });
});
(0, cucumber_1.When)("вводим значение {string}.", { timeout: setup_1.config.largeTimeout }, function (value) {
    return __awaiter(this, void 0, void 0, function* () {
        yield this.cucumberPage.waitForTimeout(1000);
        yield this.cucumberPage.keyboard.type((0, dateMatcher_1.parseIfAlias)(value), { delay: 50 });
    });
});
function whenPushButton(hotkey) {
    return __awaiter(this, void 0, void 0, function* () {
        yield this.cucumberPage.keyboard.press(hotkey);
    });
}
(0, cucumber_1.When)("нажимаем клавиши {string}.", { timeout: setup_1.config.largeTimeout }, whenPushButton);
(0, cucumber_1.When)("нажимаем клавишу {string}.", { timeout: setup_1.config.largeTimeout }, whenPushButton);
(0, cucumber_1.When)("пользователь обновляет страницу.", function () {
    return __awaiter(this, void 0, void 0, function* () {
        yield this.reload();
        yield this.cucumberPage.waitForLoadState();
    });
});
(0, cucumber_1.When)("дожидаемся выполнения службы {string}.", { timeout: -1 }, function (jobCode) {
    return __awaiter(this, void 0, void 0, function* () {
        const result = yield this.cucumberPage.evaluate((jobCode) => {
            function getJobStatus(jobCode) {
                // @ts-ignore
                return MDT.Api.fetchRecord("job.History", {
                    select: ["ID_Status/Code"],
                    // @ts-ignore
                    filter: MDT.Filter.eq("ID_Task/Code", jobCode),
                    sorting: [{ path: "ID", asc: false }]
                }).then((record) => {
                    var _a;
                    if (!record)
                        return;
                    return (_a = record === null || record === void 0 ? void 0 : record.ID_Status$) === null || _a === void 0 ? void 0 : _a.Code;
                });
            }
            return new Promise((resolve) => {
                const run = () => setTimeout(() => {
                    getJobStatus(jobCode).then((status) => {
                        if (status == "Success") {
                            resolve(true);
                            return;
                        }
                        if (["Failed", "Aborted"].includes(status)) {
                            resolve(false);
                            return;
                        }
                        run();
                    });
                }, 2000);
                run();
            });
        }, jobCode);
        (0, test_1.expect)(result).toBeTruthy();
    });
});
(0, cucumber_1.When)(/^ожидаем (\d+) секунд[уы]*\./, { timeout: -1 }, function (seconds) {
    const milliseconds = seconds * 1000;
    return new Promise((res) => setTimeout(res, milliseconds));
});
(0, cucumber_1.Then)("выгружается файл {string}.", { timeout: setup_1.config.largeTimeout * 2 }, function (fileName) {
    return __awaiter(this, void 0, void 0, function* () {
        const download = yield this.waitForDownload();
        const downloadedFileName = yield download.suggestedFilename();
        (0, test_1.expect)(downloadedFileName).toBe(fileName);
    });
});
(0, cucumber_1.Then)("появляется уведомление {string}.", function (textContent) {
    return __awaiter(this, void 0, void 0, function* () {
        (0, test_1.expect)(yield this.getNotification(textContent).waitForExist()).toBeTruthy();
    });
});
(0, cucumber_1.Then)("страница обновляется.", function () {
    return __awaiter(this, void 0, void 0, function* () {
        yield this.cucumberPage.waitForLoadState();
        yield this.waitForLoading();
    });
});
(0, cucumber_1.Then)("выполнен вход под пользователем {string}.", function (userName) {
    return __awaiter(this, void 0, void 0, function* () {
        (0, test_1.expect)(yield this.header.user.textContent()).toBe(userName);
    });
});
(0, cucumber_1.Then)("без ошибок проходит по всей навигации и открывает формы записей", { timeout: -1 }, navRunner_1.navRunnerStep);
