"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getProgressBar = exports.ProgressBar = void 0;
const setup_1 = require("../../../setup/setup");
const asyncArray_1 = require("../../utils/asyncArray");
const progressBarClass = `.mdt-progress-bar`;
const progressBarClasses = {
    hide: `${progressBarClass}-hide`,
    progress: `${progressBarClass}-progress`,
    complete: `${progressBarClass}-complete`,
    indeterminate: `${progressBarClass}-indeterminate`,
    loading: `${progressBarClass}-loading`
};
class ProgressBar {
    constructor(parentEl) {
        this.parentEl = parentEl;
        this.el = this.parentEl.locator(progressBarClass).first();
    }
    get loading() {
        return this.el.locator(progressBarClasses.loading);
    }
    isLoading() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.loading.isVisible();
        });
    }
    get complete() {
        return this.el.locator(progressBarClasses.complete);
    }
    isComplete() {
        return __awaiter(this, void 0, void 0, function* () {
            const isLoading = yield this.isLoading();
            return !isLoading;
        });
    }
    get indeterminate() {
        return this.el.locator(progressBarClasses.indeterminate);
    }
    isIndeterminate() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.indeterminate.isVisible();
        });
    }
    waitForLoading() {
        return __awaiter(this, void 0, void 0, function* () {
            yield this.el.locator(progressBarClasses.loading).waitFor();
        });
    }
    waitForComplete() {
        return __awaiter(this, void 0, void 0, function* () {
            let allProgressBars = yield this.allProgressBars();
            allProgressBars = yield (0, asyncArray_1.asyncFilter)(allProgressBars, (pb) => pb.isVisible());
            if (!allProgressBars.length)
                return;
            yield Promise.all(allProgressBars.map((p) => p.waitFor({ state: "hidden", timeout: setup_1.config.largeTimeout })));
            // Проверяем не появились ли новые прогресс бары и ожидаем их
            return this.waitForComplete();
        });
    }
    allProgressBars() {
        return this.parentEl.locator(progressBarClass).all();
    }
}
exports.ProgressBar = ProgressBar;
function getProgressBar(parentEl) {
    return new ProgressBar(parentEl);
}
exports.getProgressBar = getProgressBar;
