"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.TagMenu = void 0;
const getSelector_1 = require("../../utils/getSelector");
const field_1 = require("../form/Field/field");
const numberAndIndex_1 = require("../../utils/numberAndIndex");
const selectors = (0, getSelector_1.getSelectors)({
    tagBlock: "tag-block",
    action: "action",
    form: "tag-form",
    formTitle: "tag-form-title",
    tag: "tag",
    tagTitle: "tag-title",
    tagUser: "tag-user",
    tagDate: "tag-date",
    tagComment: "tag-comment",
    tagExtMenu: "tag-ext-menu"
});
class TagMenu {
    constructor(parentEl) {
        this.parentEl = parentEl;
        this.el = this.parentEl.locator(selectors.tagBlock);
        this.form = this.parentEl.locator(selectors.form);
        this.tag = this.parentEl.locator(selectors.tag);
    }
    getField(fieldName) {
        return __awaiter(this, void 0, void 0, function* () {
            const field = (0, field_1.getField)(this.form, fieldName);
            if (field.isExist())
                return field;
        });
    }
    getAction(actionTitle) {
        return this.el.locator(`${selectors.action}:has-text("${actionTitle}")`);
    }
    getTag(tagNumber) {
        return new Tag(this.tag.nth((0, numberAndIndex_1.getIndexFromNumber)(tagNumber)));
    }
    tagsCount() {
        return this.tag.count();
    }
    getForm() {
        return {
            el: this.form,
            title: this.form.locator(selectors.formTitle)
        };
    }
}
exports.TagMenu = TagMenu;
const tagSelectors = (0, getSelector_1.getSelectors)({
    title: "tag-title",
    user: "tag-user",
    date: "tag-date",
    comment: "tag-comment",
    extMenu: "tag-ext-menu"
});
class Tag {
    constructor(tagEl) {
        this.tagEl = tagEl;
        this.el = this.tagEl;
        this.title = this.tagEl.locator(tagSelectors.title);
        this.user = this.tagEl.locator(tagSelectors.user);
        this.date = this.tagEl.locator(tagSelectors.date);
        this.comment = this.tagEl.locator(tagSelectors.comment);
        this.extMenu = this.tagEl.locator(tagSelectors.extMenu);
    }
}
