"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const cucumber_1 = require("@cucumber/cucumber");
const test_1 = require("@playwright/test");
const form_steps_1 = require("../form/form.steps");
const dropdown_steps_1 = require("../dropdown/dropdown.steps");
const list_steps_1 = require("../list/list.steps");
(0, cucumber_1.When)("на форме в меню тегов заполняем поле {string} значением {string}.", function (fieldName, value) {
    return __awaiter(this, void 0, void 0, function* () {
        const form = yield (0, form_steps_1.getForm)(this);
        const tagMenu = yield form.getTagMenu();
        const field = yield tagMenu.getField(fieldName);
        yield (0, form_steps_1.setValueByField)(this, field, value);
    });
});
(0, cucumber_1.When)("в меню тегов заполняем поле {string} значением {string}.", function (fieldName, value) {
    return __awaiter(this, void 0, void 0, function* () {
        const tagMenu = yield this.getTagMenu();
        const field = yield tagMenu.getField(fieldName);
        yield (0, form_steps_1.setValueByField)(this, field, value);
    });
});
(0, cucumber_1.When)("нажимаем кнопку {string} в меню тегов.", function (button) {
    return __awaiter(this, void 0, void 0, function* () {
        const tagMenu = yield this.getTagMenu();
        const action = tagMenu.getAction(button);
        yield action.click();
    });
});
(0, cucumber_1.When)("нажимаем кнопку {string} в расширенном меню тега №{int}.", function (buttonTitle, tagNumber) {
    return __awaiter(this, void 0, void 0, function* () {
        const tagMenu = yield this.getTagMenu();
        const tag = tagMenu.getTag(tagNumber);
        const extMenu = tag.extMenu;
        yield extMenu.click();
        const dropdown = yield (0, dropdown_steps_1.getReadyDropdown)(this.dropdown);
        const button = dropdown.itemByTitle(buttonTitle);
        yield button.click();
    });
});
(0, cucumber_1.When)("нажимаем кнопку тегов в поле {string}.", function (fieldName) {
    return __awaiter(this, void 0, void 0, function* () {
        const form = yield (0, form_steps_1.getForm)(this);
        const field = form.getField(fieldName);
        const tag = field.tagMark;
        yield field.el.hover();
        yield tag.click();
    });
});
(0, cucumber_1.Then)("открывается меню тегов.", function () {
    return __awaiter(this, void 0, void 0, function* () {
        yield this.getTagMenu();
    });
});
(0, cucumber_1.Then)("меню тегов закрывается.", function () {
    return __awaiter(this, void 0, void 0, function* () {
        const tagMenu = yield this.getTagMenu({ waitFor: false });
        yield (0, test_1.expect)(tagMenu.el).toBeHidden();
    });
});
(0, cucumber_1.Then)("в меню тегов нет тегов.", function () {
    return __awaiter(this, void 0, void 0, function* () {
        const tagMenu = yield this.getTagMenu();
        const count = yield tagMenu.tagsCount();
        (0, test_1.expect)(count == 0).toBeTruthy();
    });
});
(0, cucumber_1.Then)("в меню тегов есть форма {string}.", function (formTitle) {
    return __awaiter(this, void 0, void 0, function* () {
        const tagMenu = yield this.getTagMenu();
        const addForm = tagMenu.getForm();
        yield (0, test_1.expect)(addForm.el).toBeVisible();
        (0, test_1.expect)(yield addForm.title.textContent()).toBe(formTitle);
    });
});
(0, cucumber_1.Then)("в меню тегов есть форма.", function () {
    return __awaiter(this, void 0, void 0, function* () {
        const tagMenu = yield this.getTagMenu();
        const addForm = tagMenu.getForm();
        yield (0, test_1.expect)(addForm.el).toBeVisible();
    });
});
(0, cucumber_1.Then)("в меню тегов нет формы {string}.", function (formTitle) {
    return __awaiter(this, void 0, void 0, function* () {
        const tagMenu = yield this.getTagMenu();
        const form = tagMenu.getForm();
        (0, test_1.expect)(yield form.title.textContent()).toBe(formTitle);
    });
});
(0, cucumber_1.Then)("в меню тегов нет формы.", function () {
    return __awaiter(this, void 0, void 0, function* () {
        const tagMenu = yield this.getTagMenu();
        const form = tagMenu.getForm();
        yield (0, test_1.expect)(form.el).toBeHidden();
    });
});
(0, cucumber_1.Then)("в меню тегов поле {string} заполнено значением {string}.", function (fieldName, value) {
    return __awaiter(this, void 0, void 0, function* () {
        const tagMenu = yield this.getTagMenu();
        const field = yield tagMenu.getField(fieldName);
        (0, test_1.expect)(yield field.displayValueAsync()).toSoftEqual(value);
    });
});
(0, cucumber_1.Then)("в меню тегов появляется тег.", function () {
    return __awaiter(this, void 0, void 0, function* () {
        const tagMenu = yield this.getTagMenu();
        yield tagMenu.getTag(1).el.waitFor();
    });
});
(0, cucumber_1.Then)(/^в меню тегов (\d+) тег[ов|а]*\./, function (count) {
    return __awaiter(this, void 0, void 0, function* () {
        const tagMenu = yield this.getTagMenu();
        yield tagMenu.tag.waitFor();
        const tagsCount = yield tagMenu.tagsCount();
        (0, test_1.expect)(tagsCount).toBe(count);
    });
});
(0, cucumber_1.Then)("тег №{int} с типом {string} создан {string} пользователем {string}.", function (number, type, date, user) {
    return __awaiter(this, void 0, void 0, function* () {
        const tagMenu = yield this.getTagMenu();
        const tag = tagMenu.getTag(number);
        (0, test_1.expect)(yield tag.title.textContent()).toBe(type);
        (0, test_1.expect)(yield tag.date.textContent()).toSoftEqual(date);
        (0, test_1.expect)(yield tag.user.textContent()).toBe(user);
    });
});
(0, cucumber_1.Then)("тег №{int} содержит комментарий {string}.", function (tagNumber, comment) {
    return __awaiter(this, void 0, void 0, function* () {
        const tagMenu = yield this.getTagMenu();
        const tag = tagMenu.getTag(tagNumber);
        (0, test_1.expect)(yield tag.comment.textContent()).toBe(comment);
    });
});
(0, cucumber_1.Then)("ячейка колонки {string} строки №{int} содержит тег.", function (columnTitle, rowNumber) {
    return __awaiter(this, void 0, void 0, function* () {
        const list = yield (0, list_steps_1.getList)(this);
        const listRow = yield list.getRow(rowNumber);
        const cell = yield listRow.getCellAsync(columnTitle);
        yield (0, test_1.expect)(cell.tagMark).toBeVisible();
    });
});
(0, cucumber_1.Then)("ячейка колонки {string} строки №{int} не содержит тег.", function (columnTitle, rowNumber) {
    return __awaiter(this, void 0, void 0, function* () {
        const list = yield (0, list_steps_1.getList)(this);
        const listRow = yield list.getRow(rowNumber);
        const cell = yield listRow.getCellAsync(columnTitle);
        yield (0, test_1.expect)(cell.tagMark).toBeHidden();
    });
});
/**форма */
(0, cucumber_1.When)("на форме в меню тегов нажимаем кнопку {string}.", function (button) {
    return __awaiter(this, void 0, void 0, function* () {
        const form = yield (0, form_steps_1.getForm)(this);
        const tagMenu = yield form.getTagMenu();
        const action = tagMenu.getAction(button);
        yield action.click();
    });
});
(0, cucumber_1.Then)("на форме есть меню тегов.", function () {
    return __awaiter(this, void 0, void 0, function* () {
        const form = yield (0, form_steps_1.getForm)(this);
        const tagMenu = yield form.getTagMenu();
        yield (0, test_1.expect)(tagMenu.el).toBeVisible();
    });
});
(0, cucumber_1.Then)("на форме в меню тегов открыта форма {string}.", function (formTitle) {
    return __awaiter(this, void 0, void 0, function* () {
        const form = yield (0, form_steps_1.getForm)(this);
        const tagMenu = yield form.getTagMenu();
        const addForm = tagMenu.getForm();
        yield (0, test_1.expect)(addForm.el).toBeVisible();
        (0, test_1.expect)(yield addForm.title.textContent()).toBe(formTitle);
    });
});
(0, cucumber_1.Then)("на форме тег №{int} с типом {string} создан {string} пользователем {string}.", function (number, type, date, user) {
    return __awaiter(this, void 0, void 0, function* () {
        const form = yield (0, form_steps_1.getForm)(this);
        const tagMenu = yield form.getTagMenu();
        const tag = tagMenu.getTag(number);
        (0, test_1.expect)(yield tag.title.textContent()).toBe(type);
        (0, test_1.expect)(yield tag.date.textContent()).toSoftEqual(date);
        (0, test_1.expect)(yield tag.user.textContent()).toBe(user);
    });
});
(0, cucumber_1.Then)(/^на форме в меню тегов (-?\d+) тег[ов|а]*\./, function (count) {
    return __awaiter(this, void 0, void 0, function* () {
        const form = yield (0, form_steps_1.getForm)(this);
        const tagMenu = yield form.getTagMenu();
        if (count > 0)
            yield tagMenu.getTag(1).el.waitFor();
        const tagsCount = yield tagMenu.tagsCount();
        (0, test_1.expect)(tagsCount).toBe(count);
    });
});
(0, cucumber_1.Then)("на форме в меню тегов есть кнопка {string}.", function (button) {
    return __awaiter(this, void 0, void 0, function* () {
        const form = yield (0, form_steps_1.getForm)(this);
        const tagMenu = yield form.getTagMenu();
        const action = tagMenu.getAction(button);
        yield (0, test_1.expect)(action).toBeVisible();
    });
});
(0, cucumber_1.Then)("на форме в меню тегов нет тегов.", function () {
    return __awaiter(this, void 0, void 0, function* () {
        const form = yield (0, form_steps_1.getForm)(this);
        const tagMenu = yield form.getTagMenu();
        const count = yield tagMenu.tagsCount();
        (0, test_1.expect)(count == 0).toBeTruthy();
    });
});
(0, cucumber_1.Then)("на форме тег №{int} содержит комментарий {string}.", function (tagNumber, comment) {
    return __awaiter(this, void 0, void 0, function* () {
        const form = yield (0, form_steps_1.getForm)(this);
        const tagMenu = yield form.getTagMenu();
        const tag = tagMenu.getTag(tagNumber);
        (0, test_1.expect)(yield tag.comment.textContent()).toBe(comment);
    });
});
(0, cucumber_1.Then)("на форме в меню тегов поле {string} заполнено значением {string}.", function (fieldName, value) {
    return __awaiter(this, void 0, void 0, function* () {
        const form = yield (0, form_steps_1.getForm)(this);
        const tagMenu = yield form.getTagMenu();
        const field = yield tagMenu.getField(fieldName);
        (0, test_1.expect)(yield field.displayValueAsync()).toSoftEqual(value);
    });
});
(0, cucumber_1.Then)("в списке запись №{int} содержит тег.", function (rowNumber) {
    return __awaiter(this, void 0, void 0, function* () {
        const list = yield (0, list_steps_1.getList)(this);
        const listRow = yield list.getRow(rowNumber);
        yield (0, test_1.expect)(listRow.formOpenerCell.tagMark).toBeVisible();
    });
});
(0, cucumber_1.Then)("в списке запись №{int} не содержит тег.", function (rowNumber) {
    return __awaiter(this, void 0, void 0, function* () {
        const list = yield (0, list_steps_1.getList)(this);
        const listRow = yield list.getRow(rowNumber);
        yield (0, test_1.expect)(listRow.formOpenerCell.tagMark).toBeHidden();
    });
});
