"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const cucumber_1 = require("@cucumber/cucumber");
const test_1 = require("@playwright/test");
const setup_1 = require("../../../setup/setup");
const pathList_1 = require("../../utils/pathList");
const ADMIN_NODE_TITLE = "Администрирование";
const MODULES_NODE_TITLE = "МОДУЛИ";
(0, cucumber_1.Given)("пользователь находится в узле навигации {string}.", { timeout: setup_1.config.largeTimeout }, function (nodePath) {
    return __awaiter(this, void 0, void 0, function* () {
        yield goToNode(this, nodePath);
    });
});
(0, cucumber_1.When)("переходим в узел навигации {string}.", { timeout: setup_1.config.largeTimeout }, function (nodePath) {
    return __awaiter(this, void 0, void 0, function* () {
        yield goToNode(this, nodePath);
    });
});
function goToNode(page, nodePath) {
    return __awaiter(this, void 0, void 0, function* () {
        const pathList = new pathList_1.PathList(nodePath);
        if (pathList.isEmpty())
            return;
        let nodeTitle = pathList.takeNext();
        if (nodeTitle == ADMIN_NODE_TITLE) {
            yield page.header.admin.click();
        }
        else {
            if (yield page.header.hasApps()) {
                yield goToAppsNode(page, nodeTitle);
                if (pathList.isEmpty())
                    return;
                yield goToNavNode(page, pathList.takeNext());
            }
            else {
                yield goToNavNode(page, nodeTitle);
            }
        }
        if (pathList.isEmpty())
            return;
        yield goToLeftNode(page, pathList);
        const content = page.getContent();
        yield content.waitForLoading();
    });
}
(0, cucumber_1.When)("нажимаем на меню приложений.", function () {
    return __awaiter(this, void 0, void 0, function* () {
        yield this.header.apps.click();
    });
});
(0, cucumber_1.When)("нажимаем на узел администрирования.", function () {
    return __awaiter(this, void 0, void 0, function* () {
        yield this.header.admin.click();
    });
});
(0, cucumber_1.When)("нажимаем на {string} в меню приложений.", function (appsNode) {
    return __awaiter(this, void 0, void 0, function* () {
        yield clickOnAppsItem(this, appsNode);
    });
});
(0, cucumber_1.When)("в верхней навигации нажимаем на узел {string}.", function (node) {
    return __awaiter(this, void 0, void 0, function* () {
        yield goToNavNode(this, node);
    });
});
(0, cucumber_1.When)("в боковой навигации нажимаем на узел {string}.", function (nodePath) {
    return __awaiter(this, void 0, void 0, function* () {
        const pathList = new pathList_1.PathList(nodePath);
        yield goToLeftNode(this, pathList);
    });
});
(0, cucumber_1.Then)("открывается узел навигации {string}.", function (nodePath) {
    return __awaiter(this, void 0, void 0, function* () {
        yield nodeWasOpen(this, nodePath);
    });
});
(0, cucumber_1.Then)("открыт узел навигации {string}.", function (nodePath) {
    return __awaiter(this, void 0, void 0, function* () {
        yield nodeWasOpen(this, nodePath);
    });
});
(0, cucumber_1.Then)("в меню приложений есть узел {string}.", function (itemTitle) {
    return __awaiter(this, void 0, void 0, function* () {
        yield this.appsTiles.el.waitFor();
        yield (0, test_1.expect)(this.appsTiles.item(itemTitle)).toBeVisible();
    });
});
(0, cucumber_1.Then)("в узле навигации есть ошибка {string}.", function (errorMessage) {
    return __awaiter(this, void 0, void 0, function* () {
        yield (0, test_1.expect)(this.getContent().content).toContainText(errorMessage);
    });
});
function nodeWasOpen(page, nodePath) {
    return __awaiter(this, void 0, void 0, function* () {
        const pathList = new pathList_1.PathList(nodePath);
        if (pathList.isEmpty())
            throw new Error("Узел навигации не был передан.");
        if (yield page.header.hasApps()) {
            let nodeTitle = pathList.takeNext();
            (0, test_1.expect)(yield page.header.appsTitle.textContent()).toBe(nodeTitle);
            if (nodeTitle == ADMIN_NODE_TITLE) {
                (0, test_1.expect)(page.header.admin).toHaveClass(/active/);
            }
            else {
                nodeTitle = pathList.takeNext();
                yield (0, test_1.expect)(page.header.navItem(nodeTitle)).toHaveClass(/active/);
            }
        }
        else {
            let nodeTitle = pathList.takeNext();
            yield (0, test_1.expect)(page.header.navItem(nodeTitle)).toHaveClass(/active/);
        }
        if (pathList.hasNext()) {
            yield expectLeftNavPath(page, pathList);
        }
        const content = page.getContent();
        const contentTitle = yield content.header.title.textContent();
        (0, test_1.expect)(contentTitle).toBe(pathList.last);
    });
}
function expectLeftNavPath(page, pathList) {
    return __awaiter(this, void 0, void 0, function* () {
        if (pathList.isEmpty())
            return;
        let list = page.leftNav.list;
        let next = pathList.takeNext();
        let node = list.item(next);
        if (!(yield node.el.isVisible())) {
            throw new Error(`Узел ${next} не найден`);
        }
        if (pathList.isEmpty()) {
            yield (0, test_1.expect)(node.el).toHaveClass(/active/);
            return;
        }
        while (pathList.hasNext()) {
            next = pathList.takeNext();
            node = node.list.item(next);
            if (!(yield node.el.isVisible())) {
                throw new Error(`Узел ${next} не найден`);
            }
            if (pathList.isEmpty()) {
                yield (0, test_1.expect)(node.el).toHaveClass(/active/);
                return;
            }
        }
    });
}
function clickOnAppsItem(page, itemTitle) {
    return __awaiter(this, void 0, void 0, function* () {
        yield page.waitNavigationAfterInvoke(() => __awaiter(this, void 0, void 0, function* () {
            yield page.header.apps.waitFor();
            yield page.appsTiles.item(itemTitle).click();
        }));
        yield page.waitForLoading();
    });
}
function goToAppsNode(page, nodeTitle) {
    return __awaiter(this, void 0, void 0, function* () {
        yield page.header.apps.click();
        yield clickOnAppsItem(page, nodeTitle);
    });
}
function goToNavNode(page, nodeTitle) {
    return __awaiter(this, void 0, void 0, function* () {
        yield page.header.navItem(nodeTitle).click();
    });
}
function goToLeftNode(page, path) {
    return __awaiter(this, void 0, void 0, function* () {
        let list = page.leftNav.list;
        while (path.hasNext()) {
            let next = path.takeNext();
            const divider = list.divider(next);
            if (yield divider.header.isVisible()) {
                yield divider.header.click();
                list = divider.list;
                continue;
            }
            const item = list.item(next);
            yield item.content.click();
            list = item.list;
        }
    });
}
