import type { IConfiguration } from "@cucumber/cucumber/lib/configuration/types";
import { DefineStepPattern, IDefineStepOptions, TestStepFunction } from "@cucumber/cucumber/lib/support_code_library_builder/types";
export declare type CucumberConifg = Partial<IConfiguration>;
export declare type Config = ConfigApp & ConfigBase;
export interface ConfigApp {
    url: string;
    users: {
        [k: string]: UserAuthData;
    };
    defaultUser?: string;
}
export interface UserAuthData {
    login: string;
    password: string;
}
export interface ConfigBase {
    /**
     * @default 10000
     */
    timeout: number;
    /**
     * @default 30000
     */
    largeTimeout: number;
    /**
     * @default 0
     */
    slowMo: number;
    /**
     * @default 3
     */
    maxRetries: number;
    /**
     * @default true
     */
    reloadOnError: boolean;
    /**
     * @default false
     */
    devTools?: boolean;
    /**
     * @default true
     */
    enableRecordSnapshots?: boolean;
    timezone?: string;
}
export interface TestsSetup {
    features: string[];
    steps: string[];
    exitOnEnd: boolean;
}
export interface Settings {
    cucumberConfiguration: CucumberConifg;
    config: Config;
    debugMode?: DebugMode;
}
export interface UserSettings {
    tests: TestsSetup;
    app: ConfigApp;
    setup: ConfigBase;
    debug: IDebugConfig;
}
export declare type DebugMode = (typeof debugMods)[number];
export declare const debugMods: readonly ["disabled", "browser", "inspectTool"];
export interface IDebugConfig {
    mode?: DebugMode;
    devTools?: boolean;
}
export declare type StepDefinition<PageObjectType> = (<WorldType = PageObjectType>(pattern: DefineStepPattern, code: TestStepFunction<WorldType>) => void) & (<WorldType_1 = PageObjectType>(pattern: DefineStepPattern, options: IDefineStepOptions, code: TestStepFunction<WorldType_1>) => void);
